/* XPM */
/* $XConsortium: DtI18N.pm /main/2 1996/07/23 11:56:53 drk $ */
static char * DtI18N_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"38 37 5 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor1	m black	c black",
"X	s iconColor4	m white	c green",
"o	s iconColor5	m black	c blue",
"O	s iconGray5	m black	c #737373737373",
/* pixels */
"                                      ",
"               ........               ",
"            ...XoXXoooo...            ",
"          ..ooXooooooooooO..          ",
"         .XXXXXXoooooooOXoOO.         ",
"        .XXXXXoooooooooooXOX..        ",
"       .XXXXoooooooooooooXXo...       ",
"      .XXXXooooooooooooooXoo....      ",
"     .XXXXoooooooooooooooXXXOo...     ",
"    .oXooooooooooooooooooXXXXOO...    ",
"    .XooooooooooooooooooXXXXXOXO..    ",
"   .oXoXoXooooooooooooooXXXXXXOOO..   ",
"   .oXXooooooooooooooooooXXXXXXOO..   ",
"   .oooXoooooooooooooooooXXXXXOXOO.   ",
"  .ooooXoXXXoooooooooooooXXXXXXOOO..  ",
"  .ooooooXXXXoooooooooooooXXXoXOXO..  ",
"  .oooooXXXXXXXooooooooooooooooXOO..  ",
"  .oooooXXXXXXXXoooooooooooooooXOOO.  ",
"  .oooooXXXXXXXXXooooooooooooooOXO..  ",
"  .oooooXXXXXXXXXXXooooooooooooXOO..  ",
"  .ooooooXXXXXXXXXXooooooooooooOXOo.  ",
"  .ooooooXXXXXXXXXoooooooooooooOOO..  ",
"   .ooooooXXXXXXXXoooooooooooooXOO.   ",
"   .oooooooXXXXXXXoooooooooooo.X...   ",
"   .oooooooXXXXXoooooooooooooo.OOo.   ",
"    .ooooooXXXXXoooooooooooooooX..    ",
"    .ooooooXXXXoooooooooooooo.Xo..    ",
"     .ooooooXXXooooooooooooooo...     ",
"      .oooooXXooooooooooooooo.o.      ",
"       .ooooXXooooooooooooo....       ",
"        .ooooXooooooooooooo.o.        ",
"         .oooooooooooooooo...         ",
"          ..ooooooooooo..o..          ",
"            ...ooXoXXXo...            ",
"               ........               ",
"                                      ",
"                                      "};
