/* XPM */
/* $XConsortium: DtPrtpr.m.pm /main/3 1995/07/18 16:24:56 drk $ */
static char * DtPrtpr_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 12 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray4     m white c #949494949494",
"X	s iconColor2	m white	c white",
"o    s iconGray1     m white c #dededededede",
"O    s iconGray2     m white c #bdbdbdbdbdbd",
"+    s bottomShadowColor m black c #636363636363",
"@    s iconGray7     m black c #424242424242",
"#    s iconGray5     m black c #737373737373",
"$    s iconGray6     m black c #636363636363",
"%    s iconGray8     m black c #212121212121",
"&    s iconGray3     m white c #adadadadadad",
"*    s selectColor m white c #737373737373",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"      ...............           ",
"      .XXXXXXXXXXXXo.           ",
"      .XOOOOOOOOOOXo.           ",
"   ++++XXOXOXOOXXXXX+++++++     ",
"  ++XOOXOOOXOOXOOOXXoOOOOOO@    ",
" ++XO#.ooooooooooooo.OoOOOOO@   ",
" +XOO$################XOOOOOO@  ",
" +Xoooooooooooooooooooooooooo@  ",
" +XOoooooooooooooooooo$$$$$$O@  ",
" +XOoooooooooooooooooo$####$O@  ",
" +XOO#################$$$$$$O@  ",
" +XOOOOOOOOOOOOOOOOOOOOOOOOOO@  ",
" +XOOOOOOOOOOOOOOOOOOOOOOOOOO@  ",
" +XOO%%%%%%%%%%%%%%%%%%OOOOOO@  ",
" +XOO%.###############%OOOOOO@  ",
" +X%%&.################%%%%%%@  ",
"  +&@.#################@@@@%    ",
"   &%%%%%%%%%%%%%%%%%%%%%%%%    ",
"     %%%%%%%%%%%%%%%%%%+*       ",
"     +++++++++++++++++++*       ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                "};
