/* XPM */
/* $XConsortium: polyline.pm /main/2 1996/07/23 13:30:45 drk $ */
static char * IEtPolyl [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 4 1 0 0",
/* colors */
"     s iconGray2     m white c #bdbdbdbdbdbd",
".    s iconGray4     m white c #949494949494",
"X    s iconGray3     m white c #adadadadadad",
"o	s iconColor1	m black	c black",
/* pixels */
"                                    ",
"                                   .",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXoooXXXXX..",
"  XXXXXXXXXXXXXXXXXXXoooooXXoXXXXX..",
"  XXXXXXXXXXXXXXoooooXXXXXXXoXXXXX..",
"  XXXXXXXXXoooooXXXXXXXXXXXXoXXXXX..",
"  XXXXXXoooXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXoXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXoXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXoXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXoXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXoXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXXoXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXXXoXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXXXXoXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXXXoXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXXoXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXoXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXoXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXoXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXoXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXoXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXoXXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  ..................................",
" ..................................."};
