/* XPM */
/* $XConsortium: DtMdl.m.pm /main/3 1995/07/18 16:22:11 drk $ */
static char * DtMdl_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray1     m white c #dededededede",
"o    s iconGray6     m black c #636363636363",
"O	s iconColor3	m black	c red",
"+    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray5     m black c #737373737373",
"#	s iconColor4	m white	c green",
"$    s iconGray4     m white c #949494949494",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"..............    ..............",
".XXXXXXXXXXXXXo   .XXXOOXXOX+.+o",
".X@@@@XXXXXXXXo    .XXOOXOXO+++o",
".XXXXXXXXXXXXXXo    .XXXOXOX.#.o",
".X@@X@XXXXXXXXXXo   .XXXXXXXXXXo",
".XXXXXXXXXXXXXXXo   .XXXXXXXXXXo",
".XXXXXXXXXXXXXXXo   .XXXXXXXXXXo",
".XXXXXXXXXXXXXXo   .XXXXXXXXXXXo",
".XXXXXXXXXXXXXo    .XXXXXXXXXXXo",
".XXXXXXX$$$X$$o   .$XX$$XXXXXXXo",
".XXXXXXXXXXXXo    .XXXXXXXXXXXXo",
".XXXXXXX$$$$$o    .$XX$$XXXXXXXo",
".XXXXXXXXXXXXo    .XXXXXXXXXXXXo",
".XXXXXXX$$$X$$o    .$$$XXXXXXXXo",
".XXXXXXXXXXXXXo    .XXXXXXXXXXXo",
".XXXXXXXXXXXXXo    .XXXXXXXXXXXo",
".XXXXXXXXXXXXXXo  .XXXXXXXXXXXXo",
".ooooooooooooooo  .ooooooooooooo"};
