/* XPM */
/* $XConsortium: Dtbmark.l.pm /main/2 1996/10/29 15:51:17 drk $ */
static char * Dtbmark_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 10 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #bdbdbdbdbdbd",
"o	s iconGray6	m black	c #636363636363",
"O	s iconColor1	m black	c black",
"+	s iconGray5	m black	c #737373737373",
"@	s iconColor6	m white	c yellow",
"#	s iconColor3	m black	c red",
"$	s iconGray8	m black	c #212121212121",
"%	s iconGray4	m white	c #949494949494",
/* pixels */
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"  ..............................                ",
"  .XXoXXXXXXXXXXXXXXXXXXXXXXXXXO                ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOO               ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoO              ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO             ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO             ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO             ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO             ",
"  .XX+XXXOOOOOXOOOXXOXXXOOXXXXXOoOO             ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO             ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO             ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXO............... ",
"  .XX+XXXOOXXX@@@XXXOXXOOOXXXXXO#######@@@####$ ",
"  .XX+XXXXXXXX@@@XXXXXXXXXXXXXXO######o@@@o###$ ",
"  .XX+XXXXXXXX@@@XXXXXXXXXXXXXXO#######oo@o###$ ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXO#########@o###$ ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXO#########@o###$ ",
"  .XX+XXXXXXXX@@@XXXXXXXXXXXXXXO#########@o###$ ",
"  .XX+XXXXXX@@@@@XXXXXXXXXXXXXXO#########@o###$ ",
"  .XX+XXXXXX@@@@@XXXXXXXXXXXXXXO#########@o###$ ",
"  .XX+XXXXXXXX@@@XXXXXXXXXXXXXXO#########@o###$ ",
"  .XX+XXXXXXXX@@@XXXXXXXXXXXXXXO#########@o###$ ",
"  .XX+XXXXXXXX@@@XXXXXXXXXXXXXXO#########@o###$ ",
"  .XX+XXXXXXXX@@@XXXXXXXXXXXXXXOOOOOOOOOO@ooO$$ ",
"  .XX+XXXXXXXX@@@@XXXXXXXXXXXXXOoOO      @o     ",
"  .XX+XXXXXXXX@@@@XXXXXXXXXXXXXOoOO      @o     ",
"  .XX+XXXXXXXX@@@@XXXXXXXXXXXXXOoOO      @o     ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO      @o     ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO      @o     ",
"  .XX+XXXXXXOOOOOOXXXXXXXXXXXXXOoOO      @o     ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO    @@@o     ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO   @@@@oo    ",
"  .XX+XXOOOOOOOXXOOOOOOOXXXXXXXOoOO   @%@@@@o   ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO   @%@%@%oo  ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO   @%@%@%oo  ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO   @%@%@%oo  ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO   @%@%@%oo  ",
"  .XX+XXXXXXXXXXXXXXXXXXXXXXXXXOoOO   @%@%@%oo  ",
"  .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOoOO   @%@%@%oo  ",
"  .OoooooooooooooooooooooooooooooOO   @%@%@%oo  ",
"  .Oo+oooooooooooooooooooooooooooOO   @%@%@%oo  ",
"   .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO    oo%o%oo  "};
