/* XPM */
/* $XConsortium: Dteditqryi.m.pm /main/2 1996/07/23 12:10:15 drk $ */
static char * Dteditqryi_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconGray2	m white	c #bdbdbdbdbdbd",
"X	s iconGray3	m white	c #adadadadadad",
"o	s iconGray5	m black	c #737373737373",
"O	s iconGray6	m black	c #636363636363",
"+	s iconGray4	m white	c #949494949494",
"@	s iconColor3	m black	c red",
"#	s iconColor6	m white	c yellow",
"$	s iconColor5	m black	c blue",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
" ......................         ",
" .XoXXXXXXXXXXXXXXXXXXO      +  ",
" .XoXXXXXXXXXXXXXXXXXXOO    @.+ ",
" .XoXXXXXXXXXXXXXXXXXXOOO  O@@o ",
" .XoXXOOOXOXOOXOOXOXXXOOO #+O@@O",
" .XoXXXXXXXXXXXXXXXXXXOOO#o#oOO ",
" .XoXXXXX$o$oXXXXXXXXXOO#o#o#O  ",
" .XoXXXX$o$o$oXXXXXXXXO#o#o#O   ",
" .XoXXX$o$o$o$oXXXXXXX#o#o#O    ",
" .XoXXXo$oXX$o$XXXXXX#o#o#O     ",
" .XoXXX$o$XXo$oXXXXX#o#o#O      ",
" .XoXXXXXXXo$oXXXXX#o#o#O       ",
" .XoXXXXXXo$oXXXXX#o#o#OO       ",
" .XoXXXXXX$o$XXXX#o#o#OOO       ",
" .XoXXXXXXXXXXXX#o#o#OOOO       ",
" .XoXXXXXX$o$XX#o#o#OXOOO       ",
" .XoXXXXXXo$oXXo#o#OXXOOO       ",
" .XoXXXXXX$o$XOXo#OXXXOOO       ",
" .XoXXXXXXXXXXOXOOXXXXOOO       ",
" .XoXXXXXXXXXOOOOXXXXXOOO       ",
" .XoXXXXXXXXOOOXXXXXXXOOO       ",
" .XoXXXOOOOOOOOOOOXXXXOOO       ",
" .XoXXXXXXXXXXXXXXXXXXOOO       ",
" .XoXXXXXXXXXXXXXXXXXXOOO       ",
" .XoXXXXXXXXXXXXXXXXXXOOO       ",
" .OOOOOOOOOOOOOOOOOOOOOOO       ",
" .OOOOOOOOOOOOOOOOOOOOOOO       ",
"  .OOOOOOOOOOOOOOOOOOOOOO       "};
