/* XPM */
/* $XConsortium: Dtaexex.t.pm /main/2 1996/07/23 12:01:29 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * Dtaexe [] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 7 1 0 0",
/* colors */
" 	s iconGray2	m white	c #c8c8c8c8c8c8",
".	s iconColor3	m black	c red",
"X	s iconGray6	m black	c #646464646464",
"o	s iconGray3	m white	c #afafafafafaf",
"O	s iconColor1	m black	c black",
"+	s iconGray5	m black	c #7d7d7d7d7d7d",
"@	s iconGray1	m white	c #e1e1e1e1e1e1",
/* pixels */
"                ",
" .X.X.o.X.X.o.XO",
" X.o.o.+.+.+.o.O",
" .o.o.o.o.o.o.oO",
" oOOOOOO.O.o.o.O",
" OOOOOOOOOO.@.oO",
" O. . . OOOO.@.O",
" . .OOOOoOOOO.@O",
" O.OOOOOOooOOO.O",
" .OOOOOOOOOOOOOO",
" OOOO..OOOOOOOOO",
" OOO.OO.OOO.OOOO",
" OO.O.OO.O.O.OOO",
" OO.OOOO.O.OOOOO",
" .OO.OO.OOO.OOOO",
" OOOOOOOOOOOOOOO"};
