/* XPM */
static char *ktuberling_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #2E3436",
".  c #393E3F",
"X  c #343634",
"o  c #3D3426",
"O  c #7D3E00",
"+  c #503D27",
"@  c #483927",
"#  c #7F4402",
"$  c #61411E",
"%  c #784817",
"&  c #6C552F",
"*  c #625239",
"=  c #735B3D",
"-  c #15394E",
";  c #1D3741",
":  c #143F58",
">  c #383E40",
",  c #19455C",
"<  c #264558",
"1  c #184D6A",
"2  c #164A66",
"3  c #144F71",
"4  c #325D78",
"5  c #3A5768",
"6  c #424748",
"7  c #494C4A",
"8  c #4E5454",
"9  c #515655",
"0  c #555B5A",
"q  c #5B5D59",
"w  c #6F6655",
"e  c #7D6547",
"r  c #5B5F60",
"t  c #5D6261",
"y  c #6B6E6E",
"u  c #666B6B",
"i  c #6C716F",
"p  c #6E7371",
"a  c #717472",
"s  c #7B7E7D",
"d  c #803F00",
"f  c #9E2F1F",
"g  c #A33C1E",
"h  c #860E28",
"j  c #9C3021",
"k  c #A83E24",
"l  c #834403",
"z  c #8C4C02",
"x  c #82460A",
"c  c #944B01",
"v  c #9B4D00",
"b  c #904700",
"n  c #9C5204",
"m  c #9A5A0A",
"M  c #9B5A12",
"N  c #A45101",
"B  c #A35A03",
"V  c #AE5901",
"C  c #BE500B",
"Z  c #AF4D1A",
"A  c #B44410",
"S  c #B95B17",
"D  c #92651E",
"F  c #AD6403",
"G  c #B96402",
"H  c #BE6912",
"J  c #B87414",
"K  c #AD4B2E",
"L  c #B64F24",
"P  c #B75B38",
"I  c #BD5A29",
"U  c #8C663F",
"Y  c #94763F",
"T  c #946730",
"R  c #C76704",
"E  c #CB6A01",
"W  c #CA6E0B",
"Q  c #C76B09",
"!  c #D26500",
"~  c #D36A02",
"^  c #D96C00",
"/  c #CC730C",
"(  c #CA7104",
")  c #D77807",
"_  c #D26D11",
"`  c #CB7610",
"'  c #D27B13",
"]  c #D67E19",
"[  c #C36914",
"{  c #E07F09",
"}  c #C2652A",
"|  c #C66B31",
" . c #967C57",
".. c #C97942",
"X. c #B98327",
"o. c #DF810A",
"O. c #D5831B",
"+. c #DC891D",
"@. c #DA8718",
"#. c #C48419",
"$. c #E68708",
"%. c #EE970B",
"&. c #E58C15",
"*. c #E38617",
"=. c #EC981A",
"-. c #F49B14",
";. c #F59B1A",
":. c #F3A109",
">. c #E4A01D",
",. c #F6A61C",
"<. c #C88720",
"1. c #D98924",
"2. c #DC9728",
"3. c #C89730",
"4. c #DA9F31",
"5. c #E69D27",
"6. c #F19D23",
"7. c #E39E35",
"8. c #DEA93E",
"9. c #EBA426",
"0. c #F9AC25",
"q. c #F5AA2B",
"w. c #F6A829",
"e. c #FBB223",
"r. c #FDBB2C",
"t. c #F6AB33",
"y. c #F2AB3A",
"u. c #F8AD30",
"i. c #F7B436",
"p. c #F9B333",
"a. c #F8B73A",
"s. c #E7AA38",
"d. c #FEC035",
"f. c #BB924E",
"g. c #AB8453",
"h. c #86816D",
"j. c #92836C",
"k. c #8C877A",
"l. c #8D8C7C",
"z. c #9C8E7A",
"x. c #B89C69",
"c. c #BEA47D",
"v. c #D49E50",
"b. c #DDAA41",
"n. c #D9A741",
"m. c #E6AC49",
"M. c #E9B449",
"N. c #F6B442",
"B. c #F9BA43",
"V. c #F3B54B",
"C. c #F9BC49",
"Z. c #F4B947",
"A. c #E7B859",
"S. c #F5BB53",
"D. c #F9BF55",
"F. c #D5AF60",
"G. c #DEB96D",
"H. c #D7B977",
"J. c #E8BB64",
"K. c #E4BD72",
"L. c #FCC644",
"P. c #FBC24E",
"I. c #F9C254",
"U. c #FCCA54",
"Y. c #F6C65C",
"T. c #FAC65B",
"R. c #FBCB5D",
"E. c #F5C253",
"W. c #F3CA61",
"Q. c #FACB63",
"!. c #F2CA6D",
"~. c #FACD6A",
"^. c #FDD463",
"/. c #FCD26B",
"(. c #FFDA6A",
"). c #F5D26D",
"_. c #E3CD7C",
"`. c #E9C677",
"'. c #FBD572",
"]. c #FEDC74",
"[. c #FCDB7C",
"{. c #FFE17D",
"}. c #155F8A",
"|. c #16618E",
" X c #146291",
".X c #21678F",
"XX c #1674AF",
"oX c #1975AF",
"OX c #1475B1",
"+X c #327AA7",
"@X c #4F7A8E",
"#X c #607C8A",
"$X c #004ED6",
"%X c #0A57DB",
"&X c #005EF1",
"*X c #026AFC",
"=X c #0E76F8",
"-X c #437BDB",
";X c #3183B2",
":X c #5C8198",
">X c #76868E",
",X c #498CB5",
"<X c #1C86C8",
"1X c #3D8FF6",
"2X c #76AACA",
"3X c #6AB5E3",
"4X c #79C5E7",
"5X c #828784",
"6X c #8A8A82",
"7X c #8A8B88",
"8X c #8C908B",
"9X c #93938D",
"0X c #869599",
"qX c #9B9D99",
"wX c #949696",
"eX c #A29B84",
"rX c #A5A597",
"tX c #979BAA",
"yX c #80A5BA",
"uX c #9EA7A6",
"iX c #A6A8A6",
"pX c #BBB8AF",
"aX c #ADB3B1",
"sX c #A0B4BD",
"dX c #B8B9B7",
"fX c #C9B584",
"gX c #D3C28C",
"hX c #ECCE83",
"jX c #F7DC87",
"kX c #F5DE94",
"lX c #E9D484",
"zX c #FFE483",
"xX c #FEE58B",
"cX c #FFE98D",
"vX c #FFEB94",
"bX c #FEED9B",
"nX c #FFF09E",
"mX c #E6DDA9",
"MX c #FBEFA3",
"NX c #FFF3A5",
"BX c #FFF4AA",
"VX c #FDF9BB",
"CX c #96BBD1",
"ZX c #9BBDE8",
"AX c #B9C7CE",
"SX c #BEDAEB",
"DX c #CACBC7",
"FX c #C5C7C2",
"GX c #DCDDDB",
"HX c #D7D7D4",
"JX c #C6D9C1",
"KX c #E1E1DF",
"LX c #D0E7E7",
"PX c #EEEEEB",
"IX c #E6E8E4",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXX.b.M.b.b.4.<.UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXA.{.{.{.].Q.E.Z.i.J UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX].`.jXvXvXzX{.(.^.U.L.#.UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX)._.gXmXMXnXvXzX].^.A.3.d.m UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXb.cX_.IX4XVXNXvXzX].kXLXF.d.>.UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXW.xXlXZX*XJXbXcXzX].3X1XK.d.e.# UXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX].zXxXZX&XrXxXzX].).=X-XW.r.,.B UXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX(.(.{.mX%Xc.].(.^.H.$XtXr.e.&.F UXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXU.^.^.^.G.m.^.R.U.7.wXa.e.,.o.z UXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXs...P A.P.U.P.P.B.p.w.0.-._ ) UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJ y.} g K K P | } I L k h A G UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXO.5.=.@.` [ S Z Z j f C E UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX` &.&.%.:.:.%.o.~ ! E UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXwXDXz.H ^ ! ! ! ! E n UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX9XGXPXGXqXk.dXaXaX@X< UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXPXs $ & pXDXFXaX3 ; UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXdXqX@ 4.2.8XIX0X#X2 UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX4 6 X.i.9.7XKX@X X, - UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX.X0XD L.i.9.f.>XOX X- 2 1 UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXXXyXD 5.t.q.=.` CXOX|.- }.2XUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX,X .9.9.&.{ $./ sXOX X: CXSXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX<X;Xk.>.u.0.,.-.{ E uXOX X5 AX% UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX;X@XY 5.p.p.u.0.;.$.E 9X+X X< % O UXUXUXUXUXUX",
"UXy dXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX/ ' 1.+.2.B.B.a.u.w.=.) j.+X X1 O l UXUXUXUXUXUX",
"i 5XPXiXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXW ` 7.V.Y.m.1.Z.D.N.t.6.' T :X X3 UXO O UXUXUXUXUX",
"a iXPXHXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXQ 1.T./.].[.~.'.7.Q.D.a.w.O.m >X|.2 UXO d UXUXUXUXUX",
"#XaXPXPXqXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX] T.~.jXxXJ.jX!.J./.T.N.y.O.M U * UXUXUXd UXUXUXUXUX",
"UXrXPXPXiXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX/ V.~.'.xXbXjXNXbXJ.~.R.C.y.v.M v c UXUXUXd O UXUXUXUX",
"UXqXPXPXdXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX_ S.~.jXvXBXhXBXbXm.'.R.K.rXa = c c UXUXUXd d UXUXUXUX",
"UXs PXPXFXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX+.D.~.jXxXbX`.A.A.'./.`.k.X   X c c UXUXUXl d UXUXUXUX",
"UXa PXPXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX] S.Q.'.jXxXxXxX[.(.Q.eXu 5X5X> x c UXUXUXUXd UXUXUXUX",
"UXt PXPXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX_ N.T.Q.'.].[.'./.R.fX9 0 9   8 x # UXUXUXUXl UXUXUXUX",
"UXX PXPXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXR y.N.D.D.Q.Q.R.I.D.h.8 t 8 7 0 x UXUXUXUXUXO O UXUXUX",
"UX  GXIXUXUXUXUXUXUXUXUXUXUXv N UXV N v l b ' y.N.N.C.C.B.a.J.> > 6 5Xi X b UXUXUXUXUXO O O UXUX",
"UX6 9 q 6XU d d d d d d d d d d d d d d d d N +.w.t.t.t.u.w.x.          @ UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUX6X6XUXUXUXO O O O O UXO O d O l O O d v / ;.;.;.;.-. .          o UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXF G ( $.o.w           UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXB g.>           UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX8X          UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXp           UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX7         UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX      UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX  UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
