/* XPM */
/* $XConsortium: basewin.pm /main/1 1996/03/09 20:11:34 rws $ */
static char * basewin_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 32 7 1 0 0",
/* colors */
"     s iconGray4     m white c #949494949494",
".	s iconColor1	m black	c black",
"X    s iconGray8     m black c #212121212121",
"o    s iconGray2     m white c #bdbdbdbdbdbd",
"O	s iconColor2	m white	c white",
"+	c #8C8C8C8C8C8C",
"@	c #C3C3C3C3C3C3",
/* pixels */
"     .                             .     .     X",
" ooo .                             .     . ooo X",
" ooo .                             .  O  . oo. X",
" ... .                             .     . o.. .",
"     .                             .     .    +.",
"................................................",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@+.",
" .O@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@+.",
" .+++++++++++++++++++++++++++++++++++++++++++++.",
" ..............................................."};
