/* XPM */
static char *rosegarden_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #323B13",
".  c #343B1C",
"X  c #323722",
"o  c #373A26",
"O  c #3C4D03",
"+  c #3B460C",
"@  c #3C5100",
"#  c #3B4517",
"$  c #3F422E",
"%  c #415501",
"&  c #4D5D02",
"*  c #435706",
"=  c #444D1A",
"-  c #4A5B15",
";  c #495817",
":  c #4E4E06",
">  c #66510B",
",  c #4C6101",
"<  c #4D6803",
"1  c #5B6401",
"2  c #526E01",
"3  c #576704",
"4  c #5D7400",
"5  c #597506",
"6  c #4E6110",
"7  c #6A6302",
"8  c #676705",
"9  c #76660A",
"0  c #657501",
"q  c #677E03",
"w  c #7C7402",
"e  c #7A7A05",
"r  c #766212",
"t  c #444027",
"y  c #585329",
"u  c #554922",
"i  c #655B25",
"p  c #BB3411",
"a  c #CD0701",
"s  c #C81501",
"d  c #DA1702",
"f  c #D80B01",
"g  c #E41E02",
"h  c #C52105",
"j  c #DB2704",
"k  c #DB360A",
"l  c #C7330E",
"z  c #E82A01",
"x  c #E43405",
"c  c #EB3B01",
"v  c #E73703",
"b  c #F03B01",
"n  c #966A0B",
"m  c #827610",
"M  c #8D6B0F",
"N  c #AE6D14",
"B  c #A8592A",
"V  c #A15C38",
"C  c #906B2B",
"Z  c #B7662C",
"A  c #AF732B",
"S  c #DF460E",
"D  c #CB581C",
"F  c #D94D12",
"G  c #EC4303",
"H  c #EB4705",
"J  c #F14305",
"K  c #E85607",
"L  c #F1580A",
"P  c #E75616",
"I  c #ED5612",
"U  c #D7791B",
"Y  c #C67015",
"T  c #EA6B0D",
"R  c #E2650A",
"E  c #F2670B",
"W  c #ED710C",
"Q  c #F1750C",
"!  c #F17B0D",
"~  c #E76717",
"^  c #F56314",
"/  c #F36C18",
"(  c #ED7B14",
")  c #EB741A",
"_  c #E3741B",
"`  c #F27917",
"'  c #D15623",
"]  c #C46B24",
"[  c #C66729",
"{  c #DC6D28",
"}  c #D56426",
"|  c #CC7329",
" . c #D67C27",
".. c #C26E3E",
"X. c #E46925",
"o. c #EB7829",
"O. c #F47A27",
"+. c #C67B50",
"@. c #E57A54",
"#. c #6B8308",
"$. c #768805",
"%. c #769506",
"&. c #6C9004",
"*. c #87870A",
"=. c #968408",
"-. c #86960D",
";. c #988713",
":. c #979D18",
">. c #AB8E0A",
",. c #A2860A",
"<. c #B78B05",
"1. c #A6980E",
"2. c #AC8915",
"3. c #B5881A",
"4. c #B69613",
"5. c #A79614",
"6. c #8EA50A",
"7. c #8AA911",
"8. c #9DB71A",
"9. c #BCA907",
"0. c #ACB11A",
"q. c #9E872F",
"w. c #B89D2A",
"e. c #B0AD21",
"r. c #D28A09",
"t. c #CC9A07",
"y. c #DC9A0B",
"u. c #CD840F",
"i. c #F98A09",
"p. c #F89B0C",
"a. c #E9841A",
"s. c #F78619",
"d. c #F5931B",
"f. c #F69A18",
"g. c #E29418",
"h. c #C7AD17",
"j. c #C9B517",
"k. c #D4B414",
"l. c #D0BD13",
"z. c #CCAF0D",
"x. c #F8B808",
"c. c #EBA814",
"v. c #F7AA1D",
"b. c #F9AB1B",
"n. c #F8A617",
"m. c #ECBB16",
"M. c #F5B31D",
"N. c #FCB41C",
"B. c #FDBA1E",
"V. c #FAB614",
"C. c #EDAB0B",
"Z. c #E78C26",
"A. c #FB8A25",
"S. c #E7962C",
"D. c #F99924",
"F. c #EE9136",
"G. c #C8A728",
"H. c #C9B924",
"J. c #D4B129",
"K. c #F6A520",
"L. c #FEA226",
"P. c #F8A927",
"I. c #FDB523",
"U. c #FDBC24",
"Y. c #F9B729",
"T. c #F9A632",
"R. c #F7B939",
"E. c #E7B42B",
"W. c #FCC30A",
"Q. c #FBC709",
"!. c #FDD809",
"~. c #FCC613",
"^. c #FCC919",
"/. c #FED11B",
"(. c #FDDB1C",
"). c #FEDB14",
"_. c #EACA11",
"`. c #FCE306",
"'. c #FDF30C",
"]. c #FEE816",
"[. c #FEF313",
"{. c #FEF71B",
"}. c #E9CA25",
"|. c #FBC325",
" X c #FDCB25",
".X c #FCC429",
"XX c #FDCC2B",
"oX c #F6C827",
"OX c #FED424",
"+X c #FCD32B",
"@X c #FEDD2A",
"#X c #F5D727",
"$X c #EBC531",
"%X c #FACD3A",
"&X c #F8CA36",
"*X c #FBD334",
"=X c #FADB36",
"-X c #FBD43B",
";X c #FBDA3B",
":X c #F4D334",
">X c #E8D225",
",X c #FEE325",
"<X c #FDE52B",
"1X c #FDEA2A",
"2X c #FEEA22",
"3X c #FEF322",
"4X c #FEFB25",
"5X c #FFF32D",
"6X c #FEFA2C",
"7X c #FFEB38",
"8X c #FEFA35",
"9X c #FFF43B",
"0X c #FEF63B",
"qX c #D08D53",
"wX c #E8985B",
"eX c #F59743",
"rX c #D3A745",
"tX c #F9A743",
"yX c #FCBA4A",
"uX c #F4AE56",
"iX c #F9B956",
"pX c #EBA74C",
"aX c #CCAC6E",
"sX c #F4B469",
"dX c #F4BC7A",
"fX c #FACC41",
"gX c #FACA4A",
"hX c #FBD543",
"jX c #FCDA43",
"kX c #FBD54B",
"lX c #FCDA4A",
"zX c #F6D045",
"xX c #F9C659",
"cX c #FAD35A",
"vX c #FBD853",
"bX c #EEC645",
"nX c #FFF741",
"mX c #F5CA69",
"MX c #FAD966",
"NX c #F3C67A",
"BX c #F9D677",
"VX c #EECB6D",
"CX c #FCE27A",
"ZX c #F6CB89",
"AX c #F6D784",
"SX c #F9DB88",
"DX c #F8DC95",
"FX c #F8DD97",
"GX c #FBE38D",
"HX c #F9E385",
"JX c #FBE39C",
"KX c #FDE99B",
"LX c #FBE795",
"PX c #FDEAA4",
"IX c #FBE6A5",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX{ { { [ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXB X.) ) ~ ) )  .UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXZ B B D _ ( T R _ F.eXS.A UXUX| [ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX|  . .) ! W R R yXcXgXT.S.Z.Z.a.X.D UXUXUXwXwXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX] a.a.( W K K W %XlXR.P.K.K.s.) ~ F p UXqXpXuXqXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX] a.( Q K K W Q %X-XY.v.K.D.d.` ~ S l V pXiXsX..UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXY a.T K H K K W +X-X|.Y.M.D.d.A./ S p Z tXxXVXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX] ( K c v K c T +X+XoXU.M.K.d.` / I l X.tXxXxX+.UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX] ( J c v c j T :X+XoX|.M.K.d.Q ^ L k o.iXBXiX~ F ' UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX] W b z z x d T XX+XXX|.M.c.d.Q I O.wXdXJXAXtXJ L X.UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXR z g d x s W oX+XXXoXM.v.D.eXsXZXDXJXSXxX/ b L ' UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXS z d d x s W oX+X:X|.Y.xXNXSXJXIXIXBXgXT.b J ~ UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXN P g f d k s W |.=XjXcXBXAXDXIXPXIXMXhX%X^ b ^ } UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXM n _ g a j j s ! &XMXVXAXSXSXKXPXKXcX+X+Xd.J ^ O.UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX9 w M Z.z a x h ' uXBXSXFXLXPXPXLXCXfXB.V.N.A.A.A.a.UXUXUXUXUXUXUXC UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX7 8 M T.k f P qXdXSXDXJXPXPXLXCXkX.Xb.p.n.yXtXL.K.U UXUXUXUXUXUX3.A UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX7 > A T.X.@.NXFXIXJXJXKXSXMXkX&XU.p.i.i.T.yXI.N.K.U UXUXUXUXUXUX3.UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX7 > rXVXZXIXJXLXGXAXMX$Xh.k.XXB.c.i.s.A.L.I.I.N.K.UXUXUXUXUXUX4.3.UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXq.aXSXGXGXHXMXlX&XY.M.z.9.}.XXb.p.! A.L.I.I.N.I.K.UXUXUXUXUX2.4.UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXZXBXMXvXkXjX-X&X|.M.m.9.z.XXXXN.f.D.T.I.U.B.N.N.g.UXUXUXUXUX2.UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXmXcXzXfX-X-X-X*XoXY.|.k.9.#X+X^.V.p.L.Y.I.U.U.N.N.u.UXUXUXUXUX>.UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXqXxXvXhX%X*X*X=X*XXXoX}.9.}.@XOXOXV.x.n.Y.|.|.B.B.b.UXUXUXUXUX>.UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXC rXlXkXhXjX;X-X*XXXoXh.l.@X<X(.(.V.x.n.I.|. XB.N.c.UXUXUXUXUX,.UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXt C zXlXlXjXjX-X&XoXl.j.=X<X<X,X(.~.W.V.I.XXXXI.V.g.UXUXUXUX4.UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXy G.lXlXlXjXjX-X}.j.:X;X<X1X,X,X).Q.x.I.XX XI.V.r.UXUXUXUX5.UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXo C :XjXlXlXlX&Xh.H.*X7X7X5X1X2X].~.W.|. XOXB.n.Y UXUXUX5.;.UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXy $XjXlXjXjX$X1.e.=X7X9X9X5X2X].!.W. XXX XB.c.UXUXUX;.>.UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXy J.jXjX-X*XJ.$.-.#X9XnX0X5X3X].!.W.XX+X XN.y.UXUX9 *.UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX$ q.;X;X=X+Xk.#.$.}.7XnX8X5X3X[.`.~.XXOX Xx.u.UXr 1 e UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXi $XjX=X+Xh.4 #.H.<X0X8X4X3X[.`.W.XXOX/.y.UXm 8 8 m UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXt w.;X=X#X1.& 5 :.$X9X8X4X3X[.`.W. XOX~.r.UXe 3 *.UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXy G.}.m.=.@ @ #.H.1X6X4X{.'.`.x._./.x.Y 0 & $.UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXo ; m ,.1 @ @ 2 :.>X4X4X[.'.`.x.~.!.t.M % 3 *.UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXX   = * O O , 5 0.#X[.'.`.Q.x./.m.n 8 & $.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXX   = + @ @ , 5 0.].`._.C.~.^.<.m , 0 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXX   + O O @ % 2 -.9.<.t.t.>.e 1 & UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXX # + 6 , , , , 1 7 1 7 1 & UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXo . ; #.-.%.&.#.0 1 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXo = 5 7.7.6.7.$.0 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX# - q %.8.8.%.4 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX+ # ; 6 &.&.4 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX. = ; 2 2 & UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX. $ - 2 @ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXX # - 5 @ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX. . 6 5 + UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX.   6 #.+ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX.   6 $.+ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
