/* XPM */
/* $XConsortium: DtABtxp.pm /main/3 1995/07/18 16:16:29 drk $ */
static char * DtABtxp_x_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 32 11 1 0 0",
/* colors */
" 	s iconColor1	m black	c black",
".    s iconGray4     m white c #949494949494",
"X    s iconGray3     m white c #adadadadadad",
"o    s iconGray1     m white c #dededededede",
"O    s iconGray6     m black c #636363636363",
"+    s iconGray2     m white c #bdbdbdbdbdbd",
"@	s iconColor2	m white	c white",
"#    s iconGray3     m white c #adadadadadad",
"$    s iconGray8     m black c #212121212121",
"%    s iconGray5     m black c #737373737373",
"&    s iconGray4     m white c #949494949494",
/* pixels */
"                                          .     ",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXX@@@@@@@@@@@@@@@@@@@XXXXXXXXXXXXXXXXXXo. X#$+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. X%$+",
" XXX@@@@@@@@@@@XXXXXXXXXXXXXXXXXXXXXXXXXXo. X%$+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. X%$+",
" XXX@@@@@@@@@@@@@@@@XXXXXXXXXXXXXXXXXXXXXo. X%$+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. X%$+",
" XXX@@@@@@@@@@@@@@@@@@@@@XXXXXXXXXXXXXXXXo. X%$+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. X%$+",
" XXX@@@@@@@@@XXXXXXXXXXXXXXXXXXXXXXXXXXXXo. X%$+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. X%$+",
" XXX@@@@@@@@@@@@XXXXXXXXXXXXXXXXXXXXXXXXXo.    +",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXX@@@@@@@@@@@@@@@XXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOO+",
" ooooooooooooooooooooooooooooooooooooooooo& OOO+",
".........................................&..++++",
"                                          ......",
" OOOOOOOOOO++++++++++++++++++++$OOOOOOOOOO+.....",
" OOOOOOOOOO+...................$OOOOOOOOOO+.....",
" OOOOOOOOOO$$$$$$$$$$$$$$$$$$$$$OOOOOOOOOO+.....",
" ++++++++++++++++++++++++++++++++++++++++++....."};
