/* XPM */
/* $XConsortium: Dtablnk.t.pm /main/2 1996/07/23 11:58:20 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * AMblnk [] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconGray1	m white	c #e1e1e1e1e1e1",
"X	s iconGray2	m white	c #c8c8c8c8c8c8",
"o	s iconGray6	m black	c #646464646464",
"O	s iconColor2	m white	c white",
"+	s iconGray5	m black	c #7d7d7d7d7d7d",
"@	s selectColor	m white	c #7d7d7d7d7d7d",
"#	s bottomShadowColor	m black	c #646464646464",
"$	s iconGray8	m black	c #323232323232",
/* pixels */
"                ",
"                ",
"  ..XXXXXXXXXo  ",
"  OOOOOOOOOO+o  ",
"  OOOOOOOOOO+o  ",
"  OOOOOOOOOO+o  ",
"  OOOOOOOOOO+o  ",
"  OOOOOOOOOO+o  ",
"  OOOOOOOOOO+o  ",
"  OOOOOOOOOO+o @",
"  OOOOOOOOOO+o@@",
"  OOOOOOOOOO+o@#",
"  OOOOOOOOOO+o#@",
"@@OOOOOOOOOO+o##",
" @OOOOOOOOOO+$#@",
" @@@@@@@@@@o$@@ "};
