/* XPM */
/* $XConsortium: DtMouse.pm /main/3 1995/07/18 16:23:09 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * curvedmouseNew [] = {
/* width height ncolors cpp [x_hot y_hot] */
"44 37 12 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X	s iconColor2	m white	c white",
"o    s iconGray2     m white c #bdbdbdbdbdbd",
"O    s iconGray3     m white c #adadadadadad",
"+    s iconGray4     m white c #949494949494",
"@    s iconGray1     m white c #dededededede",
"#    s topShadowColor m white c #bdbdbdbdbdbd",
"$    s iconGray6     m black c #636363636363",
"%    s iconGray7     m black c #424242424242",
"&    s iconGray5     m black c #737373737373",
"*    s iconGray8     m black c #212121212121",
/* pixels */
"                                            ",
"                                            ",
"                                            ",
"                                            ",
"                                            ",
"                                            ",
"          ..............................    ",
"        ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXX...  ",
"        .X.........oooooooooooooOoOOO+@XX#. ",
"       .XO$@@@@@@@@@oooooooooooOoOOO+O+++X# ",
"       .X.@OOOOOOOO.XoooooooooooOoOOO+O+++@#",
"       .X.@OOOOOOOO%XooooooooooooOoOOO+O++%#",
"       .X.@OOOOOOOO.XoooooooooooOoOOO+O+++.#",
"       .X.@OOOOOOOO.XooooooooooOoOOO+O++++%#",
"       .X.@OOOOOOOO.XoooooooooooOoOOO+O+++%#",
"    ....XO$........XoooooooooooooOoOOO+O++%#",
"   ..o&OXO$@@@@@@@@@ooooooooooooOoOOO+O+++%#",
"....+o&OX.@OOOOOOOO.XooooooooooOoOOO+O++++%#",
"@@@@+o&OX.@OOOOOOOO.XoooooooooooOoOOO+O+++%#",
"$$$$+o&OX.@OOOOOOOO.XooooooooooooOoOOO+O++%#",
"####$o&OX.@OOOOOOOO.XoooooooooooOoOOO+O+++%#",
"    #o$OX.@OOOOOOOO.XooooooooooOoOOO+O++++%#",
"     ##.XO$........XooooooooooooOoOOO+O+++%#",
"       .XO$@@@@@@@@@oooooooooooooOoOOO+O++%#",
"       .X.@OOOOOOOO.XoooooooooooOoOOO+O+++%#",
"       .X.@OOOOOOOO.XooooooooooOoOOO+O++++%#",
"       .X.@OOOOOOOO.XoooooooooooOoOOO+O+++%#",
"       .X.@OOOOOOOO.XooooooooooooOoOOO+O+%%#",
"       .X.@OOOOOOOO.XoooooooooooOoOOO+O++%##",
"       .XO+........XoooooooooooOoOOO+O++%%# ",
"       ..XOXXXXXXXXoooooooooooooOoOOO+%%%## ",
"        .*%%*************************%%###  ",
"         ###############################    ",
"                                            ",
"                                            ",
"                                            ",
"                                            "};
