/* XPM */
/* $XConsortium: Dtdata.m.pm /main/3 1995/07/18 16:33:22 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtdata_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 5 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray7     m black c #424242424242",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXoOOXXOOXOOXooXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXXooOoOOXooXOooXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXooXoOOXoOXoXooOooXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoooXooOXXoOOooXooOOXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoOOXOooXoOOoXXOOXoXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoOOooOoXOooXooOOoooXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXooXoOXOOooXOOOOXooXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXOOXoooXoXXOXOoXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoOOOXoOOXoooXXOOOoXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXOXOOoOOXOOXoOOoXoXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXooXOoXooXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
