/* XPM */
/* $XConsortium: IcMxbdy.t.pm /main/3 1995/07/18 17:13:59 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * IcMxbdy_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray1     m white c #dededededede",
"X    s iconGray3     m white c #adadadadadad",
"o    s iconGray7     m black c #424242424242",
"O	s iconColor2	m white	c white",
"+    s iconGray5     m black c #737373737373",
"@    s iconGray4     m white c #949494949494",
"#    s iconGray6     m black c #636363636363",
"$    s iconGray2     m white c #bdbdbdbdbdbd",
/* pixels */
" .............. ",
".XXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXo",
".OOOOOOOOOOOOOoo",
".O.+.o......@@oo",
".O...ooo@o....oo",
".O...Oo@#oo...oo",
".O...O$$#$oo..oo",
".O..OOOoo+oo..oo",
".OooooO$$Xoooooo",
".XXXXXO$$XoXXXXo",
".XXXXO$$@ooXXXXo",
".XXooo#XoXXXXXXo",
".XXXXXoooXXXXXXo",
" oooooooooooooo "};
