! $XConsortium: Backdrops.src /main/3 1995/12/05 10:11:06 rswiston $
!######################################################################
!#
!#     Backdrops
!#
!#     Common Desktop Environment (CDE)
!#
!#     Backdrop file used for localization of backdrop names
!#
!#     (c) Copyright 1993, 1994 Hewlett-Packard Company
!#     (c) Copyright 1993, 1994 International Business Machines Corp.
!#     (c) Copyright 1993, 1994 Sun Microsystems, Inc.
!#     (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary 
!#	   of Novell, Inc.
!#
!#
!######################################################################
!###
!#
!#   C backdrop names followed by message tags for the translated names 
!#   
!###
Backdrops*Ankh.desc: Ankh
Backdrops*Background.desc: Background
Backdrops*BrickWall.desc: BrickWall
Backdrops*Concave.desc: Concave
Backdrops*Convex.desc: Convex
Backdrops*Corduroy.desc: Corduroy
Backdrops*Crochet.desc: Crochet
Backdrops*Foreground.desc: Foreground
Backdrops*InlayColor.desc: InlayColor
Backdrops*InlayPlain.desc: InlayPlain
Backdrops*KnitLight.desc: KnitLight
Backdrops*Lattice.desc: Lattice
Backdrops*LatticeBig.desc: LatticeBig
Backdrops*Leaves.desc: Leaves
Backdrops*NoBackdrop.desc: NoBackdrop
Backdrops*OldChars.desc: OldChars
Backdrops*Paver.desc: Paver
Backdrops*Pebbles.desc: Pebbles
Backdrops*PinStripe.desc: PinStripe
Backdrops*RakedSand.desc: RakedSand
Backdrops*RicePaper.desc: RicePaper
Backdrops*SkyDark.desc: SkyDark
Backdrops*SkyLight.desc: SkyLight
Backdrops*Sprinkles.desc: Sprinkles
Backdrops*Toronto.desc: Toronto
Backdrops*WaterDrops.desc: WaterDrops
Backdrops*Wooly.desc: Wooly
