/* XPM */
/* $XConsortium: DtABitm.pm /main/3 1995/07/18 16:13:43 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * items_s_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"28 20 11 1 0 0",
/* colors */
"     s iconGray4     m white c #949494949494",
".    s iconGray1     m white c #dededededede",
"X    s iconGray3     m white c #adadadadadad",
"o	s iconColor1	m black	c black",
"O	s iconColor6	m white	c yellow",
"+	s iconColor7	m white	c cyan",
"@	s iconColor2	m white	c white",
"#	s iconColor4	m white	c green",
"$	s iconColor5	m black	c blue",
"%	s iconColor8	m black	c magenta",
"&	s iconColor3	m black	c red",
/* pixels */
"                            ",
"                            ",
"                            ",
"                            ",
"............................",
".XXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XO+@@@oXXXXXXXXXXXXXXXXXXXo",
".X#O+@@@XXooXXXXXXXoXXXXXXXo",
".X$#O+@@XXoXXXXooXXoXXXXXXXo",
".X%$#O+@XXoXXoXoXoXoXoXXXXXo",
".X&%$#O+XXoXXoXoXoXoXooXXXXo",
".X&&%$#OXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXo",
".ooooooooooooooooooooooooooo",
"                            ",
"                            ",
"                            ",
"                            ",
"                            ",
"                            "};
