/* XPM */
/* $XConsortium: Dtview.m.pm /main/2 1996/07/23 12:24:30 drk $ */
static char * Dtview2_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 8 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconGray3	m white	c #adadadadadad",
"o	s iconGray4	m white	c #949494949494",
"O	s iconGray5	m black	c #737373737373",
"+	s iconColor1	m black	c black",
"@	s iconGray6	m black	c #636363636363",
"#	s iconGray2	m white	c #bdbdbdbdbdbd",
/* pixels */
"                                ",
"                                ",
" ..............   ..............",
" .XoOoOoOoOoOo+   .oOoOoOoOoOo@+",
" .XOoOoOoOoOo@+   .ooOoOoOoOoO@+",
" .XoOoOoOoOoOo+   .oOoOoOoOoOo@+",
" .XOoOoOoOoOo@+   .ooOoOoOoOoO@+",
"  .###########+   .###########+ ",
"  .X@@@@@@@@@@+   .o@@@@@@@@@@+ ",
"  .XOoOoOoOoO@+   .oOoOoOoOoO@+ ",
"  .XoOoOoOoOo@.....ooOoOoOoOo@+ ",
"  .XOoOoOoOoO@ooooooOoOoOoOoO@+ ",
"  .XoOoOoOoOoOOOOOoOoOoOoOoOo@+ ",
"  .XOoOoOoOoOO++++OoOoOoOoOoO@+ ",
"  .XoOoOoOoOoO+###oOoOoOoOoOo@+ ",
"  .XOoOoOoOoOO+###OoOoOoOoOoO@+ ",
"  .XoOoOoOoOoO+###oOoOoOoOoOo@+ ",
"   .XoOoOoOoOoOoOoOoOoOoOoOo@+  ",
"   .XOoOoOoOo@o@o@o@oOoOoOoO@+  ",
"   .XoOoOoOo@++++++.XoOoOoOo@+  ",
"   .XOoOoOoO@+     .XOoOoOoO@+  ",
"   .XoOoOoOo@+     .XoOoOoOo@+  ",
"   .XOoOoOoO@+     .XOoOoOoO@+  ",
"   .XoOoOoOo@+     .XoOoOoOo@+  ",
"   .XOoOoOo@+       .XoOoOoO@+  ",
"   .XoOoOoO@+       .XOoOoOo@+  ",
"   ..#######+       .#######+   ",
"    .X@@@@@@+       .X@@@@@@+   ",
"    .XoOoOo@+       .XoOoOo@+   ",
"    .XOoOoO@+       .X@o@o@o+   ",
"    +++++++++       +++++++++   ",
"                                "};
