/* XPM */
/* $XConsortium: Dtaexbx.t.pm /main/2 1996/07/23 11:59:27 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * Dtaexbx [] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 12 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor5	m black	c blue",
"X	s iconGray3	m white	c #afafafafafaf",
"o	s iconGray6	m black	c #646464646464",
"O	s iconColor3	m black	c red",
"+	s iconColor2	m white	c white",
"@	s iconGray5	m black	c #7d7d7d7d7d7d",
"#	s iconColor1	m black	c black",
"$	s iconGray7	m black	c #4b4b4b4b4b4b",
"%	s selectColor	m white	c #7d7d7d7d7d7d",
"&	s bottomShadowColor	m black	c #646464646464",
"*	s iconColor6	m white	c yellow",
/* pixels */
"                ",
"   ......XXXXo  ",
"  OOOOOOOOOOoo  ",
"  .++.OOOOOO@o  ",
"  ..+.##$$OO@o  ",
"  ..+.$#$$$$@o  ",
"  ..+.#O#O##@o  ",
"  ..+.OOOOOOOo  ",
"  .+..OOOOOOOo% ",
"  ....OOOOOOOo%%",
"  ..+.OOOOOOOo&%",
"  ....**O***Oo&&",
"  ..+.OOOOOOOo&&",
" %....*O****Oo&%",
"%%....OOOOOOO&%%",
"  % %%%%&%&%%%%%"};
