/* XPM */
/* $XConsortium: DtMail.m.pm /main/3 1995/07/18 16:21:47 drk $ */
static char * DtMail_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 11 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray2     m white c #bdbdbdbdbdbd",
"X    s iconGray1     m white c #dededededede",
"o    s iconGray5     m black c #737373737373",
"O    s iconGray3     m white c #adadadadadad",
"+    s iconGray6     m black c #636363636363",
"@	s iconColor2	m white	c white",
"#    s iconGray4     m white c #949494949494",
"$	s iconColor3	m black	c red",
"%	s iconColor4	m white	c green",
"&    s iconGray7     m black c #424242424242",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"   .XXXXXXXXXXX.X.X.......o     ",
"   XOOOOOOOOOOoOoooooo+o+o+     ",
"  XXXXXXXXXXXX.X.X.........o    ",
"  XOOOOOOOOOoOooooooo+o+o+o+    ",
" O@@@@@@@@@@@@@@@@@@@@@@@@@@+   ",
" O@##X##XXXXXXXXXX#$#X$XX%.X+   ",
" O@XXXXXXXXXXXXXXXXXX$X#X.%X+   ",
"O#@###X#XXXXXXXXXX#$#X$XX%.X+#  ",
"O#@XXXXXXXXXXXXXXXXXXXXXXX.X+#  ",
"X#@XXXXXXXXXXXXXXXXXXXXXXXXX+#  ",
"@#@XXXXXXXXXXXXXXXXXXXXX.X.X+O  ",
"@#@XXXXXXXXXXXXXXXXXXXXXXXX.+O  ",
"@#@XXXXXXXXXXXXXXXXXXXXX.X.#oO  ",
"@#@.....XX#####X#####X.OO###oO  ",
"@XXXXXXo...XXXXXXXXXXXO.XXXXX.  ",
"@@..OO##oOoo#X###X###OXX###++&  ",
"@..OO###oO..XXXXXXXXXOX#####+&  ",
"@@..OO##oOO..........OX####++&  ",
"@..OO####XXXXXXXXXXXXX######+&  ",
"@@..OO#####################++&  ",
"@..OO#######################+&  ",
"@@..OO#####################++&  ",
" +++++++++++++++++++++++++++&   "};
