/* XPM */
/* $XConsortium: Dtmail.m.pm /main/2 1996/07/23 12:17:26 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * mail32 [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 8 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconGray1	m white	c #e1e1e1e1e1e1",
"o	s iconColor1	m black	c black",
"O	s iconGray8	m black	c #323232323232",
"+	s iconColor5	m black	c blue",
"@	s iconGray6	m black	c #646464646464",
"#	s iconGray7	m black	c #4b4b4b4b4b4b",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"  ............................  ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXo  ",
"  .XOOXOOXXXXXXXXXXXXXXXX+@+Xo  ",
"  .XXXXXXXXXXXXXXXXXXXXXX@+@Xo  ",
"  .XXXXXXXXXXXXXXXXXXXXXX+@+Xo  ",
"  .XXXXXXXXXXXXXXXXXXXXXX@+@Xo  ",
"  .XXXXXXXXXXXXO##OO@OOXXXXXXo  ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXo  ",
"  .XXXXXXXXXXXXOOXOOOO@OXXXXXo  ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXo  ",
"  .XXXXXXXXXXXXOOOOXO@XXXXXXXo  ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXo  ",
"  .ooooooooooooooooooooooooooo  ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                "};
