/* XPM */
/* $XConsortium: DtMnew.m.pm /main/3 1995/07/18 17:09:13 drk $ */
static char * DtMnew_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 11 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray1     m white c #dededededede",
"o    s iconGray7     m black c #424242424242",
"O	s iconColor4	m white	c green",
"+    s iconGray5     m black c #737373737373",
"@	s iconColor3	m black	c red",
"#    s iconGray3     m white c #adadadadadad",
"$    s iconGray4     m white c #949494949494",
"%    s iconGray2     m white c #bdbdbdbdbdbd",
"&    s iconGray6     m black c #636363636363",
/* pixels */
"                                ",
"                                ",
"                                ",
"                   .            ",
"                  .Xo           ",
"                 .XOXo          ",
"                .XO+OXo         ",
"               .X+XOXXXo        ",
"              .X@X+XXXXXo       ",
"   XXXXXXXXXX.X+X@XXXXXXXo+     ",
"   X########.X@X+XXXXXXXXXo     ",
"  XXXXXXXXX.XXX@XXXXXXXXXXXo    ",
"  X#######.XXXXXXXXXXXXXXXXXo   ",
" $XXXXXXX.XXXXXXXXXXXXXXXXXXXo  ",
" $X%%%%%.XXXXXXXXXXXXXXXXXX%+   ",
" $X%%%%.XXXXXXXXXXXXXXXXXX%+&   ",
"#$X%%%.XXXXXXXXXXXXXXXXXX%+%&+  ",
"#$X%%.X$XXXXXXXXXXXXXXXX%+%#&+  ",
"#$X%.X$X$XXXXXXX+XXXXXX%+%#%&+  ",
"%$X.XXX$XXXXXXX+X$XXXX%+%#%#&$  ",
"%$.X$XXXXXXXXXXXXXXXX%+%#%#%&$  ",
".+XXX$XXXXXXX+X$XXXX%+%#%#%#&#  ",
".$+%%%%XXXXX+X$XXXX%+%#%#%#%&#  ",
".XXXXXX+XXXXXXXXXX%+XX#%XXXXX%  ",
"..%%##$$+XXXXXXXX%+$$#XX$$$&&o  ",
".%%##$$$+#XXXXXX%+XXX#X$$$$$&o  ",
"..%%##$$+##%XXX%+%%%%#X$$$$&&o  ",
".%%##$$$$XXXXXXXXXXXXX$$$$$$&o  ",
"..%%##$$$$$$$$$$$$$$$$$$$$$&&o  ",
".%%##$$$$$$$$$$$$$$$$$$$$$$$&o  ",
"..%%##$$$$$$$$$$$$$$$$$$$$$&&o  ",
" &&&&&&&&&&&&&&&&&&&&&&&&&&&o   "};
