/* XPM */
/* $XConsortium: Dtdt.m.pm /main/3 1995/07/18 16:36:48 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtdt_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 8 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray8     m black c #212121212121",
"+    s iconGray4     m white c #949494949494",
"@    s iconGray6     m black c #636363636363",
"#    s iconGray7     m black c #424242424242",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXO++@OX@+@XXXXXXXXXXXXo.......",
" XX@O@O@XOOOXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXooo#XXXXo##X#oXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXX#ooXXXXXo#X##oXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXooo#XXXXo###XXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXX#ooXXXXXoX###oXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXX##XoXXXX#oXoXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXooo#XXXXoX#X#oXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXX#ooXXXXXo###XoXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXX##XoXXXX#oXooXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XX@+@XXXXXXXXXXXXXXXXXXo.......",
" XXOOO@XXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
