/* XPM */
/* $XConsortium: Dthsrc.m.pm /main/3 1995/07/18 17:11:02 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dthsrc_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 7 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray7     m black c #424242424242",
"+    s iconGray6     m black c #636363636363",
"@	s iconColor6	m white	c yellow",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXoOOXXOOXOOXooXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXXoX++X++XoXOooXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXooXoX@@@@@@@X+XooXXXXo.......",
" XXXXXX@@@@@@@@@XXXXXXXXo.......",
" XXoooX@@@XXo@@@++ooOOXXo.......",
" XXXXXX@@@XXX@@@XXXXXXXXo.......",
" XXoOOX+++XoO@@@XXOXoXXXo.......",
" XXXXXXXXXXX@@@XXXXXXXXXo.......",
" XXoOOooOoX@@@+XXOOoooXXo.......",
" XXXXXXXXX@@@XXXXXXXXXXXo.......",
" XXooXoOXO@@@+XOOOXooXXXo.......",
" XXXXXXXXX@@@XXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXOOXoooXoXXOXOoXXXo.......",
" XXXXXXXXX@@@XXXXXXXXXXXo.......",
" XXoOOOXoO@@@XoXXOOOoXXXo.......",
" XXXXXXXXX@@@XXXXXXXXXXXo.......",
" XXOXOOoOOXXXXoOOoXoXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXooXOoXooXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
