/* XPM */
/* $XConsortium: mdticon.pm /main/7 1996/10/29 16:03:29 drk $ */
static char * mdticon_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"110 165 18 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	c #B3B3CECED9D9",
"X	s iconColor1	m black	c black",
"o	c #2A2A49495555",
"O	c #55559292AAAA",
"+	s iconColor5	m black	c blue",
"@	c #323232323232",
"#	c #7D7D7D7D7D7D",
"$	c #C8C8C8C8C8C8",
"%	c #E1E1E1E1E1E1",
"&	c #646464646464",
"*	c #4B4B4B4B4B4B",
"=	c #AFAFAFAFAFAF",
"-	s iconColor6	m white	c yellow",
";	c #969696969696",
":	c #48487C7C9191",
">	s iconColor7	m white	c cyan",
",	s iconColor3	m black	c red",
/* pixels */
"                                                                                                              ",
"....................................X                                                                         ",
"...................................oX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOO  ++++++++@@OOOOoX                                                                         ",
"..OOOO              ++++++++++@@OOOoX                                                                         ",
"..OOOO##########################@OOoX                                                                         ",
"..OO                          @#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                                         ",
"..OO #########################@@@OOoX                                                                         ",
"..OOO@@@@@@@@@@@@@@@@@@@@@@@@@@@OOOoX                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOO   OOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOO OO OO O OOO  OOO OO OOO  OOOOoo                                                                         ",
"..OOO OO OO   OO OO OO OO OOOOO OOOoo                                                                         ",
"..OOO   OOO OOOO OO OO OO OOO   OOOoo                                                                         ",
"..OOO OOOOO OOOO OO OO OO OO OO OOOoo                                                                         ",
"..OOO OOOOO OOOO OO OOO  OOO OO OOOoo                                                                         ",
"..OOO OOOOO OOOOO  OOOO  OOOO  O OOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
".oooooooooooooooooooooooooooooooooooo                                                                         ",
"ooooooooooooooooooooooooooooooooooooo                                                                         ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"....................................o                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOOO                    OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%X%X&%X%&X&%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%&XX%&%@%X&%&X%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%X%&X%X#X#%%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%*X#%%%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%*= ==%%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%* -==%%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%*&%-==%%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%*=%-==%%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%=&=%-==%@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%=*&=%-==@OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%=*&=%-=$OOOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%==*&=%-=$OOOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%==*&=%-=$OOOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%==*&=%-=OOOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%==*&=%-$OOOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%==*&=%*$OOOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%%=@**&%;*OOOoo                                                                         ",
"..OOOO%%%%%%%%%%%%%%%%%%%@:**%;*OOOoo                                                                         ",
"..OOOO@@@@@@@@@@@@@@@@@@@@::*;**:OOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOO::**::OOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOO:::::OOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOO:::OOOooOOOOOOOOO                                                                ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOO::OOOOo..........                                                                ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..........o                                                                ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                ",
"..OOOOOOOOOOOO OOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                ",
"..OOO  OOO  OOOOOOOOOOOOO OOOOOOOOO OOOOOOOOoo                                                                ",
"..OOO  OOO  OO OOO  OOOO    O OO O    OOOOOOoo                                                                ",
"..OOO O O O OO OO OO OOOO OOO OO OO OOOOOOOOoo                                                                ",
"..OOO O   O OO OO OO OOOO OOOO  OOO OOOOOOOOoo                                                                ",
"..OOO OO OO OO OO OO OOOO OOOO  OOO OOOOOOOOoo                                                                ",
"..OOO OO OO OO OO OO OO O OOO OO OO OOOOOOOOoo                                                                ",
"..OOO OOOOO OO OOO  OOO OO  O OO OOO  OOOOOOoo                                                                ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                ",
".ooooooooooooooooooooooooooooooooooooooooooooo                                                                ",
"oooooooooooooooooooooooooooooooooooooooooooooo                                                                ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"....................................o                                                                         ",
"...................................oo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                                         ",
"..OOO +++++++++++++++++++++++++XOOOoo                                                                         ",
"..OOO +++++++++++++++++++++++++XOOOoo                                                                         ",
"..OO     ++++++++++++++++++     XOOoo                                                                         ",
"..OO ;;;; ++++++++++++++++ ;;;;;XOOoo                                                                         ",
"..OO ;;;;; ++++++++++X+++ ;;;;;;XOOoo                                                                         ",
"..OO ;;;;;;         X;*  ;;;;;;;XOOoo                                                                         ",
"..OO ;;; %;;;;;;;;;X-%=*;;;;;;;;XOOoo                                                                         ",
"..OO ;;$X %;;;;;;;X%&-%=*;;;;;;;XOOoo                                                                         ",
"..OO ;;X$X %;;;;;;@&;&-%=*;;;;;;XOOoo                                                                         ",
"..OO ;;XX$X %;;;;;*@&;&-%=*;;;;;XOOoo                                                                         ",
"..OO ;;&XX$XX;;;;;;*@&;&-%=*;;;;XOOoo                                                                         ",
"..OO ;;;;&&X;* ;;;;*&%$&=&-%=;;;XOOoo                                                                         ",
"..OO ;;;;;;&X;* ;;*&%$#@&=&-%*;;XOOoo                                                                         ",
"..OO ;;;;;;;&X;* ;&%$#@**&;&-*;;XOOoo                                                                         ",
"..OO ;;;;;;;;&X;*+%$#@*;**&%X;;;XOOoo                                                                         ",
"..OO ;;;;;;;;;&X+>&+@*;;;*@X*;;;XOOoo                                                                         ",
"..OO ;;;;;;;;;;+>=+@*;;;;;**;;;;XOOoo                                                                         ",
"..OO ;;;;;;;;;+>+#@*&;;;;;;;;;;;XOOoo                                                                         ",
"..OO ;;;;;;;;+>=#+*@&&@;;;;;;;;;XOOoo                                                                         ",
"..OO ;;;;;;;+>+#+@@#,-%@;;;;;;;;XOOoo                                                                         ",
"..OO ;;;;;;+>=#+@*@,-,-%@;;;;;;;XOOoo                                                                         ",
"..OO ;;;;;+>+#+@*;@*,-,-%@;;;;;;XOOoo                                                                         ",
"..OO ;;;;+>=#+@*;;&@*,-,-%@;;;;;XOOoo                                                                         ",
"..OO ;;++=#+@*;;;;;;&@*,-,-@&;;;XOOoo                                                                         ",
"..OO ;;++++@*;;;;;;;;&@*,-,@&;;;XOOoo                                                                         ",
"..OO ;;@@@@*;;;;;;;;;;&@*@@&&;;;XOOoo                                                                         ",
"..OO ;;;***;;;;;;;;;;;;&&&&;;;;;XOOoo                                                                         ",
"..OO ;;;;;;;;;;;;;;;;;;;;;;;;;;;XOOooOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO    ",
"..OOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXOOo......................................................................    ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO......................................................................o    ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo    ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo    ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo    ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO OOOOOOOOOOOO OOOOOOOOOOOOO OOOOOOOOOOOOOOOOOOOOOOOOOOoo    ",
"..OOO   OO OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO OOOOOOOOOOOOOOOO OOOOOOOOOOOOO OOOOO OOOOOOOOOOOOOOOOOOOOoo    ",
"..OO OOOO    O O OO OO OO O OO OOOO  OOO O OO    O OOOOOOOOOO   OOO  OOOO  OO OO O    OO  OOO O OOOOOOOOoX    ",
"..OO OOOOO OOO   OO OO OO  O  O OO OO OO  O OO OOO OOOOOOOOO OO OO OO OO OOOO O OOO OOO OO OO  O OOOOOOOXo    ",
"..OOO  OOO OOO OOOO OO OO OO OO OO    OO OO OO OOO OOOOOOOOO OO OO    OO  OOO  OOOO OOO OO OO OO OOOOOOOXo    ",
"..OOOOO OO OOO OOOO OO OO OO OO OO OOOOO OO OO OOO OOOOOOOOO OO OO OOOOOO  OO O OOO OOO OO OO OO OOOOOOOXo    ",
"..OOOOO OO OOO OOOO O  OO OO OO OO OOOOO OO OO OOO OOOOOOOOO O  OO OOOOOOO OO OO OO OOO OO OO OO OOOOOOOXX    ",
"..OO   OOOO  O OOOOO O OO OO OO OOO   OO OO OOO  O OOOOOOOOOO O OOO   OO  OOO OOO OO  OO  OOO   OOOOOOOOoX    ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO     OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO OOOOOOOOOOoo    ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO OOOOOOOOOOoo    ",
".ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo    ",
"oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo    ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              ",
"                                                                                                              "};
