/* XPM */
/* $XConsortium: Dtcmprs.m.pm /main/3 1995/07/18 17:10:01 drk $ */
static char * Dtcmprs_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 12 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray5     m black c #737373737373",
"+    s iconGray6     m black c #636363636363",
"@    s iconGray7     m black c #424242424242",
"#    s iconGray8     m black c #212121212121",
"$    s iconGray3     m white c #adadadadadad",
"%    s iconGray1     m white c #dededededede",
"&	s iconColor5	m black	c blue",
"*    s iconGray4     m white c #949494949494",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXOOOOOOOOOOOXXXXXXo.......",
" XXXXXXXOOOOOOOOOXXXXXXXo.......",
" XXXXXXXX+++++++XXXXXXXXo.......",
" XXXXXXXXX@@@@@XXXXXXXXXo.......",
" XXXXXXXXXX###XXXXXXXXXXo.......",
" XXXXXXXXXXX#XXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXo$ooo$oooXXXXXXXo.......",
" XXOXXXXXXXXXXXXXXXXXOXXo.......",
" XXOOXXXooXooo$oXXXXOOXXo.......",
" XXOO+XXXXXXXXXXXXX+OOXXo.......",
" XXOO+@XXooooOooXX@+OOXXo.......",
" XXOO+@#XXXXXXXXX#@+OOXXo.......",
" XXOO+@XXoOooOooXX@+OOXXo.......",
" XXOO+XXXXXXXXXXXXX+O%%%%%%%%%%%",
" XXOOXXXX@@$ooOooXXXO%@@&@&@&@&o",
" XXOXXXXXXXXXXXXXXXXX%@&@&    @o",
" XXXXXXX@@$oo$oooXXXX%&@&@&@& &o",
" XXXXXXXXXXXXXXXXXXXX%@&@&@& &@o",
" XXXXXXXXXXX#XXXXXXXX%&@&@&@ @&o",
" XXXXXXXXXX###XXXXXXX%@&@&@ @&@o",
" XXXXXXXXX@@@@@XXXXXX%&@&@ @&@&o",
" XXXXXXXX+++++++XXXXX%@ @&    @o",
" XXXXXXXOOOOOOOOOXXXX%&@&@&@&@&o",
" XXXXXXOOOOOOOOOOOXXX%oooooooooo",
" XXXXXXXXXXXXXXXXXXXXX***.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
