/* XPM */
static char *gscan2pdf_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #262B2D",
".  c #2B2F30",
"X  c #2D3335",
"o  c #323635",
"O  c #373836",
"+  c #313739",
"@  c #34393B",
"#  c #3A3E3D",
"$  c #42423F",
"%  c #393E40",
"&  c #353C44",
"*  c #3E4343",
"=  c #374D69",
"-  c #3A516D",
";  c #254875",
":  c #294C77",
">  c #324F76",
",  c #304F7B",
"<  c #32517A",
"1  c #3C5676",
"2  c #414645",
"3  c #474945",
"4  c #494A47",
"5  c #45494A",
"6  c #4B4D4A",
"7  c #4E504D",
"8  c #50524E",
"9  c #474F57",
"0  c #4E5252",
"q  c #4C545B",
"w  c #555753",
"e  c #565854",
"r  c #595B55",
"t  c #555959",
"y  c #5B5D5A",
"u  c #5F6053",
"i  c #5E605D",
"p  c #606051",
"a  c #6D6C52",
"s  c #61625E",
"d  c #787652",
"f  c #7B7852",
"g  c #445363",
"h  c #4B5967",
"j  c #4C5B6D",
"k  c #42556D",
"l  c #4B5C71",
"z  c #5F6260",
"x  c #59626D",
"c  c #526070",
"v  c #58677A",
"b  c #5C6979",
"n  c #5B6672",
"m  c #636562",
"M  c #666966",
"N  c #696B67",
"B  c #696C69",
"V  c #6E726B",
"C  c #71726E",
"Z  c #74796F",
"A  c #606C74",
"S  c #6E767C",
"D  c #747572",
"F  c #777875",
"G  c #797B76",
"H  c #70777E",
"J  c #71787E",
"K  c #7C7D7A",
"L  c #F03312",
"P  c #DE3D26",
"I  c #E53D22",
"U  c #D7422E",
"Y  c #DC4732",
"T  c #D04F3F",
"R  c #E94226",
"E  c #F24628",
"W  c #F6492A",
"Q  c #E35138",
"!  c #E7583F",
"~  c #F75134",
"^  c #F25238",
"/  c #827E53",
"(  c #DE5440",
")  c #D75B47",
"_  c #DF5B47",
"`  c #E95B43",
"'  c #E15C47",
"]  c #DE6753",
"[  c #ED6149",
"{  c #F46045",
"}  c #E46E5B",
"|  c #EA725E",
" . c #F6735C",
".. c #DA7866",
"X. c #DF7E6E",
"o. c #CD7A70",
"O. c #DA7D70",
"+. c #E07B69",
"@. c #EC7C69",
"#. c #7F817D",
"$. c #97915A",
"%. c #ABA35E",
"&. c #81827E",
"*. c #869B7E",
"=. c #B3AB61",
"-. c #DE8273",
";. c #DB877B",
":. c #D38B7F",
">. c #EF8673",
",. c #E48373",
"<. c #C6BD6B",
"1. c #D4CA75",
"2. c #2A5185",
"3. c #28528C",
"4. c #335686",
"5. c #365988",
"6. c #3C5E8C",
"7. c #295592",
"8. c #2B5892",
"9. c #2E5D9C",
"0. c #3E608F",
"q. c #3D6893",
"w. c #32619F",
"e. c #3364A3",
"r. c #3866A3",
"t. c #3D6AA4",
"y. c #3768A8",
"u. c #3E6CA8",
"i. c #425D80",
"p. c #405F88",
"a. c #42628E",
"s. c #496A89",
"d. c #4D6584",
"f. c #536A87",
"g. c #426391",
"h. c #526F98",
"j. c #577297",
"k. c #527996",
"l. c #597E98",
"z. c #416DA7",
"x. c #406FAB",
"c. c #4871A5",
"v. c #4672A9",
"b. c #4B75AB",
"n. c #527BAE",
"m. c #5C7DAA",
"M. c #547DB1",
"N. c #597FB0",
"B. c #628288",
"V. c #7F9780",
"C. c #62859D",
"Z. c #5D81AD",
"A. c #5D83B4",
"S. c #6789A1",
"D. c #6D8DA4",
"F. c #6182AA",
"G. c #718EA2",
"H. c #7291A6",
"J. c #7493A8",
"K. c #678CBA",
"L. c #6C8EB9",
"P. c #7392B7",
"I. c #7394BF",
"U. c #7697C0",
"Y. c #7A99C0",
"T. c #848582",
"R. c #878984",
"E. c #8A8B86",
"W. c #8D8D8C",
"Q. c #889D80",
"!. c #8F908C",
"~. c #91938E",
"^. c #869E99",
"/. c #949692",
"(. c #979893",
"). c #999B96",
"_. c #9C9D9B",
"`. c #8FA287",
"'. c #95A68D",
"]. c #96A88E",
"[. c #9AAB92",
"{. c #9FA19D",
"}. c #A1A29F",
"|. c #A1B091",
" X c #A6B598",
".X c #ACB89D",
"XX c #A9B59D",
"oX c #959AA0",
"OX c #9B9EA2",
"+X c #9DA0A4",
"@X c #A3A5A1",
"#X c #A7A8A5",
"$X c #A8AAA6",
"%X c #ADADAC",
"&X c #AEBAA1",
"*X c #B0BCA3",
"=X c #B6B6B6",
"-X c #BBBBBB",
";X c #DF8C81",
":X c #CC938C",
">X c #DE9385",
",X c #D99489",
"<X c #CF9891",
"1X c #D59A90",
"2X c #D99992",
"3X c #E19387",
"4X c #E9998D",
"5X c #E99688",
"6X c #EA9F92",
"7X c #D8ACA7",
"8X c #DEAFAA",
"9X c #CAB1AE",
"0X c #D3B2AD",
"qX c #DAB0AB",
"wX c #D1BCB9",
"eX c #DBBCB6",
"rX c #EEBBB2",
"tX c #E1BEB8",
"yX c #F1BEB4",
"uX c #F0C5BE",
"iX c #BFCDD9",
"pX c #C4C4C4",
"aX c #CBCBCB",
"sX c #D6C5C4",
"dX c #D6CAC8",
"fX c #DBC9C6",
"gX c #C7D0D5",
"hX c #C9D4DB",
"jX c #CFD8DE",
"kX c #D3D3D3",
"lX c #D7D7D8",
"zX c #D0D9DF",
"xX c #DDDDDD",
"cX c #EFC8C1",
"vX c #E3C6C3",
"bX c #EDD2CD",
"nX c #F0D2CD",
"mX c #EAD7D4",
"MX c #ECDAD7",
"NX c #E0DFDE",
"BX c #EEDCD9",
"VX c #E1D3D1",
"CX c #F4D9D4",
"ZX c #DFE1E1",
"AX c #E4E4E4",
"SX c #EDE6E5",
"DX c #E6E9EA",
"FX c #EBEBEB",
"GX c #F0EAE9",
"HX c #F3E3E0",
"JX c #EFEFF0",
"KX c #EEF1F1",
"LX c #F3F3F3",
"PX c #F5F8F8",
"IX c #FAFAFA",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUX# 7 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 7 7 7 7 7 7 7 6 6 $ UXUXUXUXUXUXUXUX",
"UXUXUXw @X$X$X$X$X$X$X$X#X#X#X#X$X$X$X$X$X$X$X$X$X$X#X#X#X@X@X@X}._._.{._.).(.e o UXUXUXUXUXUXUX",
"UXUXUX6 E.@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X}.@X@X}.{.{._.).).(.(.(.~.~.!.&.4 UXUXUXUXUXUXUXUX",
"UXUXUXUX7 E.).)./.).)./.).)._._._._.(._.(.).).).).).).~.~.~.!.E.E.E.R.T.T.G 6 o UXUXUXUXUXUXUXUX",
"UXUXUXT.M T.(.(._././._././././.(.(.~.T./._.).).).(.(.~.~.!.!.E.R.R.R.T.#.e O UXUXUXUXUXUXUXUXUX",
"R.lXZXZXNXNXNXxXxXxXxXxXlXlXlXlXlXlXlX%XT.).).(././.~.~.!.!.E.E.R.R.&.&.s # UXUXUXUXUXUXUXkXUXUX",
"W.IXIXIXIXIXIXIXIXPXPXLXPXPXPXLXKXKXLXaXG /.).(.(.~.~.!.!.E.E.R.R.R.&.N $ UXUXUXUXUXUXUXUXkXUXUX",
"~.IXIXIXIXPXIXIXPXLXLXCXrXBXJXJXGXJXGXaXG ~.(./.~.~.!.W.E.E.R.R.&.&.C 3 UXUXUXUXUXUXUXUXUXpXUXUX",
"W.IXIXIXPXIXLXLXLXLXHX .E 6XKXJXGXFXGXaXF ~.(./.~.~.!.!.E.E.R.&.&.G 6 o UXUXUXUXUXUXUXUXUX-XUXUX",
"E.IXIXIXLXPXLXLXLXPXuXW L 4XKXFXFXFXFXaXB K T.&.&.&.K G G F Z D C w o UXUXUXUXUXUXUXUXUXUX=XUXUX",
"R.IXPXPXIXLXLXLXLXLXnX~ I eXJXFXFXDXFXpXw 3 6 4 4 4 4 4 4 6 8 6 3 6 5 * UXUXUXUXUXUXUXUXUX%XUXUX",
"T.IXPXPXLXLXLXLXLXJXGX{ ` NXJXFXFXDXFXpXw 6 8 8 8 8 8 8 8 8 w 8 8 i y 9 E.W.W.UXUXUXUXUXUX$XUXUX",
"T.IXPXLXLXLXLXLXJXJXCX^ ` NXFXFXSXDXDXpX0 0 q q q q q q q q q q q y B 5 UXUXW.~.UXUXUXUXoXUXUXUX",
"&.IXLXLXLXLXKXKXJXKX6XP I qXFXDXDXDXDXpXj p.g.a.6.6.6.5.5.5.5.4., t B 6 UXUXUXW.~.UXUXUX/.UXUXUX",
"#.PXLXLXLXLXKXKXKXmX_ o.U -.AXDXAXAXSXpXv m.A.m.M.n.b.b.b.v.z.r.3.g N t + UXUXUXW.W.UXW.UXUXUXUX",
"K PXLXLXJXJXKXGXGX4XT dX;XY vXAXSXAXAX-Xv m.A.A.Z.M.M.n.n.v.t.r.8.- i N # UXUXUXUX~.~.UXUXUXUXUX",
"K LXJXLXJXJXFXKXbX( <XDXvXY ;.AXAXAXDX-XA G.J.H.D.D.D.S.C.l.k.k.q.< t B * UXUXUXUXUXUXUXUXUXUXUX",
"K LXJXJXJXKXGXSX@.) 7X8X2X_ I | 5XtXAX-XV ].[.[.].].].`.Q.*.*.Q.B.1 q N w UXUXUXUXUXUXUXUXUXUXUX",
"K LXJXLXSXnXrX>.' ] O.:X9XwX} R Q :.NX-XZ XX*X*X&X&X X|.[.|.[.[.^.s.h m z + UXUXUXUXUXUXUXUXUXUX",
"F LXGXuX4X>X| ` 0XZXAXAXAXAXVX>X,XdXAX-XT.gXzXzXjXhXhXhXhXhXhXhXiXm.- y B * UXUXUXUXUXUXUXUXUXUX",
"D LXuX[ X.-...0XAXDXAXAXAXAXAXAXZXZXZX=Xb P.U.K.A.A.A.A.A.A.A.A.A.t., t B 6 UXUXUXUXUXUXUXUXUXUX",
"D LXMXX.X.2XdXAXAXAXAXAXAXAXAXxXZXxXAX=Xl c.u.e.e.e.e.e.e.e.e.e.e.9.2.q N t + UXUXUXUXUXUXUXUXUX",
"D JXFXFXSXDXAXFXSXAXAXAXZXAXNXNXxXxXxX=Xk e.e.e.e.e.e.e.e.e.e.e.e.e.7.g s m % UXUXUXUXUXUXUXUXUX",
"B FXFXSXSXSXFXAXAXAXAXAXNXAXxXZXxXxXZX%X= w.e.e.e.e.e.y.e.e.e.e.e.e.7.- t B 2 UXUXUXUXUXUXUXUXUX",
"UXW.+XoXoX_.oXOX+XOXOX+X+XOXOXoXoXoXoXx : e.y.e.y.e.e.e.e.e.e.e.e.e.9., t B 8 UXUXUXUXUXUXUXUXUX",
"UXUXUX. 6 2 & - f.f.f.f.d.i., : : ; ; 2.w.e.e.e.e.e.e.e.y.y.e.e.r.e.w.3.q m z @ UXUXUXUXUXUXUXUX",
"UXUXUX6 V t h m.Y.I.I.K.M.u.y.e.r.y.y.e.e.e.e.e.y.e.e.e.e.e.y.e.e.e.e.3.g y B % UXUXUXUXUXUXUXUX",
"UXUX@ t N w j m.L.A.b.r.e.e.e.e.9.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.w.w.8.- t V 6 UXUXUXUXUXUXUXUX",
"UXUX% B C m n j.h.g.6.0.0.6.0.0.0.0.6.6.0.0.5.0.0.5.0.0.5.0.6.5.0.6.6.6.c y B t X UXUXUXUXUXUXUX",
"UXUX0 T.&.G G H H J J J J J J J J J J J S J S J S J S S S S S S S S S S D B N N + UXUXUXUXUXUXUX",
"UXUXt T.D D F F F D D D D D D D C C C D C C C D C C C C V V C V V C V V V N i B 2 UXUXUXUXUXUXUX",
"UXUXt C s s s s y s y s s s i i i i i i i i i i i i i i i i i i i i y i i r w N 8   UXUXUXUXUXUX",
"UXX y m w w w w e e e e 8 e r p u u u 8 e e r e 0 e y e w e r e w w w w w w w N z + UXUXUXUXUXUX",
"UXX z m w w w w e 8 w e e a =.<.<.<.<.$.p m E.&.e M E.#.e s E.#.r w w w w w w i m # UXUXUXUXUXUX",
"UXX z m w w w w e w w e w f <.1.1.1.1.%.p N (.E.e V (.E.i N (.R.y w w w w w w r B * UXUXUXUXUXUX",
"UXX m z w w w w e e 8 e e r f $.$.d f a e e N s e r N m e r N m w w w w w w w i N % UXUXUXUXUXUX",
"UX+ y B y t y y r y y y y t e 0 y r i y y r y t r y y r r r y y r y y y y r i N z @ UXUXUXUXUXUX",
"UXUX* m B B B B N N B B B B B B B B B N B B B B N B B B B B B B B B B B B B B m 5 UXUXUXUXUXUXUX",
"UXUXUX* * * * * * 2 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * # + UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
