/* XPM */
static char *lbreakout2_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #030303",
".  c #0B0303",
"X  c #020D02",
"o  c #090906",
"O  c #0B0C0A",
"+  c #140101",
"@  c #1A0705",
"#  c #021202",
"$  c #041B04",
"%  c #14130F",
"&  c #1A1711",
"*  c #1A1913",
"=  c #191915",
"-  c #290B08",
";  c #360705",
":  c #2A160A",
">  c #35140F",
",  c #251A14",
"<  c #3C1B12",
"1  c #053705",
"2  c #172518",
"3  c #163916",
"4  c #143714",
"5  c #23231B",
"6  c #27261E",
"7  c #35281D",
"8  c #161E23",
"9  c #1F2928",
"0  c #232B23",
"q  c #28352A",
"w  c #3B392B",
"e  c #3A3628",
"r  c #393933",
"t  c #30362F",
"y  c #5A1D14",
"u  c #47120C",
"i  c #681B11",
"p  c #462B08",
"a  c #58330B",
"s  c #49381B",
"d  c #562219",
"f  c #6E2E16",
"g  c #463A2A",
"h  c #5A3528",
"j  c #64362B",
"k  c #713B32",
"l  c #6C2F25",
"z  c #024C02",
"x  c #034303",
"c  c #055205",
"v  c #0E5E0E",
"b  c #1E401E",
"n  c #155B15",
"m  c #196519",
"M  c #1B731B",
"N  c #35463A",
"B  c #255B23",
"V  c #256B26",
"C  c #2A722A",
"Z  c #287728",
"A  c #337B34",
"S  c #754916",
"D  c #7F5114",
"F  c #6F401A",
"G  c #4E4028",
"H  c #544737",
"J  c #5D553F",
"K  c #4E4636",
"L  c #664C38",
"P  c #775635",
"I  c #754E2B",
"U  c #6C6733",
"Y  c #736832",
"T  c #3D5245",
"R  c #534E40",
"E  c #55534C",
"W  c #5A5544",
"Q  c #555652",
"!  c #445A47",
"~  c #6D5C44",
"^  c #4C7250",
"/  c #6A664B",
"(  c #6D694D",
")  c #676349",
"_  c #79664B",
"`  c #7F6A4B",
"'  c #776844",
"]  c #7E6C52",
"[  c #706C50",
"{  c #6B745D",
"}  c #5C7C63",
"|  c #607D64",
" . c #963829",
".. c #843A2C",
"X. c #923325",
"o. c #89550B",
"O. c #86510D",
"+. c #814E11",
"@. c #835214",
"#. c #8A5815",
"$. c #9A6216",
"%. c #B76D08",
"&. c #A36715",
"*. c #B57215",
"=. c #904D34",
"-. c #836335",
";. c #967135",
":. c #A97125",
">. c #AE7A32",
",. c #A54A3A",
"<. c #CF7F0E",
"1. c #CD7F12",
"2. c #855E45",
"3. c #B65F50",
"4. c #AA5A4B",
"5. c #8C6946",
"6. c #8C764B",
"7. c #92774D",
"8. c #947A4C",
"9. c #9A794B",
"0. c #806D52",
"q. c #877657",
"w. c #967951",
"e. c #9A7A53",
"r. c #987656",
"t. c #AB7E42",
"y. c #A37D4C",
"u. c #B86455",
"i. c #A46C53",
"p. c #A57763",
"a. c #AF6F63",
"s. c #C07B6C",
"d. c #1C841D",
"f. c #1F8420",
"g. c #278626",
"h. c #338B2E",
"j. c #259226",
"k. c #279428",
"l. c #29962A",
"z. c #2B982B",
"x. c #358C31",
"c. c #398E35",
"v. c #3D8A3D",
"b. c #339433",
"n. c #3A9136",
"m. c #359A36",
"M. c #3A9339",
"N. c #3C9A3C",
"B. c #379138",
"V. c #3AA63A",
"C. c #3DAB3D",
"Z. c #3FB13F",
"A. c #44923F",
"S. c #3E8C41",
"D. c #489746",
"F. c #55974A",
"G. c #569855",
"H. c #468745",
"J. c #42AD42",
"K. c #48A748",
"L. c #46B246",
"P. c #49B249",
"I. c #4FB84F",
"U. c #57A457",
"Y. c #54BD54",
"T. c #5ABB5A",
"R. c #70A659",
"E. c #709475",
"W. c #5EA360",
"Q. c #69A861",
"!. c #70B66B",
"~. c #719C52",
"^. c #5CC15C",
"/. c #64C464",
"(. c #6AC46A",
"). c #77C677",
"_. c #BC8434",
"`. c #B5823C",
"'. c #CF800E",
"]. c #D1800F",
"[. c #CF8111",
"{. c #CA821C",
"}. c #D28414",
"|. c #D48719",
" X c #D5891B",
".X c #D58816",
"XX c #CC8623",
"oX c #D79636",
"OX c #CB8A31",
"+X c #E19F3D",
"@X c #E1A03E",
"#X c #AC8347",
"$X c #B48545",
"%X c #B1884E",
"&X c #A98553",
"*X c #B58B52",
"=X c #B99459",
"-X c #938A68",
";X c #96906A",
":X c #9A946D",
">X c #8F8763",
",X c #A58669",
"<X c #BF8B6B",
"1X c #95B17E",
"2X c #8CAB6F",
"3X c #ABA179",
"4X c #BAA77C",
"5X c #CA9449",
"6X c #D19B4B",
"7X c #D29F52",
"8X c #D6A55A",
"9X c #D6A356",
"0X c #DBA24B",
"qX c #E3A343",
"wX c #E5A74A",
"eX c #E6A84B",
"rX c #C29D67",
"tX c #C88576",
"yX c #D9AA62",
"uX c #D7A962",
"iX c #C7A778",
"pX c #D8B177",
"aX c #E7BB72",
"sX c #F2C173",
"dX c #79A082",
"fX c #BA9685",
"gX c #88BC88",
"hX c #9CB184",
"jX c #93B28C",
"kX c #A2B18A",
"lX c #AEB487",
"zX c #BBB385",
"xX c #BEB789",
"cX c #ADAF8D",
"vX c #CE9A8E",
"bX c #C2AA88",
"nX c #C4BC8D",
"mX c #C4BC99",
"MX c #CEA998",
"NX c #D5BBB4",
"BX c #CEB3A7",
"VX c #92C291",
"CX c #9BC9A2",
"ZX c #AFE3B7",
"AX c #DDD59F",
"SX c #CFC396",
"DX c #CEC2A2",
"FX c #DDD6A1",
"GX c #DCC3BB",
"HX c #E2D9A6",
"JX c #F3EEBA",
"KX c #F1ECB5",
"LX c #F6F1BA",
"PX c #F7F2BA",
"IX c #EDE8B4",
"UX c None",
/* pixels */
"5 r Q Q E E E E E R R K G G H Q Q Q E E E Q E E Q Q Q E E R R H H g H Q Q E W E E Q E Q Q E r 5 ",
"6 K ] ] ] ] _ _ _ _ ' P I 6.-Xr.0.] ` ` 0.0.] 0.] ] _ _ _ _ ' ' -.-.q.-X0.0.2.0.] ] ] ] ] ` H 6 ",
"7 P $X$X$X$X#Xt.#Xt.#X`.:.rXSX=X$X$X`.`.$X$X$X$X$Xt.y.t.t.t.>.>.>.*XrXiX*X$X$X$X$X$X$X$X#X#XP 7 ",
"p @.{.{.{.{.{.XX{.{.oX6X&.*XiX:.*.XXXX{.1.{.XX{.1.{.{.XX1.XXoXoX_.y.&X*XXXXXXX1.{.{.{.{.{.{.@.p ",
"p o.[.[.<.1.[..X|.].+X0X&.&XbX&.%.}..X}.[.].[.}.}.<.}..X|.|.oXoX_.9.e.$X{.}..X[.].<.'.[.}.].o.p ",
"p o.<.[.[.}.}.}.|.[.+X0X&.%XbX:.%.}..X}.[.].<.1.}.}.}..X|.|.oXoX_.9.e.$XXX|..X.X].].[.}..X.Xo.p ",
"p o.}.1.}. X X}.[. XqX9X$.#X4X&.%..X.X.X.X|.1.1.}.|.|.}.}. XoXoX_.9.w.#X{..X.X|.|..X'.'.[.|.#.p ",
"s ;.qXqXqXqXqXqXqXwXsXaX$.y.4X`.OXeXeXwXwXeXwXqX+X+XqXqX@XqXsX9X$X7.y.5XqXeXeXeXeXeXqXqXqX+X;.a ",
"s ;.uX8X7X6X7X9X8X7XpXiX#.;.iX_.5XuXyXyXuXuXuX8X6X6X7X9X9X9XpX=X;.6.#X5X7X8XyXyXuXuXuXuX0X5X-.s ",
": a @.@.+.+.+.O.D S F F a #.`.$.O.D @.#.#.@.@.@.+.+.+.@.D S F F F #.:.:.D S @.#.#.@.D @.@.D a : ",
"7 L e.w.w.w.7.7.6.0.' U U 6.*X%X9.7.6.8.e.w.7.7.e.r.r.6.6.6.' U U Y &X=Xe.q.8.8.w.e.8.8.8.w.L 7 ",
"r { kXhXkXkXhXhX1XhX1XR.F.R.lXlXkXkXhXhXkXkXhXhXkXcXkX1XhXhX2XR.R.~.1XmXcXjX1XhXkXkXkXkXkXkX{ t ",
"4 B v.c.x.x.h.x.x.h.x.n.g.Q.VXD.h.x.n.n.c.M.c.c.c.h.x.h.x.x.x.h.B.F.Q.Q.A.c.n.c.n.n.n.c.c.x.B 2 ",
"4 m z.l.j.j.k.z.k.j.V.Z.d.W.gXb.d.k.z.l.k.l.l.l.j.j.k.k.k.k.m.m.N.H.G.U.b.l.z.k.j.k.z.l.k.k.n 4 ",
"4 C C.C.V.C.C.J.C.C.^./.g.W.gXM.l.C.C.C.C.V.C.C.C.V.C.Z.C.C.^.I.K.F.F.U.J.Z.Z.V.V.C.V.J.C.C.C 3 ",
"4 V C.C.J.J.C.C.C.C.^./.g.U.gXn.l.Z.Z.J.C.C.V.C.Z.C.C.C.C.Z.^.I.K.D.G.U.K.C.C.J.Z.C.V.C.J.C.C 3 ",
"3 C C.C.Z.J.C.V.Z.Z.^./.g.G.gXB.l.Z.C.C.J.Z.V.V.Z.Z.C.V.V.C.Y.I.J.F.G.U.J.C.Z.C.Z.C.C.V.Z.Z.C 3 ",
"3 Z L.L.L.L.L.J.Z.Z./.(.d.F.gXM.m.P.P.L.P.P.P.P.J.L.L.J.C.L.T.I.D.H.G.U.P.L.P.L.P.P.P.L.L.L.Z 3 ",
"b H.(.(.^.Y.^.^.^.^.).dXM v.!.K.I./.(.(././.(.(.^.Y.T./././.).W.v.v.D.U.T././.(./.(.(.(./.Y.A 3 ",
"4 B D.N.m.b.B.m.m.b.S.v.v Z K.z.x.M.D.N.N.N.N.N.m.z.b.N.n.B.v.A Z Z M.J.B.B.M.N.N.N.D.N.m.m.B 4 ",
"$ 1 z c c c c c z z x 1 1 n Z m c x z c c c z z c c c c c z x 1 x n m m c z z c c c c c c c 1 $ ",
"X X # # # # # # # # X # # $ $ # # X # # # # # # # # # # # # # # X # $ $ # X X # # # # # # # X X ",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX9 N Q T 9 O UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX9 } VXCXVX} q O UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX8 N dXZXZXVX} q o   UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXT dXVXCXE.T 2 o UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXt } E.| ! t = o UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX2 N T N q 2 O   UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXo O 9 q 0 2 % O o O UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUX- - : : , 5 5 5 5 5 6 6 5 5 5 5 5 5 5 , : - @ - UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXu l k k j H W / ( ( ( ( ( ( [ [ [ ( ) W L j j l y u UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXd j i.s.tXp.,X3XxXnXnXnXnXnXnXnXnXnXnXnXlX,Xp.a.3.=.d < UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXe H a.MXNXBXBXmXFXIXJXJXJXKXKXIXJXJXJXLXKXAXmXMXBXvXs.,.h 7 UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX= K 2.tXNXGXNXBXDXHXKXJXLXLXLXKXLXPXPXJXPXLXHXDXMXBXMXs.u.k g % UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX  % W r.s.vXvXvXfXbXSXFXFXFXFXFXFXFXHXFXAXHXFXSXbXfXvXvXu.4.2.g O   UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX  % W 2.4.u.u.u.i.,X3XzXxXzXbXxXzXzXzXzXzXlXzX3X,X3.3.,.,.k h 7 O   UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX% g k .. . . .=.2.q.-X;X;X:X:X;X;X;X;X-X>X>Xq.2...X.X.X.y > % o UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX, < y i i i l j J / ( ( [ ( ( ( ( / / / ) R j d i i y ; @ . UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUX- - u u u u 7 e w w w w e g w w e w e 6 6 , - ; ; - @ . UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX+ + + - @ % & * * * * & & * & & & % % % O + + + + . UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUX+ . . + . o o o o o o o o o o # o o             UXUXUXUXUXUXUXUXUXUXUXUX"
};
