/* XPM */
/* $XConsortium: DtCMark.t.pm /main/3 1995/07/18 16:19:24 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * DtCMark_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 9 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o    s iconGray5     m black c #737373737373",
"O    s iconGray4     m white c #949494949494",
"+    s iconGray3     m white c #adadadadadad",
"@    s iconGray6     m black c #636363636363",
"#	s iconColor1	m black	c black",
"$    s iconGray7     m black c #424242424242",
/* pixels */
"            ....",
" XXXXXXXXXXo....",
" XOOOOOOO+Xo....",
" X@XXXXXX+Xo....",
" XOOOOOOO+Xo....",
" X@XXXXXX+Xo....",
" X+++OOOO+Xo....",
" XX@XXX        #",
" XOOO@O XXXXXX+#",
" XX@XOX X  +  o#",
" XOOO@O X     o#",
" XXXXOX X Oo  o#",
" XOOO@O XXXXXXo#",
" XX@XOX $$$$$$$#",
" XXXXXXXXXXo....",
" ooooooooooo...."};
