/* XPM */
static char *eom_m[] = {
/* columns rows colors chars-per-pixel */
"32 32 229 2 ",
"   c #41433F",
".  c #63573F",
"X  c #3F4D5F",
"o  c #394C67",
"O  c #384C68",
"+  c #2F4C72",
"@  c #304A76",
"#  c #37507A",
"$  c #3A577B",
"%  c #424441",
"&  c #474A46",
"*  c #4D4D44",
"=  c #474A49",
"-  c #4A4C48",
";  c #4D5145",
":  c #4F514E",
">  c #4C5153",
",  c #535552",
"<  c #555A5B",
"1  c #5E615A",
"2  c #646951",
"3  c #6C6559",
"4  c #4D5A6B",
"5  c #4B5D75",
"6  c #56616B",
"7  c #516175",
"8  c #57667C",
"9  c #5C6B7D",
"0  c #636562",
"q  c #686965",
"w  c #6B6D6B",
"e  c #6D706C",
"r  c #727367",
"t  c #6B767F",
"y  c #6A7E7C",
"u  c #747572",
"i  c #777975",
"p  c #7D7E77",
"a  c #7A7C79",
"s  c #8F5A04",
"d  c #915B04",
"f  c #A96E0E",
"g  c #B4750E",
"h  c #94662C",
"j  c #AC6A25",
"k  c #B26F2E",
"l  c #B97F22",
"z  c #B07D2C",
"x  c #82766C",
"c  c #977B73",
"v  c #7E9C32",
"b  c #799548",
"n  c #769260",
"m  c #6F837A",
"M  c #708D75",
"N  c #7B927D",
"B  c #9A823E",
"V  c #B9852E",
"C  c #BC8B39",
"Z  c #D18218",
"A  c #DC9428",
"S  c #C1903F",
"D  c #CA923A",
"F  c #E0A42E",
"G  c #978058",
"H  c #94AD4F",
"J  c #9AB157",
"K  c #938969",
"L  c #8E976C",
"P  c #83847E",
"I  c #929473",
"U  c #929D78",
"Y  c #B39163",
"T  c #9AB260",
"R  c #8FA673",
"E  c #98A571",
"W  c #A6B375",
"Q  c #A2B179",
"!  c #AFBE7F",
"~  c #C28A48",
"^  c #C39245",
"/  c #CB9743",
"(  c #DBA059",
")  c #E1AA5B",
"_  c #CC9461",
"`  c #BBCC7C",
"'  c #C0CD7F",
"]  c #3F5D85",
"[  c #506683",
"{  c #5F6F85",
"}  c #646B83",
"|  c #6A7683",
" . c #68708B",
".. c #6A798A",
"X. c #6A7C94",
"o. c #877881",
"O. c #8E7C85",
"+. c #778387",
"@. c #74808C",
"#. c #7D858C",
"$. c #758890",
"%. c #76879E",
"&. c #7D8B9A",
"*. c #858681",
"=. c #8B8084",
"-. c #878A84",
";. c #898A85",
":. c #878588",
">. c #8F8189",
",. c #82888C",
"<. c #8B8D8A",
"1. c #97868C",
"2. c #8F9680",
"3. c #8F918D",
"4. c #9A9784",
"5. c #999A80",
"6. c #90928B",
"7. c #878F99",
"8. c #899196",
"9. c #939592",
"0. c #9A9790",
"q. c #999A97",
"w. c #95959C",
"e. c #9C9D9B",
"r. c #A49C8D",
"t. c #A09295",
"y. c #A39892",
"u. c #A59E9D",
"i. c #BDA38E",
"p. c #A9A397",
"a. c #A0A19F",
"s. c #ADA399",
"d. c #AEAA9D",
"f. c #B1A999",
"g. c #AFBA91",
"h. c #B5B796",
"j. c #B3BC95",
"k. c #B7B49D",
"l. c #8D97A2",
"z. c #939DAB",
"x. c #8D9CB0",
"c. c #9AA0A4",
"v. c #9CA5AF",
"b. c #92A5BD",
"n. c #98A8BF",
"m. c #A6A6A2",
"M. c #A8A9A4",
"N. c #AEAEAB",
"B. c #B0A6A3",
"V. c #B4ADA9",
"C. c #B4B3A3",
"Z. c #B8B2A7",
"A. c #B3B5AD",
"S. c #B5BAAE",
"D. c #B8BEAF",
"F. c #A4ADB8",
"G. c #AEB2B1",
"H. c #AEB6BE",
"J. c #B5B6B2",
"K. c #B7BAB0",
"L. c #B9BCB4",
"P. c #B4B7B9",
"I. c #B6B9BB",
"U. c #BDBDBA",
"Y. c #C3A285",
"T. c #CCB8A1",
"R. c #B6C482",
"E. c #BECA94",
"W. c #BAC39E",
"Q. c #BCC4A1",
"!. c #BCC3A8",
"~. c #BDC0B5",
"^. c #BFC1BC",
"/. c #D5C1A0",
"(. c #D8DCA7",
"). c #C1C5B3",
"_. c #CBCFB3",
"`. c #C1C5BA",
"'. c #C5C8BE",
"]. c #D1D7B2",
"[. c #E4CBAF",
"{. c #E6D0B6",
"}. c #DDE3B5",
"|. c #E3EAA8",
" X c #E7EEB2",
".X c #ADB7C3",
"XX c #AEBBCB",
"oX c #B2B9C1",
"OX c #BFC3C4",
"+X c #BEC5CD",
"@X c #BAC5D5",
"#X c #BEC8D2",
"$X c #C3C3C0",
"%X c #C7C9C3",
"&X c #CACCC6",
"*X c #C3C7C8",
"=X c #C0C8CF",
"-X c #CDCDCA",
";X c #D2D7C6",
":X c #D2D3CE",
">X c #C1C8D1",
",X c #CDD1D5",
"<X c #D6D4D4",
"1X c #D7D9D5",
"2X c #D9DAD7",
"3X c #D2D7DD",
"4X c #D8D6D9",
"5X c #D5D9DD",
"6X c #DEDEDC",
"7X c #F5E3C6",
"8X c #E9E0D7",
"9X c #E0E1DF",
"0X c #D3DAE6",
"qX c #DADDE1",
"wX c #D8DFEA",
"eX c #DEE1E3",
"rX c #DDE3EC",
"tX c #E6E6E4",
"yX c #E7E8E6",
"uX c #E9E9E7",
"iX c #E7E8E8",
"pX c #ECECEA",
"aX c #F0F0EE",
"sX c #E3E9F0",
"dX c #F4F4F3",
"fX c #FBFAF7",
"gX c #F7F8FB",
"hX c #FCFCFB",
"jX c None",
/* pixels */
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjX;.;.P ;.jXjXjXjXjXjXjXjXjXjXjXjX",
"jXjXjXjXjXjXjXjXjXjXjXjX*.;.<.L.6XdXfXU.*.jXjXjXjXjXjXjXjXjXjXjX",
"jXjXjXjXjXjXjXjX*.;.;.K.6XdXhXfXdXaXaXaX;.jXjXjXjXjXjXjXjXjXjXjX",
"jXjXjXjX*.;.;.J.6XdXhXfXdXaXpXpXpXpXuXfX3.jXjXjXjXjXjXjXjXjXjXjX",
"jX;.;.N.2XdXhXhXfXaXpXpXpXpXpX9X:X`.A.tXU.jXjXjXjXjXjXjXjXjXjXjX",
"<.9XhXfXdXdXaXpXpXpXpXtX<X'.K.D.W.E.W.-X6X;.jXjXjXjXjXjXjXjXjXjX",
"P hXaXaXaXpXpXyX2X%XK.D.Z.V.h.L 2 ; % - u q jXjXjXjXjXjXjXjXjXjX",
";.dXaXuX2X&XL.K.A.A.Z.k.<Xa.: :.U.6XpX6X^.-.- % jXjXjXjXjXjXjXjX",
"jX1XdXA.).].}.Z.aXhXpXo.w a 6XP.7.m M $.z.I.2Xi % jXjXjXjXjXjXjX",
"jXM.hX`.}. X|.s.fX7X) . <.:X:.@XsXeXn N &.n...%X-.% jXjXjXjXjXjX",
"jX;.hX:X_.(.f.1.~ A B w $XG T.8XrXw.b R +.@X9 ] I.q   jXjXjXjXjX",
"jX*.tXtX~.B.aXhXZ F * I.K /.[.j >.=.v T -.+X&.$ [ N.% jXjXjXjXjX",
"jXjXU.dXL.V.hXhX( h u 0.Y {.k _ gX<XI H U G.oX7 jX3.w jXjXjXjXjX",
"jXjX6.dX%XZ.V.0.O.3 9.x i.Y.c 4XhXaX4.J Q 6.5X6 b.9 <.% jXjXjXjX",
"jXjX<.aX2X!.' r.dX, u.} wXwXu.4.d.C.Q E 2.a tX#.>X$ 6.% jXjXjXjX",
"jXjXjX:XpXS.` y.hX% q. .0XrX-X;X:X&XL.U.-XqXiX*XH.jX<.% jXjXjXjX",
"jXjXjXm.fXK.R.W p.- *.y v.OX:X1X6XtXpXpXpXyXyX,Xl.# i % jXjXjXjX",
"jXjXjX;.dX-Xj.! g.1 w | .XeXtXpXpXpXpXyXuXyXeX3X| 4 0 % jXjXjXjX",
"jXjXjX;.6X6XZ.~.-Xq., w XXqXeXtXiXiXtXpXuXyX5XF.5 < : jXjXjXjXjX",
"jXjXjXjXK.aXyXyXyX2X= 1 &.@X5XqXtXiXiX<XI.8.| 8 O ,   jXjXjXjXjX",
"jXjXjXjX6.dXyXyXtXyX9.& , x.@X>XoXc.,.#.@.X.jX@ , &   jXjXjXjXjX",
"jXjXjXjX;.uXuXuXpXaXpX0 - , 4 { X.%.jXjXjXjXO , - = jXjXjXjXjXjX",
"jXjXjXjXP J.aXtX-XM.*.p - & , > X + jX+ o > , - & r s d jXjXjXjX",
"jXjXjXjXjX;.P ;.*.jXjXjXjX% % - : , , , : * % % jXs V z d jXjXjX",
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjX% % % % % jXjXjXjXd f / C d jXjX",
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXd g D ^ d jX",
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXd g D ^ s ",
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXd g V d ",
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXd d jX",
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjX",
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjX",
"jXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjX"
};
