/* XPM */
/* $XConsortium: Dtdate.m.pm /main/2 1996/07/23 12:07:35 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

/* Designed by the User Interaction Design Group, Hewlett-Packard */
static char *date32[]={
/* width height ncolors cpp [x_hot y_hot] */
"32 32 22 1 0 0",
/* colors */
"  c none m none s none",
"$ s topShadowColor     m white",
"& s background         m black",
"( s selectColor        m white",
"* s bottomShadowColor  m black",
", s white      c white     m white",
". s iconColor1 c black     m black",
"B s iconColor2 c white     m white",
"4 s iconColor3 c red       m black",
"6 s iconColor4 c green     m white",
"8 s iconColor5 c blue      m black",
"2 s iconColor6 c yellow    m white",
": s iconColor7 c cyan      m white",
"0 s iconColor8 c magenta   m black",
"< s iconGray1 c #e1e1e1e1e1e1  m white",
"> s iconGray2 c #c8c8c8c8c8c8  m white",
"@ s iconGray3 c #afafafafafaf  m white",
"D s iconGray4 c #969696969696  m white",
"F s iconGray5 c #7d7d7d7d7d7d  m black",
"H s iconGray6 c #646464646464  m black",
"J s iconGray7 c #4b4b4b4b4b4b  m black",
"L s iconGray8 c #323232323232  m black",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"   <<<<<<<<<<<<<<<<<<<<<<<<<<   ",
"   <DDDDDDDDDDDDDDDDDDDDDDDDJ   ",
"   <DBBBBBBBBBBBBBBBBBBBBBDDJ   ",
"   <DBBBBBBBBBBBBBBBBBBBBBLDJ   ",
"   <DBBHHHBBBBBBBBBBHBBHBBLHJ   ",
"   <DBHBBBHBBBBHBBBHHBHBHBLHJ   ",
"   <DBHBBBHB,HBHHBBBHBBBHBLHJ   ",
"   <DBHBBBHBHBBHBBBBHBBHBBLHJ   ",
"   <DBHBBBHBHBBHBBBBHBHBBBLHJ   ",
"   <DBBHHHBB,HBBHBBHHBHHHBLHJ   ",
"   <DBBBBBBBBBBBBBBBBBBBBBLHJ   ",
"   <DBHHHHHBBBBBBBBBBBBBBBLHJ   ",
"   <DBHBHBHBBBBBBBBBBBBBBBLHJ   ",
"   <DBBBHBBHBHBBHBBBHHBBBBLHJ   ",
"   <DBBBHBBHBHBH@HBHBBBBBBLHJ   ",
"   <DBBBHBBHBHBHBBBB,HBBBBLHJ   ",
"   <DBBHHHBBHBHBHHBHHBBBBBLHJ   ",
"   <DBBBBBBBBBBBBBBBBBBBBBLHJ   ",
"   <DDLLLLLLLLLLLLLLLLLLLLLHJ   ",
"   <DDDHHHHHHHHHHHHHHHHHHHHHJ   ",
"   <DDDDFFFFFFFFFFFFFFFFFFFFJ   ",
"   <JJJJJJJJJJJJJJJJJJJJJJJJJ   ",
"                                ",
"                                ",
"                                ",
"                                "
};
