/* XPM */
/* $XConsortium: DtFlag.t.pm /main/3 1995/07/18 16:21:07 drk $ */
static char * DtFlag_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 10 1 0 0",
/* colors */
"     s iconGray1     m white c #dededededede",
".    s bottomShadowColor m black c #636363636363",
"X	s none	m none	c none",
"o    s iconGray6     m black c #636363636363",
"O    s iconGray8     m black c #212121212121",
"+    s topShadowColor m white c #bdbdbdbdbdbd",
"@	s iconColor6	m white	c yellow",
"#    s iconGray5     m black c #737373737373",
"$	s iconColor2	m white	c white",
"%	s iconColor1	m black	c black",
/* pixels */
"     ....XXXXXXX",
". oOO    .....+X",
". oO@@ @#  $@%+X",
". oO@ @#@#@@@%+X",
". oO@@ @#@ @@%+X",
". oO@ @#@#@@@%+X",
". oO@@ @#@ @@%+X",
". oO%%%%@#@@@%+X",
". oO+++%%%%%%++X",
". oO+XX++++++XXX",
". oO+XXXXXXXXXXX",
". oO+XXXXXXXXXXX",
". oO+XXXXXXXXXXX",
". oO+XXXXXXXXXXX",
"OOOOO+XXXXXXXXXX",
"++++++XXXXXXXXXX"};
