/* XPM */
/* $XConsortium: Dtpcl.m.pm /main/3 1995/07/18 16:46:32 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtpcl_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 9 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray7     m black c #424242424242",
"+    s iconGray8     m black c #212121212121",
"@    s iconGray1     m white c #dededededede",
"#	s iconColor5	m black	c blue",
"$    s iconGray3     m white c #adadadadadad",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXoOOXXOOXOOXooXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXXooOoOOXooXOooXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXooXoOOXoOXoXooOooXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoooXooOXXoOOooXooOOXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoOOXOooXoOOoXXOOXoXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoOOooOoXOooXooOOoooXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XX++++X++X+oX@@@@@@@@@@@@@@@@@@",
" XXXXXXXXXXXXX@#O#O#O#O#O#O#O#Oo",
" XXXXXXXXXXXXX@O   O#O  #O O#O#o",
" XX+++X+X+++oX@# #O O O# # #O#Oo",
" XXXXXXXXXXXXX@O O# # #O#O O#O#o",
" XX+++++X++Xoo@#   #O O#O# #O#Oo",
" XXXXXXXXXXXXX@O O#O# #O#O O#O#o",
" XX++++X+++XOX@# #O#O O# # #O#Oo",
" XXXXXXXXXXXXX@O O#O#O  #O    #o",
" XXXXXXXXXXXXX@#O#O#O#O#O#O#O#Oo",
" XXXXXXXXXXXXX@ooooooooooooooooo",
" XXXXXXXXXXXXX$$$$$$$$$$$.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
