/* XPM */
/* $XConsortium: MouseOL.pm /main/3 1995/07/18 17:24:00 drk $ */
static char * MouseOL [] = {
/* width height ncolors cpp [x_hot y_hot] */
"64 37 7 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X    s iconGray1     m white c #dededededede",
"o    s iconGray8     m black c #212121212121",
"O	s iconColor2	m white	c white",
"+    s iconGray3     m white c #adadadadadad",
"@    s iconGray5     m black c #737373737373",
/* pixels */
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"          ................................                      ",
"          .XXXXXXXXXoOOOOOOOOOOOOOOOOOOOOO..                    ",
"          .X++++++++oOXXXXXXXXXXXXXXXXXXXXXO.                   ",
"          .X++++++++oOXXXXXXXXOOXOOOOXOXXXXXO.                  ",
"          .X++++++++oOXXXXXXXOXXXXXXXXXX+XXXXO.                 ",
"          .X++++++++oOXXXXXXOXXXOOOOXOXXX++XXXO.                ",
"          .X++++++++oOXXXXXXXOOOOOOOO+XOX+++XXX.                ",
"          .X++++++++oOXXXXOXXXOOOOOOOOXOOX@++XXX.               ",
"          .X++++++++oOXXXXXXOOOOOOOOXXOXXXO++XXX.               ",
"          .XoooooooooOXXXXXOXOOOOOOXOOXOXXX@@+XXoX              ",
"          .XXXXXXXXXoOXXXXXXOOOOOOXXXXO++@X@++XXoX              ",
"          .X++++++++oOXXXXXXOOOOO+OXXX@XXX+X@@XXoX              ",
"          .X++++++++oOXXX+XOXXOOOOXX++XO++++@@XXoX              ",
"          .X++++++++oOXXX+XXOXOOXXXXXOX++++++@XXoX              ",
"          .X++++++++oOXXXXXXXOOXXX++X++@+@@+@@XXoX              ",
"          .X++++++++oOXXX+XXOXOX+XXO+@+++@++@@XXoX              ",
"          .X++++++++oOXXXX+XXO+X+O+@+++@++@@+@XXoX              ",
"          .XoooooooooOXXXX@+XXX+XX@+@+++@+++@XX@oX              ",
"          .XXXXXXXXXoOXXXX++XXXX+++++@+@@+@@@XXooX              ",
"          .X++++++++oOXXXXX+@+OX+++@+++@+++@XX@oX               ",
"          .X++++++++oOXXXXXX+@@+++++@@@+@@@XXXooX               ",
"          .X++++++++oOXXXXXXX@+@++@+@++@@@XXXoooX               ",
"          .X++++++++oOXXXXXXXX+@@@++@@@@@XXXoooX                ",
"          .X++++++++oOXXXXXXXXX@X@@@@@XXXXXoooX                 ",
"          .X++++++++oOXXXXXXXXXXXXXXXXXXX@oooX                  ",
"          .XooooooooooooooooooooooooooooooooX                   ",
"          .oooooooooooooooooooooooooooooooXX                    ",
"            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX                      ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                "};
