/* XPM */
static char *fontforge_m[] = {
/* columns rows colors chars-per-pixel */
"32 32 236 2 ",
"   c #171203",
".  c #4E5235",
"X  c #555733",
"o  c #51533E",
"O  c #60622F",
"+  c #6B623F",
"@  c #747734",
"#  c #464646",
"$  c gray29",
"%  c #4B4B4B",
"&  c #595A46",
"*  c #555555",
"=  c #565656",
"-  c #5D5E52",
";  c gray37",
":  c #5F5F5F",
">  c #696346",
",  c #686750",
"<  c #79715D",
"1  c gray39",
"2  c #686868",
"3  c gray42",
"4  c #6C6C6C",
"5  c #6F6F6F",
"6  c #717171",
"7  c #747474",
"8  c gray47",
"9  c #797979",
"0  c #7B7B7B",
"q  c gray49",
"w  c #7E7E7E",
"e  c #80713C",
"r  c #8A7C49",
"t  c #A48217",
"y  c #AA8717",
"u  c #A9AB1C",
"i  c #8B8F3B",
"p  c #B1993D",
"a  c #B89A38",
"s  c #BD9F3E",
"d  c #A1A73D",
"f  c #D3AE0E",
"g  c #C1A23F",
"h  c #95804B",
"j  c #9B8948",
"k  c #AD964A",
"l  c #B69A42",
"z  c #AE9A5E",
"x  c #BFA341",
"c  c #B9A04A",
"v  c #B9A253",
"b  c #878178",
"n  c #9F9276",
"m  c #AAA165",
"M  c #BCA867",
"N  c #AAAB7E",
"B  c #BAA973",
"V  c #B5A379",
"C  c #B5A77B",
"Z  c #C0A548",
"A  c #CCCD44",
"S  c #D8D549",
"D  c #E5DC5B",
"F  c #EFDA58",
"G  c #EFDD58",
"H  c #EDDE62",
"J  c #F2DA62",
"K  c #F3DD78",
"L  c #EAE065",
"P  c #808080",
"I  c #818181",
"U  c gray51",
"Y  c #838383",
"T  c #848484",
"R  c gray52",
"E  c #868686",
"W  c gray53",
"Q  c #898989",
"!  c gray54",
"~  c #8E8E8E",
"^  c #909091",
"/  c gray57",
"(  c #929292",
")  c gray58",
"_  c #959595",
"`  c #979797",
"'  c #9D9D9D",
"]  c gray62",
"[  c #A29D89",
"{  c #AFA581",
"}  c #ACA286",
"|  c #A9A38F",
" . c #A7A299",
".. c #AAA698",
"X. c #B2A996",
"o. c #A0A0A0",
"O. c gray63",
"+. c #A2A2A2",
"@. c #A6A5A3",
"#. c #A4A4A4",
"$. c #A5A5A5",
"%. c gray65",
"&. c #A7A7A7",
"*. c gray66",
"=. c #A8A8A9",
"-. c gray67",
";. c #ACACAC",
":. c gray68",
">. c #AEAEAE",
",. c #AEAFAF",
"<. c #AFAFAF",
"1. c #AFB0B0",
"2. c #B1B1B1",
"3. c #B2B2B2",
"4. c gray70",
"5. c #B4B4B4",
"6. c gray71",
"7. c #B6B6B6",
"8. c #B9B9B9",
"9. c gray73",
"0. c gray74",
"q. c #BDBEBE",
"w. c gray75",
"e. c #F1DB8A",
"r. c #F2E09A",
"t. c #EFE2AC",
"y. c #F0E7BE",
"u. c #C0C0C0",
"i. c #C1C1C1",
"p. c gray76",
"a. c #C3C2C2",
"s. c #C2C3C3",
"d. c #C3C3C3",
"f. c gray77",
"g. c #C4C5C5",
"h. c #C5C5C5",
"j. c gray79",
"k. c #C9CACA",
"l. c #CACACA",
"z. c #CACACB",
"x. c #CACBCB",
"c. c #CBCCCC",
"v. c gray80",
"b. c #CDCDCD",
"n. c #CDCECE",
"m. c #CECECE",
"M. c gray81",
"N. c #D5D2CD",
"B. c #D0D0D0",
"V. c gray82",
"C. c #D1D2D2",
"Z. c #D2D2D2",
"A. c #D2D3D3",
"S. c LightGray",
"D. c #D3D4D4",
"F. c gray83",
"G. c #D5D5D5",
"H. c #D5D6D6",
"J. c gray84",
"K. c #D7D7D7",
"L. c #D7D8D8",
"P. c #D8D8D8",
"I. c gray85",
"U. c #D9DADA",
"Y. c #DADADA",
"T. c gray86",
"R. c gainsboro",
"E. c #DDDDDD",
"W. c #DDDEDE",
"Q. c #DEDFDF",
"!. c #DFDFDF",
"~. c #EBE3C6",
"^. c #F4EFDB",
"/. c #DFE0E0",
"(. c gray88",
"). c #E0E1E1",
"_. c #E1E1E1",
"`. c #E2E2E2",
"'. c #E2E3E3",
"]. c gray89",
"[. c #E4E5E5",
"{. c gray90",
"}. c #E5E6E6",
"|. c #E5E6E7",
" X c #E6E7E7",
".X c #E7E7E7",
"XX c #E6E7E8",
"oX c #E7E8E8",
"OX c #E7E8E9",
"+X c gray91",
"@X c #E8E9E9",
"#X c #E9E9E9",
"$X c #E8E9EA",
"%X c #E9EAEA",
"&X c #E9EAEB",
"*X c #EAEAEA",
"=X c gray92",
"-X c #EEEDEB",
";X c #EBEBEC",
":X c #EBECEC",
">X c #EBECED",
",X c #ECECEC",
"<X c #ECEDED",
"1X c gray93",
"2X c #EDEEEE",
"3X c #EEEEEE",
"4X c #EEEFEF",
"5X c #EFEFEF",
"6X c #F7F4E8",
"7X c #EFF0F0",
"8X c gray94",
"9X c #F0F1F1",
"0X c #F1F1F1",
"qX c #F1F2F2",
"wX c gray95",
"eX c #F2F3F3",
"rX c #F3F3F3",
"tX c #F3F4F4",
"yX c #F4F4F4",
"uX c #F4F5F5",
"iX c gray96",
"pX c #F5F6F6",
"aX c #F6F6F6",
"sX c #F6F7F7",
"dX c gray97",
"fX c #F8F7F1",
"gX c #F9F9F7",
"hX c #F7F8F8",
"jX c #F8F8F8",
"kX c #F9F9F9",
"lX c gray98",
"zX c #FBFBFB",
"xX c gray99",
"cX c #FDFDFD",
"vX c #FEFEFE",
"bX c None",
/* pixels */
"bXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbX",
"bXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbX",
"bXbXbXbX9X=X:X<X<X7X7X7X9X9X9X9X9X9XuX9X9XuXuXuXuXrXuXuXbXbXbXbX",
"bXbXbXbX;X|.XXOXOX;X:X:X<X<X<X5X9X5X9X9X9X9X9X<X9X9X9XrXbXbXbXbX",
"bXbXbXbX:XXXOX=X/.:X<X:X<X<X|.5X5X=X9X9XuX9XuX`.9X9XrXuXbXbXbXbX",
"bXbXbXbX<X=XQ.A.q.Z.Z.Z.F.Z.a.Z.Z.a.F.F.I.F.F.j.!.,XrXdXbXbXbXbX",
"bXbXbXbX<X=X:X|.W U w 9 7 6 : 4 6 3 9 P W W W Q 5XuXuXdXbXbXbXbX",
"bXbXbXbX4X|.I.x.U U ( :.8.g.O.1 2 $.g.3.] ~ U W F.|.uXkXbXbXbXbX",
"bXbXbXbX9X<X<X].( <.9X9XrXrXj.w w j.uXuXuXdX@.) <XdXdXkXbXbXbXbX",
"bX- f bX9X<X5X`.` |.9XrXrXiXv.Q W m.jXjXkXjX!.) <XlXlXlXbXbXbXbX",
"bXe N p 9X<X4X/.3.=XrXuXuXuXm._ ( m.kXkXkXkXrXw.,XlXlXlXbXbXbXbX",
"bXz [ u r.4X7XQ.OXI.rXuXuXuXM.O.] M.kXlXlXkX5X9X,XlXlXlXbXbXbXbX",
"bXbXy > A t.9XW.:X|.OX9XdXgXM.-.*.V.kXkXkXlXkXdX=XvXlXlXbXbXbXbX",
"bXbXbXt , S y.W.7XuXuXdXuXjXZ.6.3.V.lXxXlXvXvXkX+XlXvXvXbXbXbXbX",
"bXbXbX  s & D ~.uXuXuXuXkXkXZ.<.-.Z.xXlXvXlXvXlXrXlXlXvXbXbXbXbX",
"bXbXbXbX..g o L ^.sXgXgXkXkXZ.#.$.F.xXxXlXlXvXvXvXvXvXvXbXbXbXbX",
"bXbXbXbXF.| Z . H 6XdXkXlXlXM.~ ( V.lXvXxXvXxXvXxXvXvXvXbXbXbXbX",
"bXbXbXbX9XN.} c X G fXlXlXlXM.T T M.xXvXvXvXvXvXvXvXvXvXbXbXbXbX",
"bXbXbXbXuX0XM.C c O F gXlXxXM.0 0 M.vXvXvXvXvXvXvXvXvXvXbXbXbXbX",
"bXbXbXbXuXuX,Xv.C k @ J gX,Xf.6 6 b.vXvXvXvXxXlXkXkXkXlXbXbXbXbX",
"bXbXbXbXdXuXdX5Xh.B j i K vX5.2 2 f.vXvXxXkXjXdXuXrXuXdXbXbXbXbX",
"bXbXbXbXdXrXdXdX5Xw.M r d e.*.: ; 5.vXlXkX9X9X5X,X+X=X9XbXbXbXbX",
"bXbXbXbXdXdXdXdXkX,X9.v + m b * * U iXkX,X(.I.Z.v.j.F.:.bXbXbXbX",
"bXbXbXbXdXdXdXkXlXkX,X@.r a V % % # * 8 F.6.O.;.h.F.:.bXbXbXbXbX",
"bXbXbXbXjXuXkXkXkX=XT.m.] n l X.W.P.I.F.q.^ vXuXI.3.bXbXbXbXbXbX",
"bXbXbXbXdXdXjXkXkXkXkXkX=Xa. .< -XkXiX,Xv.*.uXI.6.bXbXbXbXbXbXbX",
"bXbXbXbXjXdXjXkXkXvXlXlXlX9XF.f.N.dXrX+Xa.h.W.6.bXbXbXbXbXbXbXbX",
"bXbXbXbXjXdXkXkXkXkXvXvXvXvXkX<X=XuX9X].q.F.3.bXbXbXbXbXbXbXbXbX",
"bXbXbXbXhXjXjXkXkXvXkXkXlXvXvXvXdXdX0X].m.:.bXbXbXbXbXbXbXbXbXbX",
"bXbXbXbXkXkXkXxXkXvXvXvXvXvXvXvXlXlXrX,X:.bXbXbXbXbXbXbXbXbXbXbX",
"bXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbX",
"bXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbX"
};
