/* XPM */
/* $XConsortium: Dtasys.m.pm /main/3 1995/07/18 16:29:30 drk $ */
static char * Dtasys [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 12 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconColor1	m black	c black",
"o	s iconColor5	m black	c blue",
"O    s iconGray4     m white c #949494949494",
"+    s iconGray3     m white c #adadadadadad",
"@    s iconGray7     m black c #424242424242",
"#	s iconColor7	m white	c cyan",
"$    s iconGray6     m black c #636363636363",
"%    s iconGray8     m black c #212121212121",
"&    s iconGray5     m black c #737373737373",
"*    s iconGray1     m white c #dededededede",
/* pixels */
" .............................X ",
" .oOoOoOoOoOoOoOoOoOoOoOoOoOoOX ",
" .OoOoOoOoOoOoOoOoOoOoOoOoOoOoX ",
"......oOoOoOoOoOoOoOoOoOoO.....X",
".OOOOO.oOoOoOoOoOoOoOoOoO.OOOOOX",
".OOOOOO.oOoOoOoOoOoOoOoO.OOOOOOX",
".OOOOOOO................OOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOO................OOOOOOOX",
".OOOOOO.++++++++++++++++XOOOOOOX",
".OOOOOO.+@@@@@@@@@@@@@@+X@OOOOOX",
".OOOOOO.+@#o#o#o#o#o#o.+X@OOOOOX",
".OOOOOO.+@o..#o#o#o#o#.+X@OOOOOX",
".OOOOOO.+@#.#o#o#o#o#o.+X@OOOOOX",
".OOOOOO.+@o#o#o#o#o#o#.+X@OOOOOX",
".OOOOOO.+@#o#o#o#o#o#o.+X@OOOOOX",
".OOOOOO.+@o#o#o#o#o#o#.+X@OOOOOX",
".OOOOOO.+@#o#o#o#o#o#o.+X@OOOOOX",
".OOOOOO.+@o#o#o#o#o#o#.+X@OOOOOX",
".OOOOOO.+$.............+X@OOOOOX",
".OOOOOO.++++++++++++++++X@OOOOOX",
".OOOOOOOXXXXXXXXXXXXXXXX@OOOOOOX",
".OOOOOOOO%%$$$$$$$$$$%%@@OOOOOOX",
".OOOOO%%%%XX$$$$$$$$X%%%%%@OOOOX",
".OOOO.&&&&&&&&&&&&&&&&&&&&%@OOOX",
".OOO.*.$.$.&.&.&.&.&.&.&.$*X@OOX",
".OO..$$.$.$.$.$.$.$.$.$.$.$.X@OX",
".OO*************************X@OX",
".OOXXXXXXXXXXXXXXXXXXXXXXXXXX@OX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
"XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"};
