/* XPM */
/* $XConsortium: DtCMtdo.t.pm /main/3 1995/07/18 16:20:20 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * DtCMtdo_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 11 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".    s iconGray5     m black c #737373737373",
"X    s iconGray1     m white c #dededededede",
"o	s iconColor5	m black	c blue",
"O    s iconGray4     m white c #949494949494",
"+    s iconGray3     m white c #adadadadadad",
"@    s iconGray6     m black c #636363636363",
"#	s iconColor3	m black	c red",
"$	s iconColor1	m black	c black",
"%	s iconColor6	m white	c yellow",
"&    s iconGray2     m white c #bdbdbdbdbdbd",
/* pixels */
"               .",
" XXXXXXXXXXXXXX.",
" XXoXXXoXXXXXXX.",
" XoooXoXOOXOOOX.",
" XXoooXXXXXXXXX.",
" XXXoXXXOOOXXXX.",
" XXXXXXXXXXXO+X.",
" X@@@XXXOOXO##..",
" X@O XXXXXO  .$.",
" X@  XXXXO%&.&X.",
" XXXXXXXO%&.&XX.",
" XXXXXXO%&.XXXX.",
" XXXXXO%&.&XXXX.",
" XXXXO &.&XXXXX.",
" XXXX X.XXXXXXX.",
" ....@.........."};
