/* XPM */
static char *powermanga_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #010001",
".  c #0E0E00",
"X  c #0A090A",
"o  c #08080A",
"O  c #130000",
"+  c #1D0404",
"@  c #001400",
"#  c #0C160C",
"$  c #121200",
"%  c #181800",
"&  c #180F18",
"*  c #121313",
"=  c #121C1C",
"-  c #1B1B1C",
";  c #181018",
":  c #2A0200",
">  c #240000",
",  c #3E0505",
"<  c #340A0A",
"1  c #221111",
"2  c #062706",
"3  c #1F2100",
"4  c #013A01",
"5  c #0F3604",
"6  c #152416",
"7  c #192719",
"8  c #123812",
"9  c #242400",
"0  c #2B2300",
"q  c #333300",
"w  c #3A003D",
"e  c #1C2525",
"r  c #232323",
"t  c #2A2A2B",
"y  c #372627",
"u  c #293E2A",
"i  c #333233",
"p  c #490000",
"a  c #460C0C",
"s  c #440000",
"d  c #500000",
"f  c #5A0202",
"g  c #5D0B0B",
"h  c #431415",
"j  c #521616",
"k  c #571A1E",
"l  c #6C0101",
"z  c #6C080E",
"x  c #740403",
"c  c #7E0100",
"v  c #7A0E00",
"b  c #780B0A",
"n  c #77040C",
"m  c #671C00",
"M  c #7C1500",
"N  c #690015",
"B  c #650015",
"V  c #7F0013",
"C  c #4A2015",
"Z  c #6E2300",
"A  c #6C2A00",
"S  c #633600",
"D  c #7B3C00",
"F  c #52003C",
"G  c #6A0027",
"H  c #7B0027",
"J  c #7E003A",
"K  c #4D2424",
"L  c #532727",
"P  c #423032",
"I  c #5C3534",
"U  c #0E440E",
"Y  c #015A01",
"T  c #055905",
"R  c #154D15",
"E  c #1B4D1B",
"W  c #195119",
"Q  c #244406",
"!  c #345B00",
"~  c #006900",
"^  c #08630A",
"/  c #157D00",
"(  c #167116",
")  c #2A7C00",
"_  c #254725",
"`  c #454500",
"'  c #584F00",
"]  c #5A5B00",
"[  c #4B6900",
"{  c #5C6100",
"}  c #7C6600",
"|  c #717100",
" . c #7B7B00",
".. c #2F004B",
"X. c #3A004B",
"o. c #29174B",
"O. c #290058",
"+. c #291756",
"@. c #332256",
"#. c #15006B",
"$. c #00007E",
"%. c #09007B",
"&. c #040C77",
"*. c #120079",
"=. c #00127F",
"-. c #0F1677",
";. c #29006A",
":. c #360061",
">. c #25007D",
",. c #3A0078",
"<. c #00347D",
"1. c #342262",
"2. c #470040",
"3. c #67004A",
"4. c #730444",
"5. c #7F0042",
"6. c #6B006E",
"7. c #7F006A",
"8. c #00587E",
"9. c #464646",
"0. c #4A4646",
"q. c #565454",
"w. c #5E6060",
"e. c #626464",
"r. c #6E6E6E",
"t. c #820001",
"y. c #8D0000",
"u. c #930000",
"i. c #9D0000",
"p. c #86001E",
"a. c #950013",
"s. c #961111",
"d. c #A50000",
"f. c #AC0101",
"g. c #BB0000",
"h. c #B20607",
"j. c #A4001D",
"k. c #AC1616",
"l. c #843D05",
"z. c #952116",
"x. c #920039",
"c. c #AD003F",
"v. c #C40001",
"b. c #CC0000",
"n. c #C0000B",
"m. c #D40001",
"M. c #DA0101",
"N. c #DC0808",
"B. c #D61700",
"V. c #D50015",
"C. c #EC0101",
"Z. c #E50304",
"A. c #F40000",
"S. c #FF0000",
"D. c #F6000A",
"F. c #EC1500",
"G. c #EA0012",
"H. c #EA1212",
"J. c #FD1F1F",
"K. c #D52500",
"L. c #DC2300",
"P. c #D52C00",
"I. c #C53B00",
"U. c #C60020",
"Y. c #C30034",
"T. c #CF0034",
"R. c #CF2A2A",
"E. c #EA2422",
"W. c #FC2020",
"Q. c #976A00",
"!. c #FF5000",
"~. c #950059",
"^. c #A10044",
"/. c #835555",
"(. c #955858",
"). c #C25959",
"_. c #CA6262",
"`. c #DD7575",
"'. c #078607",
"]. c #009600",
"[. c #009A00",
"{. c #0B920B",
"}. c #3B8900",
"|. c #349600",
" X c #01AD01",
".X c #02B202",
"XX c #09BA06",
"oX c #17AD17",
"OX c #27B100",
"+X c #428000",
"@X c #699600",
"#X c #4FB000",
"$X c #00C400",
"%X c #00CB00",
"&X c #15C400",
"*X c #01D601",
"=X c #11DC00",
"-X c #16D500",
";X c #2AC300",
":X c #2BD500",
">X c #01EC01",
",X c #05E800",
"<X c #15EC00",
"1X c #05F200",
"2X c #00FF00",
"3X c #0EF100",
"4X c #A4A500",
"5X c #A9AA00",
"6X c #FF9A00",
"7X c #D5B000",
"8X c #C2C200",
"9X c #CFD600",
"0X c #D1D600",
"qX c #FFDD00",
"wX c #EDEE00",
"eX c #FFEC00",
"rX c #F7F800",
"tX c #FEFD00",
"yX c #F0F100",
"uX c #010082",
"iX c #00008B",
"pX c #110081",
"aX c #00178A",
"sX c #000093",
"dX c #320084",
"fX c #00238B",
"gX c #112593",
"hX c #053C93",
"jX c #2E278D",
"kX c #0000B8",
"lX c #570482",
"zX c #690087",
"xX c #1A7A8A",
"cX c #006DB6",
"vX c #4C6C9E",
"bX c #5064A1",
"nX c #0000DA",
"mX c #0046C7",
"MX c #008FA3",
"NX c #1182BD",
"BX c #00ABB9",
"VX c #10BABC",
"CX c #7DB5B6",
"ZX c #03B2DA",
"AX c #1AD1E0",
"SX c #888989",
"DX c #959595",
"FX c #979999",
"GX c #988787",
"HX c #A4A6A6",
"JX c #B3B4B4",
"KX c #EE9F9F",
"LX c #C1B4B4",
"PX c #B7C0C0",
"IX c #DDCFCF",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX        UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX. q { } v d UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX  %  .9XqX!.M   UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX  0 8XrXtXqX}   UXUXUXUXUXUX        UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX  3 4XwXtX9X]   UXUXUXUXUX$ q { } v d UXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX$ ] 4X8X .q   UXUXUXUX  $  .9XqX!.M   UXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX$ 9 9 % . UXUXUXUXUX  9 8XrXtXqX}   UXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX  9 4XwXtX9X{   UXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX$ ] 4X8X .q   UXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX$ 9 9 % $ UXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXt X         X t UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX= e = a x c f , j L UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX@ @ @ @ @ @ @ @ @ UXP y + + : : < h L k.S.S.b.u.t.j t UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUX  X 6 T ~ ~ ~ ~ ~ ~ ~ ^ _ k x l i.m.m.m.N.N.C.S.S.A.N.u.s X UXUXUXUXUX        UXUXUX",
"UXUXUXUXUXo & E {.XX$X$X$X%X%X%X}.l.z.h.v.v.C.S.S.S.S.S.S.S.S.S.A.u., X UXUXUXUX9 ` | D l > UXUX",
"UXUXUXUXo # _ oX2X2X2X2X2X<X:X:XQ.S.C.C.C.C.A.S.S.S.S.S.S.S.S.A.M.u.a * UXUXUX  ` 5XyX6XK.: UXUX",
"UXUXUX  * _ XX3X2X2X2X2X2X@XP.P.F.C.f.u.u.u.b.D.S.S.S.S.S.S.S.b.u.t.,   UXUXUX  | wXtXeX7X0 UXUX",
"UXUXUX  6 ( >X2X2X2X2X3X@XI.S.m.j.4.2.w w w x.Y.n.M.S.S.S.S.S.v.l p : UXUXUXUX  ] 0XtXwX4X3   UX",
"UXUXUX  4 ].>X2X2X2X<X#XL.A.m.V ..uXuXiXsXuXdX6.H n.S.S.S.S.C.f.f O   UXUXUXUX  q  .8X4X] $ UXUX",
"UXUXUX  4 ].>X2X2X2X@XL.A.m.V O.%.$.$.kXnXsX%.dX6.Y.S.S.S.A.d.g 1 o UXUXUXUXUXUX. % 0 9 $ UXUXUX",
"UXUXUX- U [.>X2X<X@XI.S.S.U.3.*.jXbXNXmXkXiX$.pXzX^.b.A.Z.f.t., X   UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXi R '.*X>X;XP.S.S.C.c.lXgXvXCXAXcX$.$.uX*.6.J u.C.v.c t.s   UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUX7 8 '.[.) B.S.A.d.F gXZXVXxXhXaX$.$.uX#.G t.u.C.v.c t.l UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUX6 U Q S N.S.G.x.:.fXBXMX<.$.$.$.$.-.@.z d.v.v.d.l p UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUX- a t.M.D.G.~.,.=.8.<.$.$.$.uXpX1.I b g.M.u.c l O UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXy K t.m.C.a.X.uX=.=.$.$.$.pXlX4.b c y.u.t.t.l O UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX0./.R.A.b.J dXuXuXuX$.&.+.4.p.t.t.x x t.m q . UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXw.HX`.W.D.T.7.;.#.#.#.o.K x t.c c t.c A ! ~ @ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXe.JXIXKXW.D.V.p.B N N z x c t.c c t.Z OXXX~ @ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX9.DXPXLX_.E.S.m.v.g.u.t.t.c c c t.S |.1X%X~ @ UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXX r e.SXDXFX).H.Z.C.M.u.x c t.t.c Z |.2X2X$X~ @   UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXo * 9.r.SXFXGX(.s.u.u.t.t.c v t.Z OX3X2X2X$X~ @   UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXo - i 9.e.e.q.L z t.t.t.v [ [ |.1X2X1X%X{.W # UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX    o r t t t C m A A ' =X2X2X2X2X>X].R t UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUX    o o X X 5 / &X-X=X2X2X2X2X2X>X].4 X UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX2 Y .X>X2X2X2X2X2X,X X( 8 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX@ Y  X>X>X>X>X>X X^ u UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX@ Y ].].].].].^ 7 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX2 4 4 4 4 4 2 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX          UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
