/* XPM */
/* $XConsortium: Dthistprevi.m.pm /main/2 1996/07/23 12:12:40 drk $ */
static char * Dthistprevi_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 5 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconGray6	m black	c #636363636363",
"X	s iconGray5	m black	c #737373737373",
"o	s iconGray2	m white	c #bdbdbdbdbdbd",
"O	s iconGray4	m white	c #949494949494",
/* pixels */
"                                ",
"                                ",
"                ..              ",
"               .XXX             ",
"              .XXXo             ",
"             .XXXXo             ",
"            .XXXXo              ",
"           .o.XXo               ",
"          .X.ooo                ",
"          oXXo                  ",
"           oo                   ",
"                 ..             ",
"       ...      .XXX            ",
"      .XXXo    .XXXo            ",
"     .XXXXo   .XXXXo       o.   ",
"    ..XXXo   .XXXXo       oO.   ",
"    .XXXo   .o.XXo       oO..   ",
"   .o.Xo   ...ooo       oO.O.   ",
"  .X.oo    o..o        oO.O..   ",
"  .XXo      oo        oO.O.O.   ",
"   oo   ..           oO.O.O..   ",
"       .XXX         oO.O.O.O.   ",
"      .XXXo        oO.O.O.O..   ",
"     .XXXXo         .O.O.O.O.   ",
"    .XXXXo           .O.O.O..   ",
"   .o.XXo             .O.O.O.   ",
"  .X.ooo               .O.O..   ",
"  oXXo                  .O.O.   ",
"   oo                    .O..   ",
"                          .O.   ",
"                           ..   ",
"                                "};
