/* XPM */
/* $XConsortium: Fplock.t.pm /main/3 1995/07/18 16:59:35 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * Flock [] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X    s iconGray1     m white c #dededededede",
"o	s iconColor1	m black	c black",
"O    s topShadowColor m white c #bdbdbdbdbdbd",
"+    s iconGray8     m black c #212121212121",
"@    s iconGray2     m white c #bdbdbdbdbdbd",
"#    s iconGray6     m black c #636363636363",
"$    s iconGray4     m white c #949494949494",
/* pixels */
"                ",
"     .....      ",
"    .XXXXXoO    ",
"   .X+ooooXoO   ",
"   .XoOOOOXoO   ",
"   .XoO  .XoO   ",
"  ..XoO...X+O.  ",
"  .@@@@@@@@@@O  ",
"  .@########+O  ",
"  .@$$$$$$$$+O  ",
"  .@########+O  ",
"  .@$$$$$$$$+O  ",
"  .@oooooooo+O  ",
"  .OOOOOOOOOOO  ",
"                ",
"                "};
