/* XPM */
/* $XConsortium: Dtfpcfg.m.pm /main/3 1995/07/18 16:37:35 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * fpcfg [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 15 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray1     m white c #dededededede",
"X    s topShadowColor m white c #bdbdbdbdbdbd",
"o    s background    m black c #949494949494",
"O    s iconGray2     m white c #bdbdbdbdbdbd",
"+    s iconGray4     m white c #949494949494",
"@    s iconGray7     m black c #424242424242",
"#	s iconColor6	m white	c yellow",
"$    s iconGray3     m white c #adadadadadad",
"%	s iconColor1	m black	c black",
"&	s iconColor8	m black	c magenta",
"*	s iconColor5	m black	c blue",
"=	s iconColor3	m black	c red",
"-    s bottomShadowColor m black c #636363636363",
";    s selectColor m white c #737373737373",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                 ......         ",
"                .               ",
"               .                ",
"              .                 ",
"      ...........               ",
"     .      .    .              ",
"     .     .     .              ",
"     .     .     .         .    ",
"     .     .     .         .    ",
"     .   ..... .....     .....  ",
"     .    ...   ...       ...   ",
"           .     .         .    ",
"XXXXXXXXXXXXXXXXXXXXXoXoXoXoXoXo",
"ooooooooooooooooooooXooooooooooo",
"O+@o@#+@ooO$$ooO@+@oXoo%%%%%%o@@",
"@+ooO@++oo@@+oo+@++oXooooooooooo",
"&*+o+=*+oo@@Ooo+@*+oXooooooooooo",
"+&oo@++@oo@@@oo+@+@oX#o@@@@@@o%%",
"ooooooooooooooooooooXooooooooooo",
"--------------------------------",
";-;-;-;-;-;-;-;-;-;-;-;-;-;-;-;-",
" ; ; ; ; ; ; ; ; ; ; ; ; ; . ; ;",
"                          ...   ",
"                         .....  ",
"                           .    ",
"                           .    ",
"                                "};
