/* XPM */
/* $XConsortium: Dtshar.t.pm /main/3 1995/07/18 17:11:51 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtshar_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 8 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o    s iconGray5     m black c #737373737373",
"O    s iconGray4     m white c #949494949494",
"+	s iconColor1	m black	c black",
"@    s iconGray6     m black c #636363636363",
"#    s iconGray7     m black c #424242424242",
/* pixels */
"            ....",
" XoOXXXXXXX+....",
" XXXXXXXXXX+....",
" XoooXo@ooX+....",
" XXXXXXXXXX+....",
" X@oX@oo@XX+....",
" XXXXXXXXXX+....",
" X@@X@#X@@X+....",
" XXXXXXXXXX+....",
" XOo@Xo@o@O+....",
" XXXXXXXXXX+....",
" XOooOXoooX+....",
" XXXXXXXXXX+....",
" XXXXXXOoXX+....",
" XXXXXXXXXX+....",
" +++++++++++...."};
