/* XPM */
/* $XConsortium: terminal.pm /main/5 1996/07/23 13:53:08 drk $ */
/* Designed by the User Interaction Design Group, Hewlett-Packard */
/* Copyright (c) 1993 Hewlett-Packard */
static char *newterminal32[]={
/* width height ncolors cpp [x_hot y_hot] */
"32 32 22 1 0 0",
/* colors */
"  c none m none s none",
"$    s topShadowColor m white c #bdbdbdbdbdbd",
"&    s background    m black c #949494949494",
"(    s selectColor m white c #737373737373",
"*    s bottomShadowColor m black c #636363636363",
", s white      c white     m white",
". s iconColor1 c black     m black",
"B s iconColor2 c white     m white",
"4 s iconColor3 c red       m black",
"6 s iconColor4 c green     m white",
"8 s iconColor5 c blue      m black",
"0 s iconColor6 c yellow    m black",
"2 s iconColor7 c cyan      m white",
": s iconColor8 c magenta   m white",
"<    s iconGray1     m white c #dededededede",
">    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray3     m white c #adadadadadad",
"D    s iconGray4     m white c #949494949494",
"F    s iconGray5     m black c #737373737373",
"H    s iconGray6     m black c #636363636363",
"J    s iconGray7     m black c #424242424242",
"L    s iconGray8     m black c #212121212121",
/* pixels */
"                                ",
"                                ",
"       *****************$       ",
"      *<<<<<<<<<<<<<<<<>*$      ",
"     *,,,,,,,,,,,,,,,,,,,.$     ",
"    *,>>>>>>>>>>>>>>>>>>>>.$    ",
"    *,>HHHHHHHHHHHHHHHHHH>.$    ",
"    *,>H................,>.$    ",
"    *,>H.JJJJJJJJJJJJJJ.,>.$    ",
"    *,>H.J<J<J<J<JJJJJJ.,>.$    ",
"    *,>H.JJJJJJJJJJJJJJ.,>.$    ",
"    *,>H.JD<J<JD<J<JJJJ.,>.$    ",
"    *,>H.JJJJJJJJJJJJJJ.,>.$    ",
"    *,>H.J<D<J<J<DJJJJJ.,>.$    ",
"    *,>H.JJJJJJJJJJJJJJ.,>.$    ",
"    *,>H.JJJJJJJJJJJJJJ.,>.$    ",
"    *,>H.JJJJJJJJJJJJJJ.,>.$    ",
"    *,>H................,>.$    ",
"    *,>H,,,,,,,,,,,,,,,,,>.$    ",
"    *D>>>>>>>>>>>>>>>>>>>>.$    ",
"     $....................$     ",
"      $$$..HHHHHHHHHH..$$$      ",
"    *****...FFFFFFFF...$*****   ",
"   *FFFFFFFFFFFFFFFFFFFFFFFF.$  ",
"  *,,,F,F,F,F,F,F,F,F,,F,F,H,.$ ",
" *,,,H,H,H,H,H,H,H,H,H,,H,H,,,.$",
"*,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,.",
"*DDDDDDDDDDDDDDDDDDDDDDDDDDDDDD.",
"*...............................",
" $$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$",
"                                ",
"                                "
};
