/* XPM */
/* $XConsortium: mminicon.pm /main/2 1996/07/23 13:36:50 drk $ */
static char * MVIminWmIcon_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"50 180 29 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s topShadowColor	m white	c #bdbdbdbdbdbd",
"X	s background	m black	c #949494949494",
"o	s bottomShadowColor	m black	c #636363636363",
"O	c #4B4B4B4B4B4B",
"+	s iconColor5	m black	c blue",
"@	c #C8C8C8C8C8C8",
"#	s iconColor3	m black	c red",
"$	s iconColor8	m black	c magenta",
"%	s iconColor4	m white	c green",
"&	s iconColor7	m white	c cyan",
"*	c #E1E1E1E1E1E1",
"=	c #AFAFAFAFAFAF",
"-	c #323232323232",
";	s iconColor6	m white	c yellow",
":	s selectColor	m white	c #737373737373",
"?	c #646464646464",
">	c #E0E0E0E0E0E0",
",	c #AEAEAEAEAEAE",
"<	c #F9F9F9F9F9F9",
"1	c #C7C7C7C7C7C7",
"2	c #FFFF0000ABAB",
"3	s iconColor1	m black	c black",
"4	c #FFFF00000202",
"5	c #959595959595",
"6	c #7D7D7D7D7D7D",
"7	c #04040000FFFF",
"8	c #0909FFFF0101",
"9	c #969696969696",
/* pixels */
"                                                  ",
" ............................................     ",
" ............................................     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..Xo......................................XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXX OXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXX  + OXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXX ++++ OXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXX  +++   @OXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXX +  @@@@@@@OXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXX   @@@@@@@@@OXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXX @@@@@@@@@@@OXXXXXXXXo.XX     ",
" ..Xo.XXoooooooooo  @@@@@@@@@@@@@XXXXXXXXo.XX     ",
" ..Xo.XXoooooooo   @@@@@@@@@@@@@@XXXXXXXXo.XX     ",
" ..Xo.XXoo ##### $$$$$ %%%%% &&&&@XXXXXXXo.XX     ",
" ..Xo.XXo ##### $$$$$ %%%%% &&&&&&XXXXXXXo.XX     ",
" ..Xo.XXo****************************XXXXo.XX     ",
" ..Xo.XXo*==========================-XXXXo.XX     ",
" ..Xo.XXo*==========================-XXXXo.XX     ",
" ..Xo.XXo*======== ;#;#;;##; =======-:XXXo.XX     ",
" ..Xo.XXo*======== #;#;##;;# =======-::XXo.XX     ",
" ..Xo.XXo*======== ;#;#;;##; =======-::XXo.XX     ",
" ..Xo.XXo*======== --------- =======-o:XXo.XX     ",
" ..Xo.XXo*======== -???????? =======-ooXXo.XX     ",
" ..Xo.XXo*========           =======-ooXXo.XX     ",
" ..Xo.XXo*=========??????????=======-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XX.*==========================-ooXXo.XX     ",
" ..Xo.XXX*==========================-ooXXo.XX     ",
" ..Xo.XXX*==========================-ooXXo.XX     ",
" ..Xo.XXX*---------------------------ooXXo.XX     ",
" ..Xo.XXXXXXX:oooooooooooooooooooooooooXXo.XX     ",
" ..Xo.XXXXXXXX:ooooooooooooooooooooooooXXo.XX     ",
" ..Xo.XXXXXXXX:::::::::::::::::::::::::XXo.XX     ",
" ..Xo.oooooooooooooooooooooooooooooooooooo.XX     ",
" ..Xo......................................XX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ............................................     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXX XXXX XXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXX XXXX XXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXX XX  XX  XX XXXX XXXXXXXXX XX  XXXXXX     ",
" ..XXXXX XX  X   XX XXXX XXXX    X XX  XXXXXX     ",
" ..XXXXX XX   X  XX XXXX XXXXXXXXX XX  XXXXXX     ",
" ..XXXXX    XX    XX  XX   XX          XXXXXX     ",
" ..XXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..oooooooooooooooooooooooooooooooooooooooooo     ",
"                                                  ",
"                                                  ",
"                                                  ",
"                                                  ",
" ............................................     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..Xo......................................XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXoooooooooooooooooooooooooooXXXXo.XX     ",
" ..Xo.XXXXo>,,,,,,,,,,,,==========*O.XXXXo.XX     ",
" ..Xo.XXXXo>,,,,,,,,,,,,======* <<<<<*@XXo.XX     ",
" ..Xo.XXXXo>,,,,,,,,,O*,===<<1111$$2O11<:o.XX     ",
" ..Xo.XXXXo>,,,,,,,,,O*,==<@1;;;;22$O113:o.XX     ",
" ..Xo.XXXXo>,,,,,,,,,O*,==@11;;;41OO1113:o.XX     ",
" ..Xo.X     O,,>OOOO,O*,<@111;44153311@:Xo.XX     ",
" ..Xo.XOOOO@ O,,,,,,,O*,<1441111136@1@3XXo.XX     ",
" ..Xo.XXXXo66O,,,,,,,O*,<1443<777111111O:o.XX     ",
" ..Xo.XXXXo @OOOOOOOOO*O<13317777178781O:o.XX     ",
" ..Xo.XXXXo666@@@@@@@@@@?@@@@+++71878@@3:o.XX     ",
" ..Xo.XX*>>>>>>**999999999-3@@@@117O1@-:Xo.XX     ",
" ..Xo.XX@@@@@@@@@995555599933=@@@11@6-:XXo.XX     ",
" ..Xo.X**,?*===,?=O?99<<<<<<<<<6666OX:XXXo.XX     ",
" ..Xo.X**=?*====?=O?99<<33<33<<3999O.XXXXo.XX     ",
" ..Xo.X**,?*,,=,?=O?99<366<366<3699O.XXXXo.XX     ",
" ..Xo.X*66=66666@=O?993399<39933699O.XXXXo.XX     ",
" ..Xo.X*@@@@@@@@@,O?999699<39996699O.XXXXo.XX     ",
" ..Xo.X********>*,O-OOOOOO<3O33<<33O.XXXXo.XX     ",
" ..Xo.X**********,Oo......<3.3.<<.3..XXXXo.XX     ",
" ..Xo.X*11@1@1@1@,OoXXXXXX<3:::<<:::XXXXXo.XX     ",
" ..Xo.X*@@,@,@,@,5OoXXXXXX<3:XX<<:<<<<<XXo.XX     ",
" ..Xo.X*,,5,5,5,56OoXXXXXX<3:XX<<:33<33XXo.XX     ",
" ..Xo.X*9555555559OoXXXX<<<<<XX<<:XX<3:XXo.XX     ",
" ..Xo.X*9555555569OoXXXX33333:<<<3XX<3:XXo.XX     ",
" ..Xo.X*6666666666OoXXXXXXXXXXX:::XX333XXo.XX     ",
" ..Xo.XX666666666-ooXXXXXXXXXXXXXXXXX::XXo.XX     ",
" ..Xo.XXXooooooooo::XXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXX::::::::::XXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.oooooooooooooooooooooooooooooooooooo.XX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" .ooooooooooooooooooooooooooooooooooooooooooo     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXX   XXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXX   X  XXXXXXXXXX XXXXXXXXXXXXXXX     ",
" ..XXXXXXXXX  X     X     XXX XXX   XXXXXXXXX     ",
" ..XXXXXXXXX  XXX  XXX XX XXX XXXXXX XXXXXXXX     ",
" ..XXXXXXXXX X  X  XXXX  XXXX XXXXXXXXXXXXXXX     ",
" ..XXXXXXXXX X  X  X XX XXXXX XXX XX XXXXXXXX     ",
" ..XXXXXXXXX   XXX  XXXXXXX     X   XXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXX   XXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..oooooooooooooooooooooooooooooooooooooooooo     ",
" .ooooooooooooooooooooooooooooooooooooooooooo     ",
"                                                  ",
"                                                  ",
"                                                  ",
" ............................................     ",
" ............................................     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XoooooooooooooooooooooooooooooooooooooooXX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXooooooooooooooooooooooooXXXXXXXXo.XX     ",
" ..Xo.XXX                       .XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX *****=*?**=***=******-.XXXXXXXXo.XX     ",
" ..Xo.XXX *****-??*-?=-?=?*****-.XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX *****=**=***==*******-.XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX ****?=****-*6********-.XXXXXXXXo.XX     ",
" ..Xo.XXX ****=?=-*-=-6********-.XXXXXXXXo.XX     ",
" ..Xo.XXX ***********O33==*****-.XXXXXXXXo.XX     ",
" ..Xo.XXX ***********O=3;;=****-.XXXXXXXXo.XX     ",
" ..Xo.XXX ***********O?=*;@=***-.XXXXXXXXo.XX     ",
" ..Xo.XXX ************??**;@=**-.XXXXXXXXo.XX     ",
" ..Xo.XXX ************OO=*;;@**-.XXXXXXXXo.XX     ",
" ..Xo.XXX ************@=OO=**;@=.XXXXXXXXo.XX     ",
" ..Xo.XXX *************@=O?=*;;@=XXXXXXXXo.XX     ",
" ..Xo.XXX **************==??=*;;@XXXXXXXXo.XX     ",
" ..Xo.XXX **************@=OO?**;;=XXXXXXXo.XX     ",
" ..Xo.XXX ***************@=OO=**;@XXXXXXXo.XX     ",
" ..Xo.XXX *****************@=OO?=*;@=XXXXo.XX     ",
" ..Xo.XXX ******************@=OO?*99=@XXXo.XX     ",
" ..Xo.XXX *******************==O?=**OO9XXo.XX     ",
" ..Xo.XXX *******************@=-O?*O*OOXXo.XX     ",
" ..Xo.XXX ********************@-XO??O**XXo.XX     ",
" ..Xo.XXX........................:OO?9$OXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXX::oOOO::o.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXX::OOO::o.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXX:::::::o.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXX:::::Xo.XX     ",
" ..Xo.oooooooooooooooooooooooooooooooooooo.XX     ",
" ..Xo......................................XX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXX  XXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXX X  XX XX    XXXXXX     X    X    XXXX     ",
" ..XXXX X         XX XXXXXX  XXXX  XXX XXXXXX     ",
" ..XXXX   X  X    XX XXXXXX  XXXX  XXX XXXXXX     ",
" ..XXXX X X  X    XX XXXXXX  XXXX  XXX XXXXXX     ",
" ..XXXX XX   X    XX XXX XX  XX X   XX XX XXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..oooooooooooooooooooooooooooooooooooooooooo     ",
" .ooooooooooooooooooooooooooooooooooooooooooo     ",
"                                                  ",
"                                                  ",
"                                                  "};
