/* XPM */
static char *supertux_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #020202",
".  c #0C0C0C",
"X  c #0A0703",
"o  c #16140B",
"O  c #1F1B09",
"+  c #0C0E11",
"@  c #131313",
"#  c #141618",
"$  c #1B1B1B",
"%  c #231B10",
"&  c #3B3609",
"*  c #21201B",
"=  c #373017",
"-  c #392A1A",
";  c #1D2225",
":  c #19232C",
">  c #1D2732",
",  c #232323",
"<  c #2C2A23",
"1  c #252729",
"2  c #25292C",
"3  c #2C2C2C",
"4  c #252C33",
"5  c #2C2F33",
"6  c #2C3135",
"7  c #343434",
"8  c #3C3C3C",
"9  c #373736",
"0  c #3C3B2C",
"q  c #422F1B",
"w  c #413E34",
"e  c #5F5B06",
"r  c #6D5C1A",
"t  c #696409",
"y  c #75641B",
"u  c #7D6A1A",
"i  c #78661A",
"p  c #4D472E",
"a  c #564E2C",
"s  c #55523C",
"d  c #59563E",
"f  c #494838",
"g  c #695B2C",
"h  c #7F5A31",
"j  c #635A3B",
"k  c #6D6334",
"l  c #766623",
"z  c #384647",
"x  c #3B4F65",
"c  c #434343",
"v  c #4C4C4C",
"b  c #454749",
"n  c #575544",
"m  c #444F5A",
"M  c #434D57",
"N  c #4C565F",
"B  c #535353",
"V  c #5A5A5A",
"C  c #50565B",
"Z  c #6B6342",
"A  c #746E47",
"S  c #7B7140",
"D  c #786A57",
"F  c #475A6F",
"G  c #505B65",
"H  c #5A6169",
"J  c #5B6772",
"K  c #5A6976",
"L  c #556777",
"P  c #656565",
"I  c #6C6C6C",
"U  c #767676",
"Y  c #7E7E7E",
"T  c #806F18",
"R  c #917D1E",
"E  c #88731C",
"W  c #855F34",
"Q  c #816E25",
"!  c #897527",
"~  c #947C24",
"^  c #947F2B",
"/  c #887938",
"(  c #976D38",
")  c #9F7040",
"_  c #A97841",
"`  c #99831E",
"'  c #A69E06",
"]  c #A08A1A",
"[  c #A49815",
"{  c #B9A61A",
"}  c #998224",
"|  c #99853E",
" . c #A58C23",
".. c #AB9325",
"X. c #A8972B",
"o. c #B19E2A",
"O. c #BD8D3D",
"+. c #AF9531",
"@. c #A29334",
"#. c #B3993D",
"$. c #B4A427",
"%. c #B8A727",
"&. c #C4BC04",
"*. c #C4AB1E",
"=. c #D2BD18",
"-. c #C8A92B",
";. c #D0AE29",
":. c #D1B529",
">. c #D3B826",
",. c #CDB828",
"<. c #E1AF3E",
"1. c #E5B939",
"2. c #E9BC37",
"3. c #DBD303",
"4. c #DDCB14",
"5. c #DCC91C",
"6. c #E8D21C",
"7. c #EBD916",
"8. c #F4E60C",
"9. c #F5E909",
"0. c #F6E314",
"q. c #EACB27",
"w. c #EED02B",
"e. c #FAD62B",
"r. c #FBD82A",
"t. c #F6D02E",
"y. c #EEC533",
"u. c #F0C632",
"i. c #E8D838",
"p. c #F4D634",
"a. c #F1D539",
"s. c #8E855F",
"d. c #94844A",
"f. c #BF8C42",
"g. c #B5824A",
"h. c #A99744",
"j. c #A3985E",
"k. c #A6A15F",
"l. c #BCAE5C",
"z. c #818075",
"x. c #878A63",
"c. c #AF916E",
"v. c #BAB27B",
"b. c #CF9B49",
"n. c #C79752",
"m. c #D49D46",
"M. c #D6A243",
"N. c #CAA756",
"B. c #C4AB44",
"V. c #C0AE6D",
"C. c #CEC258",
"Z. c #E6D24A",
"A. c #DACE60",
"S. c #C7C97A",
"D. c #EAD76B",
"F. c #E4E165",
"G. c #4D6D8C",
"H. c #446F97",
"J. c #45719A",
"K. c #577592",
"L. c #697684",
"P. c #627E9B",
"I. c #5279A5",
"U. c #738594",
"Y. c #5784B5",
"T. c #7C92A8",
"R. c #7092BA",
"E. c #6386A9",
"W. c #6C9CD3",
"Q. c #769ED0",
"!. c #7BACD9",
"~. c #79A8D2",
"^. c #7AA7CD",
"/. c #67ADEF",
"(. c #6BADEF",
"). c #6EA5E4",
"_. c #77AEE9",
"`. c #7AB3E6",
"'. c #76B4ED",
"]. c #7DB9EF",
"[. c #79B7EF",
"{. c #6AA6F1",
"}. c #6AAAF1",
"|. c #72ACF1",
" X c #6EB1F0",
".X c #74B4F1",
"XX c #7DB5F2",
"oX c #7BB9F1",
"OX c #838383",
"+X c #8C8B8B",
"@X c #999685",
"#X c #868B90",
"$X c #929292",
"%X c #9A9A9A",
"&X c #9F9D95",
"*X c #A39E8C",
"=X c #9BB09F",
"-X c #A3A39E",
";X c #8194A6",
":X c #94A4AF",
">X c #91A4B5",
",X c gray65",
"<X c #ABABAB",
"1X c #B4B4B4",
"2X c #BBBBB9",
"3X c #B3BAAC",
"4X c #B7C480",
"5X c #B6C798",
"6X c #84AACB",
"7X c #95AFC7",
"8X c #9DB9C9",
"9X c #87B2D4",
"0X c #8BB1D4",
"qX c #89B4DA",
"wX c #9ABBDA",
"eX c #A4BCD8",
"rX c #8CB9E2",
"tX c #86BAE8",
"yX c #93BCE3",
"uX c #95BDE5",
"iX c #81B6F3",
"pX c #84B9F2",
"aX c #89BEF3",
"sX c #B4C1CD",
"dX c #ADC3D9",
"fX c #B3C8DB",
"gX c #A9C8C7",
"hX c #8DC1F2",
"jX c #95C5F4",
"kX c #9AC5F5",
"lX c #9CCAF4",
"zX c #A0C1E6",
"xX c #B2CDE5",
"cX c #BFD6EC",
"vX c #A1C7F6",
"bX c #A3CBF6",
"nX c #A9CDF5",
"mX c #BDD9F5",
"MX c #BFDCF8",
"NX c #C4C4C4",
"BX c #CCCCCC",
"VX c #CAD9CF",
"CX c #CBD2D8",
"ZX c #D2D2D2",
"AX c #DCDCDC",
"SX c #C2DCF4",
"DX c #C2DDF8",
"FX c #DFE5EB",
"GX c #C6E0F9",
"HX c #CCE3F9",
"JX c #D2E5F9",
"KX c #E4E4E4",
"LX c #EBEBEB",
"PX c #F4F4F4",
"IX c #FDFDFD",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXXXXXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXpXvXkXiXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXpXbXlXkXkXXXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXXXbXbXlXkXjXkX.XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX`.zXwXqXqXqXqXrXrX_.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXR.T.L.C 8 3 ; > x K.R.W.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJ.L H V B b c 7 @       > F I.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJ.m v V B v c 8 3 @           > Y.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXF v V V B v 8 5 $ . . $ @ X   X x ).UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXP.b v V B v w 5 $ . X c L.z.V ;   : Q..XUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXE.J c B V B c 9 3 $ X 8 <XLX<X+X9 + + G.pX.XUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXpXL.b b V B b c 8 3 @ @ Y LX2Xc 3 ; X   z aXpX XUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXaXeXM 9 c V B b c 8 3 $ , $XPX&X$   X   & X.S.5X8X9XUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXjXmXT.4 5 c V B b c c 5 $ @ I BX$X$ p T ] { q.p.a.Z.A.S.4XUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXaXDXmXU.; 3 c V B b c 8 3 $ X . 7 7 3 ~ -.;.y.e.e.e.e.e.e.p.a.a.UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXpXDXMXxXK # 2 8 v c 8 w 9 3 # X     @ % ( n.O.M.<.y.r.e.p.y.2.1.1.y.UXUXUXUXUXUX",
"UXUXUXUXUXUXUXjXGXDXMXT.2 + 3 c c < $ 1 3 $ .           h _ O.m.M.M.M.b.n.n.N.N.v.=XUXUXUXUXUXUX",
"UXUXUXUXUXUXjXGXDXDXxXL + @ 3 9 8 3 $ @ . .             X W ) ) _ g.c.&X:X6XqX_._.|.UXUXUXUXUXUX",
"UXUXUXUXUXhXHXGXGXmX;X5 + , 9 8 9 3 , +                     % - q D 9XpXXXoX.X.X|.|.}.UXUXUXUXUX",
"UXUXUXUXaXJXGXGXSX8Xm $ $ 9 c c 9 , # .                 X $ 9 c 9 B ^.oXoXoX.X.X.X X|./.UXUXUXUX",
"UXUXUXjXHXHXGXHXdXK ; , 7 c c 8 7 $ .                   3 P %X1X,X#XT.!.oXoX.X.X.X X X|.{.UXUXUX",
"UXUXkXHXHXHXGXcX;X4 3 9 c c c 8 9 , @ X               . V <XZXPXIXLXVX7X`.oX.X.X.X X X(.{.{.UXUX",
"UXjXJXJXJXHXGXdXN $ 9 c c c c 8 8 3 $ X           . , v %XKXIXIXIXIXIXFXzX[..X.X X X X/.}.{.{.UX",
"UXjXJXJXHXHXGX>X5 1 c v b c c 8 7 $ +       . @ # 3 P %XBXIXIXIXIXIXIXIXCXqX[..X.X X X/./.{.{.UX",
"UXUXkXJXJXHXcXU.1 9 c v v b c 8 5 .         @ c B P %XBXLXIXIXIXIXIXIXIXLXwX_..X.X X X}.{.{.UXUX",
"UXUXUXjXHXHXxXJ 1 9 c B v v c w 3 @         . 9 U -XBXKXPXPXIXIXIXIXIXIXIXsX!..X X X X|.{.UXUXUX",
"UXUXUXUXhXHXfXG 1 8 v V v c 8 3 $ . X X   . @ , b OXBXLXLXIXIXIXIXIXIXIXIXBX^.[.tX.X|.}.UXUXUXUX",
"UXUXUXUXUXhXfXJ 2 7 v V B c 5 < $ @ + @ @ @ # * , 3 P NXLXIXIXIXIXIXIXIXIXAX6XgXF.C.!.UXUXUXUXUX",
"UXUXUXUXUXVXD.h.7 7 v V v w 5 , , $ * $ * # # $ $ # $ P ZXIXIXIXIXIXIXIXIXKX3Xi.9.9.{ UXUXUXUXUX",
"UXUXUXUXUXUXB.w.o.0 c B v c 5 , $ , * , < 3 , $ # . X $ OXAXPXIXIXIXIXIXIXAXl.6.0.=.} UXUXUXUXUX",
"UXUXUXUXUXUX#.-.w...d B v c 9 , $ @ @ . # 3 c v c 7 $ @ b 2XLXPXIXIXIXIXPXBXk.5.$.~ UXUXUXUXUXUX",
"UXUXUXUXUXUXV.+.:.q.%.Z v c 8 3 * @ .     . V %X+XU.U I OXZXKXKXIXIXPXIXLX,Xj.+.~ UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXh...:.q.@.n b w 9 5 * .     + V <X1XNXBXBXNXBXAXAXLXPXPXLXAX-Xd.^ ! UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXZ |  .>.:.@.d c 8 9 3 # X   + B ,X2XBX2XBXNXBXBXZXAXKXKXKXZX*X/ UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX* j Q ..:.6.X.n c 8 7 1 +   X 9 +XNXBXBXAXBXBXBXBXZXZXAXKX2Xs./ UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUX  . < g ! ..,.6.$.d 7 < $ +     $ V 3XZXZXKXKXZXBXZXBXZXAXNX@XS UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUX  + 1 8 l ~ $.5.0.%.f . .       . 1 I &XNXBXBXZXBXNXZXBXNX@XA UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUX  X @ $ = r } >.7.7.%.e t & o     X * 3 Y $X$XOX$X+XY +Xz.A UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUX        X = r ` { 5.9.3.3.&.' t o       $ * 1 3 1 , < a k UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXu E ~ [ { 4.4.8.[ @               O y Q l UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXy y y i i u T x.uXyXrXrXrXA r r r y i UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXiXnXbXbXlXlXkXkXkX'.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXXXnXbXlXlXlXkX'.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXpXbXlXlXkXiXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXpXbXkXiXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXiXiXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
