/* XPM */
/* $XConsortium: Dteditqry.l.pm /main/2 1996/10/29 15:51:34 drk $ */
static char * Dteditqry_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 14 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #bdbdbdbdbdbd",
"o	s iconGray6	m black	c #636363636363",
"O	s iconGray5	m black	c #737373737373",
"+	s iconColor1	m black	c black",
"@	s iconGray4	m white	c #949494949494",
"#	s iconColor3	m black	c red",
"$	s iconGray1	m white	c #dededededede",
"%	s bottomShadowColor	m black	c #636363636363",
"&	s iconColor6	m white	c yellow",
"*	s iconGray7	m black	c #424242424242",
"=	s iconColor5	m black	c blue",
"-	s iconGray3	m white	c #adadadadadad",
/* pixels */
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"  .................................             ",
"  .XXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXo         X   ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+o       XX@  ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+oo     X#.$@ ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+oo+   X###@$@",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+oo+%  +###OOX",
"  .XXOXXX+++++X++X+++XX+++X++XXXXX+oo+% &@+####o",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+oo+%&&@@+##+o",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+ooo&&.&XO++o ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+oo&&.&XO&*O  ",
"  .XXOXXXXXXXX======XXXXXXXXXXXXXX+o&&.&XO&*O   ",
"  .XXOXXXXXXX========XXXXXXXXXXXXXo&&.&XO&*O    ",
"  .XXOXXXXXX==========XXXXXXXXXXXX&&.&XO&*O     ",
"  .XXOXXXXXX====XX====XXXXXXXXXXX&&.&XO&*O      ",
"  .XXOXXXXXX===XXX====XXXXXXXXXX&&.&XO&*O       ",
"  .XXOXXXXXX===XXX====XXXXXXXXX&&.&XO&*O        ",
"  .XXOXXXXXX===XXX====XXXXXXXX&&.&XO&*O         ",
"  .XXOXXXXXXXXXXX====XXXXXXXX&&.&XO&*O%         ",
"  .XXOXXXXXXXXXX====XXXXXXXX&&.&XO&*O+%         ",
"  .XXOXXXXXXXXXX====XXXXXXX&&.&XO&*O++%         ",
"  .XXOXXXXXXXXXX====XXXXXX&&.&XO&*Oo++%         ",
"  .XXOXXXXXXXXXXXXXXXXXXX&&.&XO&*O+o++%         ",
"  .XXOXXXXXXXXXXXXXXXXXX&&.&XO&*OX+o++%         ",
"  .XXOXXXXXXXXXX====XXX&&.&XO&*OXX+o++%         ",
"  .XXOXXXXXXXXXX====XXX$.&XO&*OXXX+o++%         ",
"  .XXOXXXXXXXXXX====XX-$OXO&*OXXXX+o++%         ",
"  .XXOXXXXXXXXXX====X-o$oO&*OXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXXXo$$XX*OXXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXXOOX$XoOXXXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXXoo+++OXXXXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXX++OOXXXXXXXXXX+o++%         ",
"  .XXOXXXXXXXXXOOOO++ooXXXXXXXXXXX+o++%         ",
"  .XXOXXXXX++++++++++++++++XXXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+o++%         ",
"  .XXOXXXXXXXXXXXXXXXXXXXXXXXXXXXX+o++%         ",
"  .++++++++++++++++++++++++++++++++o++%         ",
"  .+oooooooooooooooooooooooooooooooo++%         ",
"  .++ooooooooooooooooooooooooooooooo++%         ",
"   ..+++++++++++++++++++++++++++++++++%         ",
"    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%         ",
"                                                "};
