/* XPM */
/* $XConsortium: Dtkey.t.pm /main/3 1995/07/18 16:43:00 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtkey_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 7 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray1     m white c #dededededede",
"+    s iconGray6     m black c #636363636363",
"@    s iconGray4     m white c #949494949494",
/* pixels */
"             ...",
" XXXXXXXXXXXo...",
" XXXXXXOOOOXo...",
" XXXXXO+++OOo...",
" XX@+O++X++Oo...",
" XXXXO+++++Oo...",
" XX+@@+++++Oo...",
" XXXXXO+++OXo...",
" XX++@O@+OOXo...",
" XXXXXO@++OXo...",
" XX@+@O@+OXXo...",
" XXXXXO@++OXo...",
" XXo@+O@+OXXo...",
" XXXXXXOXXXXo...",
" XXXXXXXXXXXo...",
" oooooooooooo..."};
