/* XPM */
/* $XConsortium: textpi.pm /main/1 1996/03/09 20:13:03 rws $ */
static char * text_pane_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 32 11 1 0 0",
/* colors */
" 	s iconColor1	m black	c black",
".    s iconGray4     m white c #949494949494",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o    s iconGray1     m white c #dededededede",
"O    s iconGray6     m black c #636363636363",
"+	s iconColor2	m white	c white",
"@    s iconGray3     m white c #adadadadadad",
"#	c #B7B7B7B7B7B7",
"$    s iconGray8     m black c #212121212121",
"%    s iconGray5     m black c #737373737373",
"&	c #8C8C8C8C8C8C",
/* pixels */
"                                          .     ",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXX+++++++++++++++++++XXXXXXXXXXXXXXXXXXo. @#$X",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. @%$X",
" XXX+++++++++++XXXXXXXXXXXXXXXXXXXXXXXXXXo. @%$X",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. @%$X",
" XXX++++++++++++++++XXXXXXXXXXXXXXXXXXXXXo. @%$X",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. @%$X",
" XXX+++++++++++++++++++++XXXXXXXXXXXXXXXXo. @%$X",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. @%$X",
" XXX+++++++++XXXXXXXXXXXXXXXXXXXXXXXXXXXXo. @%$X",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. @%$X",
" XXX++++++++++++XXXXXXXXXXXXXXXXXXXXXXXXXo.    X",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXX+++++++++++++++XXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo. OOOX",
" ooooooooooooooooooooooooooooooooooooooooo& OOOX",
".........................................&..XXXX",
"                                          ......",
" OOOOOOOOOOXXXXXXXXXXXXXXXXXXXX$OOOOOOOOOOX.....",
" OOOOOOOOOOX...................$OOOOOOOOOOX.....",
" OOOOOOOOOO$$$$$$$$$$$$$$$$$$$$$OOOOOOOOOOX.....",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX....."};
