/* XPM */
/* $XConsortium: Dtviewi.m.pm /main/2 1996/07/23 12:24:48 drk $ */
static char * Dtviewi_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 5 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconGray3	m white	c #adadadadadad",
"X	s iconGray4	m white	c #949494949494",
"o	s iconGray5	m black	c #737373737373",
"O	s iconGray6	m black	c #636363636363",
/* pixels */
"                                ",
"                                ",
" ..............   ..............",
" ..XoXoXoXoXoXo   .XoXoXoXoXoXoo",
" ..oXoXoXoXoXoo   .XXoXoXoXoXooo",
" ..XoXoXoXoXoXo   .XoXoXoXoXoXoo",
" ..oXoXoXoXoXoo   .XXoXoXoXoXooo",
"  ............o   ............o ",
"  ..ooooooooooo   .Xooooooooooo ",
"  ..oXoXoXoXooo   .XoXoXoXoXooo ",
"  ..XoXoXoXoXo.....XXoXoXoXoXoo ",
"  ..oXoXoXoXooXXXXXXoXoXoXoXooo ",
"  ..XoXoXoXoXoooooXoXoXoXoXoXoo ",
"  ..oXoXoXoXoooooooXoXoXoXoXooo ",
"  ..XoXoXoXoXoo...XoXoXoXoXoXoo ",
"  ..oXoXoXoXooo...oXoXoXoXoXooo ",
"  ..XoXoXoXoXoo...XoXoXoXoXoXoo ",
"   ..XoXoXoXoXoXoXoXoXoXoXoXoo  ",
"   ..oXoXoXoXoXoXoXOXoXoXoXooo  ",
"   ..XoXoXoXooooooo..XoXoXoXoo  ",
"   ..oXoXoXooo     ..oXoXoXooo  ",
"   ..XoXoXoXoo     ..XoXoXoXoo  ",
"   ..oXoXoXooo     ..oXoXoXooo  ",
"   ..XoXoXoXoo     ..XoXoXoXoo  ",
"   ..oXoXoXoo       ..XoXoXooo  ",
"   ..XoXoXooo       ..oXoXoXoo  ",
"   .........o       ........o   ",
"    ..ooooooo       ..ooooooo   ",
"    ..XoXoXoo       ..XoXoXoo   ",
"    ..oXoXooo       ..oXoXoXo   ",
"    ooooooooo       ooooooooo   ",
"                                "};
