/* XPM */
/* $XConsortium: startup.pm /main/2 1996/07/23 13:43:07 drk $ */
static char * StartuOL [] = {
/* width height ncolors cpp [x_hot y_hot] */
"64 37 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X    s iconGray1     m white c #dededededede",
"o    s iconGray5     m black c #737373737373",
"O	s iconColor2	m white	c white",
"+    s iconGray8     m black c #212121212121",
"@    s iconGray7     m black c #424242424242",
"#	s iconColor1	m black	c black",
"$    s topShadowColor m white c #bdbdbdbdbdbd",
/* pixels */
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"         ...............                                        ",
"        .XXXXXXXXXXXXXXX.                                       ",
"       .XXoXoXoXoXoXoXoXo.                                      ",
"      .XoXoXoXoXoXoXoXoXoo............................          ",
"      .XoXoXoXoXoXoXoXoXooOOOOOOOOOOOOOOOOOOOOOOOOOOOO.         ",
"      .Xo+++++oXoXoXoXoXoo++++++++++++++++++++++++@++++.        ",
"      .Xo+   XoXoXoXoXoXooXXXXOOXXXXXXXOOXXXXXXXXOOOXXX.        ",
"      .Xo+   XoXoXoXoXoXoo#######################++++++.        ",
"      .Xo+   XoXoXoXoXoXooXXXXXXXXXXXXXXXXXXXXXXXXXXX$$         ",
"      .Xo+   XoXoXoXoXoXooXXOOOXOOOOOXXOO++XXO++OX++$$          ",
"      .Xo+   XoXoXoXoXoXooXXO++OOO+++OOO+$+OO++$+O+$$           ",
"      .Xo+   XoXoXoXoXoXooXO++++O++$$+++$ $++$$ $$$$            ",
"      .Xo+   XoXoXoXoXoXooO++$$+++$ $$$$   $$                   ",
"      .Xo+XXXXoXoXoXoXoXo+++$  $$$                              ",
"      .XoXoXoXoXoXoXoXoXo+$$                                    ",
"      .XoXoXoXoXoXoXoXoXo+$                                     ",
"       .oXoXoXoXoXoXoXoXo+$                                     ",
"        $++++++++++++++++$                                      ",
"         $$$$$$$$$$$$$$$$                                       ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                "};
