/* XPM */
/* $XConsortium: Dtaexfl.m.pm /main/2 1996/07/23 12:02:07 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtaexfl_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 13 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s background	m black	c #969696969696",
"X	s iconGray2	m white	c #c8c8c8c8c8c8",
"o	s iconColor1	m black	c black",
"O	s iconGray7	m black	c #4b4b4b4b4b4b",
"+	s iconGray6	m black	c #646464646464",
"@	s iconGray3	m white	c #afafafafafaf",
"#	s iconGray1	m white	c #e1e1e1e1e1e1",
"$	s iconGray8	m black	c #323232323232",
"%	s iconGray5	m black	c #7d7d7d7d7d7d",
"&	s iconColor5	m black	c blue",
"*	s iconColor6	m white	c yellow",
"=	s iconGray4	m white	c #969696969696",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXooXoOOXXOOXOOXooXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX++++XoOoOOXooXOooXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX++++XXoOXoXooOooXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX+++XXOXXoOOooXooOOXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXoooXXoXoOOoXXOOXoXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX+++++oXOooXooOOoooXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX++++@OOooXOOOOXooXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XX                             ",
" XX ###########################$",
" XX #%#@#%O%#&&&&&&&&&&##%##%##$",
" XX %*%##OOO#&&&&&&&&&&#%%###%#$",
" XX +%+@#%O%#&&&&&&&&&&##%##%##$",
" XX ##########=###=###=########$",
" XX $$$$$$$$$$$$$$$$$$$$$$$$$$$$",
" XXX=====================.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
