/* XPM */
/* $XConsortium: rectang.pm /main/2 1996/07/23 13:02:27 drk $ */
static char * IEtRecta [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 4 1 0 0",
/* colors */
" 	s iconGray2	m white	c #c8c8c8c8c8c8",
".	s iconGray4	m white	c #969696969696",
"X	s iconGray3	m white	c #afafafafafaf",
"o	s iconColor1	m black	c black",
/* pixels */
"                                    ",
"                                   .",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXoooooooooooooooooooooooXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoooooooooooooooooooooooXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  ..................................",
" ..................................."};
