/* XPM */
/* $XConsortium: Dtgraphmap.m.pm /main/3 1996/07/23 12:10:45 drk $ */
static char * Dtgraphmap1_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 5 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconGray1	m white	c #dededededede",
"X	s iconGray5	m black	c #737373737373",
"o	s iconGray8	m black	c #212121212121",
"O	s iconGray7	m black	c #424242424242",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                        ....... ",
"                        .XXXXXo ",
"                    OOOO.XXXXXo ",
"           .......  O   .XXXXXo ",
"           .XXXXXo  O   ooooooo ",
"         OO.XXXXXoOOO           ",
"         O .XXXXXo  O   ....... ",
"         O ooooooo  O   .XXXXXo ",
"         O          OOOO.XXXXXo ",
"         O              .XXXXXo ",
" ....... O              ooooooo ",
" .XXXXXo O                      ",
" .XXXXXoOO                      ",
" .XXXXXo O                      ",
" ooooooo O              ....... ",
"         O              .XXXXXo ",
"         O          OOOO.XXXXXo ",
"         O .......  O   .XXXXXo ",
"         O .XXXXXo  O   ooooooo ",
"         OO.XXXXXoOOO           ",
"           .XXXXXo  O   ....... ",
"           ooooooo  O   .XXXXXo ",
"                    OOOO.XXXXXo ",
"                        .XXXXXo ",
"                        ooooooo ",
"                                ",
"                                "};
