/* XPM */
/* $XConsortium: locked.pm /main/2 1996/07/23 12:25:58 drk $ */
static char * pinin_xpm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"30 17 7 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s iconGray6	m black	c #636363636363",
"X	s iconColor1	m black	c black",
"o	s iconGray1	m white	c #dededededede",
"O	s iconGray2	m white	c #bdbdbdbdbdbd",
"+	s iconGray4	m white	c #949494949494",
"@	s iconGray7	m black	c #424242424242",
/* pixels */
"            ...               ",
"         X..oOo..             ",
"       XXXooOoOoOX            ",
"      X++.oOoOoOoX            ",
"     X++XoOoOoOoOoX           ",
"     X++XOoOoOoOoOX           ",
"    X+++XoOoOoOoOoX           ",
"    X.++X.oOoOoOo.X           ",
"    X+.++XOoOoOooX            ",
"    XX+.+XX.oOo.XX            ",
"     X@+.+.XXXX.X             ",
"     X.@+.+.+.+.X             ",
"     XX.@......X              ",
"    XXXXXXXXXXX               ",
"   XXX                        ",
"   XX                         ",
"                              "};
