/* XPM */
/* $XConsortium: Dtload.m.pm /main/3 1995/07/18 16:43:43 drk $ */
static char * Dtload_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 7 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".    s iconGray1     m white c #dededededede",
"X    s iconGray3     m white c #adadadadadad",
"o	s none	m none	c none",
"O    s iconGray8     m black c #212121212121",
"+	s iconColor7	m white	c cyan",
"@    s iconGray5     m black c #737373737373",
/* pixels */
" ...............................",
" XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoO",
" oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXO",
" XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoO",
" oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXO",
" XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoO",
" oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXO",
" XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoO",
" oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXO",
" XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoO",
" oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXO",
" XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoO",
" oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXO",
" XoXoXoXoXoXoXoXoXoXoXoXo++XoXoO",
" oXoXoXoXoXoXoXoXoXoXoXoX@@oXoXO",
" XoXoXoXoXoXoXoXoXoXoXoXo++XoXoO",
" ..............................O",
" XoXoXoXoXoXoXoXoXoXoXoo++++oXoO",
" oXoXoXoXoXoXoXoXoXoXoXo@@@@XoXO",
" XoXoX++oXoXoXoXoXoXoXo++++++XoO",
" oXoXo@@XoXoXoXoXoXoXoX@@@@@@oXO",
" XoXo+++++oXoXoXoXoXoX+++++++XoO",
" oXoX@@@@@XoXoXoXoXoXo@@@@@@@oXO",
" X+++++++++++XoXoXoX++++++++++oO",
" o@@@@@@@@@@@oXoXoXo@@@@@@@@@@XO",
" ++++++++++++++++++++++++++++++O",
" @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@O",
" ++++++++++++++++++++++++++++++O",
" @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@O",
" ++++++++++++++++++++++++++++++O",
" @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@O",
" OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO"};
