/* XPM */
/* $XConsortium: helpmgr.pm /main/2 1996/07/23 13:20:38 drk $ */
/* Designed by the User Interaction Design Group, Hewlett-Packard */
/* Copyright (c) 1993 Hewlett-Packard */
static char *help48[]={
/* width height ncolors cpp [x_hot y_hot] */
"48 48 22 1 0 0",
/* colors */
"  c none m none s none",
"$    s topShadowColor m white c #bdbdbdbdbdbd",
"&    s background    m black c #949494949494",
"(    s selectColor m white c #737373737373",
"*    s bottomShadowColor m black c #636363636363",
", s white      c white     m white",
". s iconColor1 c black     m black",
"B s iconColor2 c white     m white",
"4 s iconColor3 c red       m black",
"6 s iconColor4 c green     m white",
"8 s iconColor5 c blue      m black",
"2 s iconColor6 c yellow    m white",
": s iconColor7 c cyan      m white",
"0 s iconColor8 c magenta   m black",
"<    s iconGray1     m white c #dededededede",
">    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray3     m white c #adadadadadad",
"D    s iconGray4     m white c #949494949494",
"F    s iconGray5     m black c #737373737373",
"H    s iconGray6     m black c #636363636363",
"J    s iconGray7     m black c #424242424242",
"L    s iconGray8     m black c #212121212121",
/* pixels */
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"           *********                            ",
"           *F@>DDFJ$             **********     ",
"           *H@:@:JJ*********     *@>@@@@FL$     ",
"     ******LH:D:F4JLDDDDDDHJ*****LFDDDDFHL$     ",
"     *<<<>@LHF:F4JJLDFHFFFHJL@8@8LHF>D@DFL$     ",
"     *<>@DFLH:D:F4JLDFFFFFHJL8@JHLHFDDFFJL$     ",
"     *<>@DFLHF:F4JJLDFFFFFHJLJHF8LHF@DFFFL$     ",
"     *<DFHFLH:D:F4JLDFFFFFHJL8@JHLHFDDFFFL$     ",
"     *<DFHFLHF:F4JJLBBBBBBBJLJHJ8LHFDJFFFL$     ",
"     *<>@DFLH:J:L4JBBBBBBBBBL8@JHLHFDDFFFL$     ",
"     *<DFHFLHF:L4JBBBBFFFBBBBJHJ8LHFDHFFFL$     ",
"     *<D@HFLH:D:F4BBBFFFFFBBB8@JHLHFDJFFFL$     ",
"     *<>@DFLHF:F4JBBBFFFFFBBBJHJ8LHFDHFFFL$     ",
"     *<DFHFLH:D:F4BBBFFFFFBBB8@JHLHFDJFFFL$     ",
"     *<>@DFLHF:L4JJLDFFFFBBBBJHF8LHFDHFFFL$     ",
"     *<DFHFLH:J:L4JLDFFFBBBBL8@JHLHFDDFFFL$     ",
"     *<D@DFLHF:F4JJLDFFBBBBJLJHF8LHFDDFFFL$     ",
"     *<DFHFLH:J:L4JLDFBBBBHJL8@JHLHFDHFFFL$     ",
"     *<>@DFLHF:L4JJLDFBBBFHJLJHF8LHFDFFFFL$     ",
"     *<>@DFLH:D:F4JLDFBBBFHJL8@JHLHFDDFFFL$     ",
"     *<>@DFLHF:F4JJLDFFFFFHJLJHF8LHFDDFFFL$     ",
"     *<>@DFLH:D:F4JLDFBBBFHJL8@JHLHFDDFFFL$     ",
"     *<>@DFLHF:F4JJLDHBBBJHJLJHF8LHFDDFFFL$     ",
"     *<>@DFLH:D:F4JLDFBBBFHJL8@JHLHFDDFFFL$     ",
"     *<>@DFLHF:F4JJLDHHFJJHJLJHF8LHFDJFFFL$     ",
"     *<@FHFLH:D:F4JLDFFFFFHJL8@JHLHFDDFFFL$     ",
"     *<>@DFLHF:F4JJLDHFJJJHJLJHF8LHFDDFFFL$     ",
"     *<>@DFLH:D:F4JLDFFFFFHJL8@JHLHFDDFFFL$     ",
"     *<>@DFLHF:F4JJLDFFFFFHJLJHF8LHHDDFFFL$     ",
"     *>>@DFLH:D:F4JLDFFFFFHJL8@JHLHFDDFFFL$     ",
"     *@@DFFLHFFFHHJLDHFFHJHJLJHJ8LHHFFFHHL$     ",
"     *LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL$     ",
"     *$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$     ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                "
};
