/* XPM */
/* $XConsortium: prticon.pm /main/2 1996/07/23 13:40:43 drk $ */
static char * Fprnt_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 13 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray1     m white c #dededededede",
"o    s iconGray2     m white c #bdbdbdbdbdbd",
"O    s bottomShadowColor m black c #636363636363",
"+    s topShadowColor m white c #bdbdbdbdbdbd",
"@    s iconGray7     m black c #424242424242",
"#    s iconGray5     m black c #737373737373",
"$    s iconGray4     m white c #949494949494",
"%    s iconGray6     m black c #636363636363",
"&    s iconGray8     m black c #212121212121",
"*    s iconGray3     m white c #adadadadadad",
"=    s selectColor m white c #737373737373",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"       ............X            ",
"       .oooooooooo.X            ",
"   OOOO..o.o.oo.....OOOOOOO+    ",
"  OO.oo.ooo.oo.ooo..Xoooooo@+   ",
" OO.o#$XXXXXXXXXXXXX$oXooooo@+  ",
" O.oo%################.oooooo@+ ",
" O.XXXXXXXXXXXXXXXXXXXXXXXXXX@+ ",
" O.oXXXXXXXXXXXXXXXXXX%%%%%%o@+ ",
" O.oXXXXXXXXXXXXXXXXXX%####%o@+ ",
" O.oo#################%%%%%%o@+ ",
" O.oooooooooooooooooooooooooo@+ ",
" O.oooooooooooooooooooooooooo@+ ",
" O.oo&&&&&&&&&&&&&&&&&&oooooo@+ ",
" O.oo&$###############&oooooo@+ ",
" O.&&*.################&&&&&&@+ ",
"  O*@$#################@@@@&+++ ",
"   *&&&&&&&&&&&&&&&&&&&&&&&&+   ",
"     &&&&&&&&&&&&&&&&&&O=+++    ",
"     OOOOOOOOOOOOOOOOOOO=       ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                "};
