/* XPM */
/* $XConsortium: Dtdtksh.t.pm /main/3 1995/07/18 16:37:12 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtdtksh_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 9 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray4     m white c #949494949494",
"+    s iconGray3     m white c #adadadadadad",
"@	s iconColor6	m white	c yellow",
"#    s iconGray1     m white c #dededededede",
"$    s iconGray5     m black c #737373737373",
/* pixels */
"             ...",
" XXXXXXXXXXXo...",
" XXXOOXOOXXXo...",
" XXOXOXOXOXXo...",
" XOOOOXOOOOXo...",
" OOXO  +  OOo...",
" OOO +@+@+ Oo...",
" XO  +#+#+# o...",
" X @+#@+@ +@ ...",
" X X@ +@+#@#@...",
" X$$X@+X+@#+ ...",
" XX$@X#@# @#o...",
" XXX$$@+@+$$o...",
" XXXX@+@+@$Xo...",
" XXXX$$@$$$Xo...",
" oooooooooooo..."};
