/* XPM */
static char *tuxpaint_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 231 2 ",
"   c black",
".  c #010100",
"X  c #010101",
"o  c #030200",
"O  c #020202",
"+  c gray1",
"@  c #040300",
"#  c #060400",
"$  c gray2",
"%  c #060606",
"&  c #080600",
"*  c #090700",
"=  c #0A0703",
"-  c gray4",
";  c #0B0B0B",
":  c gray5",
">  c #0E0E0E",
",  c gray6",
"<  c #120D00",
"1  c #1A1300",
"2  c #1F1600",
"3  c gray7",
"4  c #131313",
"5  c #161616",
"6  c #1D1A14",
"7  c gray11",
"8  c #1D1D1D",
"9  c #1E1E1E",
"0  c #231A00",
"q  c #241A00",
"w  c #271D00",
"e  c #2A1F00",
"r  c #221B11",
"t  c #2B2000",
"y  c #2A2108",
"u  c #2B2209",
"i  c #2C210C",
"p  c #3A2B00",
"a  c #3E2E00",
"s  c gray13",
"d  c #252525",
"f  c gray15",
"g  c gray17",
"h  c gray18",
"j  c #2F2F2F",
"k  c #323232",
"l  c gray20",
"z  c #373737",
"x  c gray22",
"c  c #393939",
"v  c #3A3A3A",
"b  c gray23",
"n  c #433100",
"m  c #443200",
"M  c #533D00",
"N  c #493613",
"B  c #7B1D3C",
"V  c #524118",
"C  c #5E491A",
"Z  c #614800",
"A  c #624800",
"S  c #684D00",
"D  c #6D531F",
"F  c #785F17",
"G  c #644631",
"H  c #754530",
"J  c #765F3C",
"K  c #444444",
"L  c #464646",
"P  c #4C4C4C",
"I  c #4E4E4E",
"U  c #535353",
"Y  c gray33",
"T  c #565656",
"R  c gray34",
"E  c #585858",
"W  c #5B5B5B",
"Q  c gray36",
"!  c gray38",
"~  c #626262",
"^  c gray39",
"/  c #686868",
"(  c gray42",
")  c #717171",
"_  c gray46",
"`  c #777777",
"'  c gray47",
"]  c gray49",
"[  c #886400",
"{  c #81661B",
"}  c #A47900",
"|  c #AA7E00",
" . c #806120",
".. c #9A7524",
"X. c #846834",
"o. c #94753E",
"O. c #A27C25",
"+. c #831E41",
"@. c #841F41",
"#. c #871F43",
"$. c #8F2247",
"%. c #99254D",
"&. c #9B254E",
"*. c #9E2650",
"=. c #A22852",
"-. c #AE2B59",
";. c #B12C5B",
":. c #B22E5C",
">. c #B52D5D",
",. c #AB3760",
"<. c #BD3062",
"1. c #C03163",
"2. c #C23164",
"3. c #C53267",
"4. c #CC346B",
"5. c #D73770",
"6. c #DB3B75",
"7. c #E23B77",
"8. c #955445",
"9. c #904850",
"0. c #A7516F",
"q. c #B78700",
"w. c #B88800",
"e. c #A98226",
"r. c #B78E28",
"t. c #BB9129",
"y. c #BD963B",
"u. c #C59100",
"i. c #C69200",
"p. c #C79300",
"a. c #D29B00",
"s. c #D49D00",
"d. c #D59D00",
"f. c #D69E00",
"g. c #DCA200",
"h. c #DDA300",
"j. c #E4A800",
"k. c #E8AB00",
"l. c #EBAD00",
"z. c #F1B200",
"x. c #F3B300",
"c. c #F4B400",
"v. c #F6B500",
"b. c #F7B600",
"n. c #F9B800",
"m. c #FBB900",
"M. c #FCBA00",
"N. c #FEBB00",
"B. c #FFBC00",
"V. c #F1B91B",
"C. c #C79C2C",
"Z. c #D5A929",
"A. c #D3A731",
"S. c #E1B22D",
"D. c #E8B82F",
"F. c #F3C130",
"G. c #B7A05F",
"H. c #C39C5C",
"J. c #D2A764",
"K. c #BE6B88",
"L. c #B1778A",
"P. c #E07199",
"I. c #808080",
"U. c gray51",
"Y. c gray52",
"T. c #868686",
"R. c gray54",
"E. c #8D8D8D",
"W. c gray59",
"Q. c #989898",
"!. c #9B9B9B",
"~. c gray61",
"^. c #A0A0A0",
"/. c gray64",
"(. c gray65",
"). c #AAAAAA",
"_. c gray67",
"`. c gray70",
"'. c #B9B9B9",
"]. c gray",
"[. c gray75",
"{. c #C6B687",
"}. c #C6BA97",
"|. c #CEBE9F",
" X c #D496AC",
".X c #F48FB3",
"XX c #D6A0B3",
"oX c #C1B7BA",
"OX c #E0ABBE",
"+X c #E3AABE",
"@X c #CFC8B5",
"#X c #D7CEB3",
"$X c #C1C1C1",
"%X c gray76",
"&X c #C5C5C5",
"*X c #CBC8C1",
"=X c #CBCBCB",
"-X c #CDCDCD",
";X c #CECECE",
":X c #D2D2D2",
">X c gray83",
",X c gray84",
"<X c #D7D7D7",
"1X c gray87",
"2X c #DFDFDF",
"3X c #E2CAD2",
"4X c #EDDAE1",
"5X c #E4E4E4",
"6X c #EFE4E8",
"7X c #E9E9E9",
"8X c #F9E5EC",
"9X c #F2F1EE",
"0X c #F7EDF0",
"qX c gray94",
"wX c #F1F1F1",
"eX c #F4F4F4",
"rX c gray96",
"tX c #F6F6F6",
"yX c #F8F8F8",
"uX c #F9F9F9",
"iX c #FAFAF9",
"pX c gray98",
"aX c #FBFBFB",
"sX c #FCF9FA",
"dX c #FEF9FB",
"fX c gray99",
"gX c #FDFDFD",
"hX c #FEFCFD",
"jX c #FEFEFE",
"kX c gray100",
"lX c None",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX        lXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX                lXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX                      lXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX                      lXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX  c c     ; I l           lXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXW.kXkXE.3 2XkXkXW.        lXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXE kXkXkX7X` kXkXkXkXl         lXlXlXlXlXlXlXlX",
"lXlXlXlX          lXlX  lXlXlXlXlXlXlXlXlXlXlXlXlX/.qX,XkXtX,XkXkXkXkX`         lXlXlXlXlXlXlXlX",
"lXlXlX                    lXlXlXlXlXlXlXlXlXlXlXlX=XR > aXkXkXqXtXkXkX]         lXlXlXlXlXlXlXlX",
"lXlX                      lXlXlXlXlXlXlXlXlXlXlX  ,XU.E kXkXaXd Q kXkX!           lXlXlXlXlXlXlX",
"lX                        lXlXlXlXlXlXlXlXlXlXlX  [.kXkXkXkX,X  U kXkX9           lXlXlXlXlXlXlX",
"lX                          lXlXlXlXlXlXlXlX@ p A { {.*X'.aXaXE ;XkX(.            lXlXlXlXlXlXlX",
"                            lXlXlXlXlXlXlXm h.B.B.B.B.v.q.G.9XkXkX2X3             lXlXlXlXlXlXlX",
"                              lXlXlXlXlXa M.B.B.B.B.B.B.B.B.V.}.&Xj               lXlXlXlXlXlXlX",
"                                lXlXlXlXi.B.g.s.B.B.B.B.B.B.B.k.2                 lXlXlXlXlXlXlX",
"lX                                lXlXw B.M.0 m B.B.B.B.B.B.B.B.}                 lXlXlXlXlXlXlX",
"lXlXlXlX                              n B.a.  M B.B.B.B.B.B.B.B.c.@               lXlXlXlXlXlXlX",
"lXlXlXlXlXlX                          q B.k.1 i.B.B.B.B.B.B.B.B.M.@               lXlXlXlXlXlXlX",
"lXlXlXlXlXlXlX                          s.B.B.B.B.B.B.B.B.B.B.B.i.                lXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlX                      t s.B.B.B.B.B.B.B.B.B.B.S                 lXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlX                      * [ v.B.B.B.B.B.B.B.h.*                 lXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlX                        < A | h.z.z.j.w.t                     lXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlX                                                            lXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX                                                          lXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlX                4 I ! I 3                                 lXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX            ) aXkXkXkXtXT.                                lXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX        d kXkXkXkXkXkXkXE.                                lXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX          ( kXkXkXkXkXkXkXaX9       ! c                       lX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX          !.kXkXkXkXkXkXkXkX'       L (                       lX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlX        c /.kXkXkXkXdXOXK.0.L.oX      $ `.>                       ",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX        R.kXkXkXkXkXsXP.2.-.&.+.9.J r     h _.$                     ",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX      c kXkXkXkXkXkX.X7.4.>.*.#.8.H.J.y.F y L U.                    ",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX      W.kXkXkXkXkX8X6.5.3.;.&.+.H X.o.A.D.F.Z.#X                    ",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX      ;XkXkXkXkXkX+X<.<.:.=.$.B G V C ..e.t.C.@X                  lX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX      5XkXkXkXkXkXXX,. X0X4X3X6XkXaX6 i N D |.Y                   lX",
"lXlXlXlXlXlXlXlXlXlXlXlXlX        2XkXkXkXkXkXsXsXkXkXkXkXkXkXkX3     E.P                 y S.lX",
"lXlXlXlXlXlXlXlXlXlXlXlXlX        [.kXkXkXkXkXkXkXkXkXkXkXkXkXkX,     ~.                =  .O.t.",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX      T.kXkXkXkXkXkXkXkXkXkXkXkXkXkX>                       lXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX      c kXkXkXkXkXkXkXkXkXkXkXkXkXkX;               s /.    lXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlX        :XkXkXkXkXkXkXkXkXkXkXkXkXaX$           9 ' $Xh     lXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlX      E kXkXkXkXkXkXkXkXkXkXkXkXtX        9 $X_.R         lXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlX        ;XkXkXkXkXkXkXkXkXkXkXkX$X                        lXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX      l tXkXkXkXkXkXkXkXkXkXkXE                         lXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};
