/* XPM */
/* $XConsortium: DtABpuw.pm /main/3 1995/07/18 16:15:15 drk $ */
static char * DtABpuw_x_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 32 3 1 0 0",
/* colors */
"     s iconGray2     m white c #bdbdbdbdbdbd",
".    s iconGray8     m black c #212121212121",
"X    s iconGray4     m white c #949494949494",
/* pixels */
"                                               .",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.",
" X........................................... X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X.",
" X.X            .X            .X           .X X.",
" X.X XXXXXXXXXXX.X XXXXXXXXXXX.X XXXXXXXXXX.X X.",
" X.X XXXXXXXXXXX.X XXXXXXXXXXX.X XXXXXXXXXX.X X.",
" X.X.............X.............X............X X.",
" X.                                           X.",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.",
" ..............................................."};
