/* XPM */
/* $XConsortium: DtMa.pm /main/3 1995/07/18 16:21:30 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * DtMa_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"98 98 11 1 0 0",
/* colors */
"     s background    m black c #949494949494",
".    s iconGray2     m white c #bdbdbdbdbdbd",
"X    s iconGray4     m white c #949494949494",
"o	s iconColor2	m white	c white",
"O    s iconGray1     m white c #dededededede",
"+    s iconGray5     m black c #737373737373",
"@	s iconColor4	m white	c green",
"#    s iconGray6     m black c #636363636363",
"$    s iconGray3     m white c #adadadadadad",
"%	s iconColor1	m black	c black",
"&    s iconGray7     m black c #424242424242",
/* pixels */
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"               .....................................................................              ",
"               .....................................................................              ",
"               X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X              ",
"               XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX              ",
"             .........................................................................            ",
"             .........................................................................            ",
"             X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X            ",
"             XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX            ",
"           oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO+          ",
"           oO++++OO++O++++OO+OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX@X@X@OOOOO+          ",
"           oO+++O+++O+++O++OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO++++OOOO++++@X@X@XOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO++++OOOOX@X@X@OOOOO+          ",
"           oO++++O+++OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@X@X@XOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX@X@X@OOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO++++OOOO++++@X@X@XOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO++++OOOOX@X@X@OOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@X@X@XOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO+          ",
"           oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO+          ",
"          ooOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO++         ",
"         oooOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO#++        ",
"        ooooOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO#+++       ",
"       oooOoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO#X+++      ",
"      oooO+oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO#XX+++     ",
"     oooO++oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO#XX$+++    ",
"    oooO+##oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO#%%XX+++   ",
"   oooO++##oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO#%%XX$+++  ",
"   ooOO..$$$$XXXXXXXXXXXX......OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoooooooooooooooooooo++  ",
"   ooOOoooooooooooooooooooo$$...OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo....................++  ",
"   ooOO.O....$.$$$$$$$$$$$$#$$...OOOOOO+++O++++OO+++OOOOOOOOOOOOOOOOOOOOo.$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$&$$...OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo.$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$&$$....OOOO++++O++++++O+++OOOOOOOOOOOOOOOOOOo.$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$&$$....OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo.$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$&$$....OOOO+++O++++O++++OOOOOOOOOOOOOOOOOOOOo.$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$&$$....OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo.$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$&$$....OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo.$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$&$$....OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo.$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$&$$.........................................o.$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$&$$$........................................o.$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$&$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$o.$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$$&$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$o.$$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$$$&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&.$$$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$$$.........................................$$$$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOOOO....$.$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$XXXXXX+++  ",
"   ooOO.O....$.$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$X$XXXXXX++  ",
"   ooOOO......$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$XXXXXX+++  ",
"   oo.$X$XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX++  ",
"   oo$X$XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX+++  ",
"   ooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX++++  ",
"   $oX++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  "};
