/* XPM */
static char *gcompris_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #010100",
".  c #1F1313",
"X  c #220F0F",
"o  c #381A1A",
"O  c #2E2401",
"+  c #1B102D",
"@  c #010137",
"#  c #030339",
"$  c #0D0736",
"%  c #160735",
"&  c #191434",
"*  c #120B2B",
"=  c #2F1E29",
"-  c #301E27",
";  c #261C36",
":  c #2C0F35",
">  c #322028",
",  c #3C2624",
"<  c #3C3B35",
"1  c #363638",
"2  c #373838",
"3  c #3D2D3C",
"4  c #4F1E1E",
"5  c #523F00",
"6  c #4B2F1E",
"7  c #56381D",
"8  c #54193E",
"9  c #621E20",
"0  c #412A24",
"q  c #58272A",
"w  c #5F2D32",
"e  c #403E3F",
"r  c #423F34",
"t  c #513D28",
"y  c #5A4500",
"u  c #715700",
"i  c #6F551E",
"p  c #775C1C",
"a  c #64401A",
"s  c #4D462F",
"d  c #554C2C",
"f  c #5C512A",
"g  c #5E5227",
"h  c #454132",
"j  c #4A4538",
"k  c #524D3A",
"l  c #5F5435",
"z  c #635527",
"x  c #6C5B25",
"c  c #6A5A2F",
"v  c #635632",
"b  c #7A6429",
"n  c #756226",
"m  c #271C45",
"M  c #362E48",
"N  c #3E3D40",
"B  c #3E324A",
"V  c #242456",
"C  c #472D44",
"Z  c #732444",
"A  c #51504A",
"S  c #5C505D",
"D  c #614F4E",
"F  c #705E5D",
"G  c #78514F",
"H  c #6B604B",
"J  c #797059",
"K  c #5A5B7D",
"L  c #883713",
"P  c #990B22",
"I  c #D50D18",
"U  c #FE0E0E",
"Y  c #FA1817",
"T  c #EB2E18",
"R  c #D51923",
"E  c #C83132",
"W  c #FB2D2D",
"Q  c #FC2424",
"!  c #FA3939",
"~  c #EA393C",
"^  c #9B461D",
"/  c #976E0F",
"(  c #916F16",
")  c #8A711C",
"_  c #9B7D16",
"`  c #967919",
"'  c #987917",
"]  c #866600",
"[  c #A37D00",
"{  c #A37D13",
"}  c #AE5E23",
"|  c #9D7F21",
" . c #947721",
".. c #956726",
"X. c #972C40",
"o. c #A0384B",
"O. c #C73944",
"+. c #8B4158",
"@. c #B3464C",
"#. c #806A5D",
"$. c #836D65",
"%. c #8E796C",
"&. c #CD4A54",
"*. c #F94747",
"=. c #E6595A",
"-. c #F75656",
";. c #D15860",
":. c #D77174",
">. c #F56C6C",
",. c #F76161",
"<. c #F47E7E",
"1. c #B58F0E",
"2. c #BC940C",
"3. c #A38214",
"4. c #AC8816",
"5. c #B58D18",
"6. c #BB9310",
"7. c #AE860B",
"8. c #A98322",
"9. c #DA8A07",
"0. c #C69900",
"q. c #CD9D01",
"w. c #CB9B0B",
"e. c #C29606",
"r. c #DF9900",
"t. c #C69A12",
"y. c #E59902",
"u. c #F09A01",
"i. c #FC8609",
"p. c #CEA10A",
"a. c #D4A300",
"s. c #D9A700",
"d. c #DCAA01",
"f. c #D3A409",
"g. c #DBA908",
"h. c #DAA40E",
"j. c #CEA212",
"k. c #D4A61A",
"l. c #E5A300",
"z. c #EBA500",
"x. c #E3AE00",
"c. c #ECAB01",
"v. c #E2AA0B",
"b. c #F4A600",
"n. c #FEAD00",
"m. c #FFA10C",
"M. c #E6B101",
"N. c #EBB401",
"B. c #EFB801",
"V. c #E9B409",
"C. c #F3B301",
"Z. c #FFB300",
"A. c #F4BC00",
"S. c #FCBE00",
"D. c #F7BB0B",
"F. c #EBB616",
"G. c #C09A23",
"H. c #CD9238",
"J. c #CEA628",
"K. c #DAB02E",
"L. c #CEA939",
"P. c #DFA53C",
"I. c #D7B13E",
"U. c #EDAD22",
"Y. c #F1AE21",
"T. c #E8B827",
"R. c #EFAA3E",
"E. c #F2B233",
"W. c #F5C304",
"Q. c #FFC400",
"!. c #FFC50B",
"~. c #FFC801",
"^. c #E1C015",
"/. c #FFC612",
"(. c #FFC61D",
"). c #FFC91B",
"_. c #FFC817",
"`. c #FFC725",
"'. c #FFC922",
"]. c #FFCA2D",
"[. c #FFC734",
"{. c #FECB34",
"}. c #FFC73B",
"|. c #FAC73F",
" X c #9A8347",
".X c #A4845A",
"XX c #9D9570",
"oX c #97867B",
"OX c #A38567",
"+X c #DCB544",
"@X c #DFA553",
"#X c #EEAA41",
"$X c #E7BB48",
"%X c #FBB547",
"&X c #FEB94D",
"*X c #F6B449",
"=X c #E1BA51",
"-X c #FEBB54",
";X c #FFBF5A",
":X c #F0BF51",
">X c #CEA66F",
",X c #FFCF4A",
"<X c #FFCB43",
"1X c #FFD044",
"2X c #ECC759",
"3X c #FFC953",
"4X c #FFC05E",
"5X c #FFCA5F",
"6X c #FFD256",
"7X c #EAC243",
"8X c #ECC967",
"9X c #FFC264",
"0X c #FFCA64",
"qX c #FEC56C",
"wX c #FFCC69",
"eX c #F4C86E",
"rX c #FFD26B",
"tX c #FFD463",
"yX c #EDC876",
"uX c #FFC770",
"iX c #FFCB75",
"pX c #FFCC7C",
"aX c #F3C776",
"sX c #FFD375",
"dX c #FFD879",
"fX c #636487",
"gX c #B09681",
"hX c #8B8BA0",
"jX c #9E9EAE",
"kX c #B8B8B8",
"lX c #A9AAB9",
"zX c #F28A8A",
"xX c #F48181",
"cX c #FFCE84",
"vX c #FACE8B",
"bX c #F4D381",
"nX c #FFD186",
"mX c #FFD28B",
"MX c #FFDA8D",
"NX c #FFD984",
"BX c #FFD594",
"VX c #FDDB94",
"CX c #FFD79A",
"ZX c #FFD99D",
"AX c #E8C488",
"SX c #FFDBA3",
"DX c #FFDEAB",
"FX c #FDE2AC",
"GX c #FCE3A7",
"HX c #FFE2B4",
"JX c #FFE4BC",
"KX c #FFE6C1",
"LX c #FFE9C5",
"PX c #FFEBCC",
"IX c #FFECD0",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXg.T.+X=X+XL.G.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXa.A.{.VXSXDXDXDXZXbX8XI.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUX0.B.Q.Q.[.CXSXSXSXDXHXJXJXHXVX8X+XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX0.M.~.Q.Q.!.rXBXCXSXSXDXFXHXHXJXLXJXVX8XK.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXA.Q.x.M.Q.Q.~.(.sXBXBXCXSXSXDXHXHXHXJXKXKXHXbX$Xt.UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXq.Q.Q.Q.d.M.Q.Q.Q.`.sXmXBXBXCXSXSXDXHXJXJXJXLXPXKXVX2XJ.UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXA.Q.Q.Q.x.x.Q.Q.Q.(.wXnXmXBXBXZXSXSXDXHXJXJXKXLXPXPXGX8XJ.UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXa.Q.Q.Q.Q.x.x.Q.~.S.J..X$.%.>XBXCXZXSXSXFXFXHXJXKXLXPXIXFXyXL.UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXM.Q.Q.Q.Q.x.x.B.n + # @ @ & $.vXBXCXZXSXDXDXHXHXJXKXLXPXIXFXyXJ.UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXB.~.Q.Q.~.x./ , = > - - , ; OXvXBXBXCXZXSXDXHXHXJXJXKXPXIXIXHX8XJ.UXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXA.~.d.[ w.a , + a 6 * t - B yXvXmXBXBXCXZXSXSXDXHXJXJXLXLXPXIXGX2Xj.UX",
"UXUXUXUXUXUXUXUXUXUXUXUXUX0.M.y y ( m %.D + S oXC # & >XcXcXvXmXBXCXZXSXSXDXDXHXJXJXLXLXPXPXVX7X",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUX5   u p fXkXjXV lXkXhX# @ 8.<XuXcXcXvXmXBXCXCXSXDXDXHXHXJXJXLXPXIXLX",
"UXUXUXUXUXUXUXUXUXUX! ,.<.UX    ] i K A J H XXk hX# @ ' ~.(.3XiXcXcXvXmXBXCXCXSXGXFXFXJXJXKXLXPX",
"*.W U Q -.xXzX>.*.Q Y ! ,.:.X   L q B 5.M.W.W.^. X# $ } S.Q.!.].0XpXcXcXnXBXBXCXZXSXSXDXHXHXJXJX",
">.*.Q Y W -.xXzX>.! UXUX*.=.o   9 8 , y.n.S.S.W.' : P Q m.Q.Q.Q.!.[.0XpXcXcXnXBXBXCXSXSXDXDXHXJX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUX4   . @.X.^ 9.u.9...G &.W Y i.~.Q.Q.Q.Q./.}.wXpXcXcXmXBXBXCXSXSXDXDX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXO w =.~ T T E ;.xX:.Z q M.~.Q.Q.Q.Q.Q.Q./.}.wXpXcXvXmXBXBXCXSXSX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX0.7.* C o.E I R O.+.m # & g.~.Q.Q.Q.Q.Q.Q.Q.Q./.}.0XpXcXvXmXBXCXCX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXq.x.p.% # # % % % $ # # # $ w.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q./.[.5XpXvXmXmXBX",
"UXUXUXUXUXUXUXUXUXUXUXUXd.A.A.N.B.t # @ @ @ @ @ @ @ # # 7.~.Q.Q.Q.~.Q.N.x.B.Q.~.~.Q.!.`.3XsXcXmX",
"UXUXUXUXUXUXUXUXUXUXUXM.Q.~.M.v.U.H.3 # @ @ @ @ @ # # $ { Q.Q.Q.Q.A.s.x.B.x.s.M.S.Q.Q.Q.S.(.}.0X",
"UXUXUXUXUXUXUXUXUXUXUXM.~.D.Y.R.&X&X@XH ; # @ @ @ # M  Xg.x.A.A.d.d.A.Q.Q.Q.S.M.d.x.A.~.Q.Q.Q.!.",
"UXUXUXUXUXUXUXUXUXUXUXh.Y.E.&X&X;X;X9XqX>XOX#.F $.gXAX].~.S.M.a.d.S.~.Q.Q.Q.Q.~.Q.M.d.d.B.S.~.Q.",
"UXUXUXUXUXUXUXUXUXUXR.R.&X-X;X4X9XuXsXpXnXBXBXZXSXMX[.~.~.Q.Q.S.M.x.M.Q.Q.Q.Q.Q.Q.Q.Q.A.M.s.x.A.",
"UXUXUXUXUXUXUXUX#X*X&X;X4X9XuXiXpXcXvXBXBXSXSXVX6X_.Q.Q.Q.Q.Q.~.Q.Q.B.z.C.A.Q.~.Q.Q.Q.~.~.Q.M.d.",
"UXUXUXUXUXUXUX*X&X;X4X9XuXiXpXcXnXBXCXSXSXdX,X_.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.S.n.b.b.b.C.S.~.Q.Q.Q.Q.Q.Q.",
"M.UXUXUXUX*X&X;X9XqXuXpXpXnXmXBXSXSXVXtX].!.Q.Q.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.~.S.n.n.n.b.b.c.B.S.Q.Q.Q.~.",
"Q.A.0.P.;X;X9XqXiXpXcXnXBXCXZXVXsX|._.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.S.Z.Z.n.n.n.n.b.z.c.B.A.S.",
"Q.Q.S.F.:XqXiXcXcXmXBXCXZXNX6XT.p.g.Q.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.S.Z.Z.Z.n.n.n.n.n.n.b.z.l.",
"Q.Q.~.S.$XcXvXmXCXZXVXtX{.k.' g r s p.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.S.n.S.Z.Z.Z.n.n.n.n.n.n.b.y.",
"Q.S.F.:XvXBXCXBXdX,X).W.3.s 2 h g g 2.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.S.S.S.S.S.C.c.c.N.M.c.l.z.y.UXUX",
"V.K.aXCXBXsX,X'.~.Q.Q.1.2 h _ g.A.A.Q.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.S.S.S.S.S.S.C.6.b c 8.B.~.Q.B.a.UXUXUX",
"eXnXsX,X'.!.~.Q.Q.Q.Q.n 1 _ ~.~.~.M.f.B.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.S.S.S.w.b j N l | V.Q.Q.Q.Q.A.d.UX",
"<XF.M.M.M.A.Q.Q.Q.Q.S.n 1 3.Q.Q.4.d h ` Q.Q.Q.Q.Q.Q.Q.Q.S.Q.S.Q.v. .j e l 4.V.Q.~.Q.Q.Q.Q.Q.Q.A.",
"x.B.A.Q.A.x.S.Q.Q.Q.~.4.1 x A.Q.6._ x d M.~.Q.Q.Q.Q.Q.Q.Q.~.S.t.c e j | V.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.",
"Q.Q.~.Q.Q.M.A.Q.Q.Q.~.f.r s g.~.Q.M.x d M.~.Q.Q.Q.Q.Q.Q.Q.B. .j N b j.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.M.",
"Q.~.Q.Q.Q.B.B.Q.Q.Q.~.M.g 1 x _ ) g d 6.Q.Q.Q.~.Q.Q.~.Q.g.b N j  .V.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.~.A.x.",
"Q.Q.Q.Q.Q.A.M.Q.Q.Q.Q.Q.) < r s z ` g.~.Q.S.A.A.N.x.d.q.x e k 5.!.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.~.M.A.",
"Q.Q.Q.Q.~.A.M.~.Q.Q.Q.Q.M.t.1.e.a.M.M.a.q.UXUXUXUXUXUXUXUXUX3.S.~.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.A.M.Q.",
"M.Q.Q.Q.Q.Q.a.s.s.s.a.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXM.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.M.A.Q.",
"d.x.Q.Q.Q.Q.a.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXq.B.Q.Q.Q.Q.Q.Q.Q.Q.Q.S.x.M.x.",
"~.x.x.Q.Q.Q.x.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXa.B.Q.~.~.Q.Q.Q.Q.x.a.B.Q.",
"Q.Q.x.x.Q.Q.M.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXq.M.S.Q.~.Q.Q.x.A.Q.Q.",
"Q.Q.Q.x.x.Q.x.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXd.B.S.Q.~.~.Q.Q.",
"Q.Q.Q.Q.x.x.0.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXa.x.M.M.B.",
"S.Q.~.Q.~.a.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"a.x.M.M.a.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
