/* XPM */
/* $XConsortium: Dthitem.l.pm /main/3 1995/07/18 16:39:23 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

/* Designed by the User Interaction Design Group, Hewlett-Packard */
static char *helpitem48[]={
/* width height ncolors cpp [x_hot y_hot] */
"48 48 21 1 0 0",
/* colors */
"  c none m none s none",
"$    s topShadowColor m white c #bdbdbdbdbdbd",
"&    s background    m black c #949494949494",
"(    s selectColor m white c #737373737373",
"*    s bottomShadowColor m black c #636363636363",
". s iconColor1 c black     m black",
"B s iconColor2 c white     m white",
"4 s iconColor3 c red       m black",
"6 s iconColor4 c green     m white",
"8 s iconColor5 c blue      m black",
"2 s iconColor6 c yellow    m white",
": s iconColor7 c cyan      m white",
"0 s iconColor8 c magenta   m black",
"<    s iconGray1     m white c #dededededede",
">    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray3     m white c #adadadadadad",
"D    s iconGray4     m white c #949494949494",
"F    s iconGray5     m black c #737373737373",
"H    s iconGray6     m black c #636363636363",
"J    s iconGray7     m black c #424242424242",
"L    s iconGray8     m black c #212121212121",
/* pixels */
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                       *******                  ",
"                    ***<<<<<<<***               ",
"                   **<<DDDDDDD<<**              ",
"                 **<<DDDDDDDDDDD<<**            ",
"                **<DDDDDDDDDDDDDDD<$$           ",
"                *<DDDHDDDDDHDDDDDHDJ$           ",
"               *<DDDDDDBBBBBBBDDDDDDJ$          ",
"              **<HDHDDBBBBBBBBBHDDDHJ$$         ",
"              *<DDDDDBBBBDDDBBBBDDDDDJ$         ",
"              *<DHDHDBBBDHDHDBBBDHDHDJ$         ",
"             *<DDDHDDBBBHDDDDBBBDDHDDDJ$        ",
"             *<HDHDHDBBBDHDHDBBBDHDHDHJ$        ",
"             *<DHDDDHDHDHDDDBBBBHDDDHDJ$        ",
"            .*<HDHDHDHDHDHDBBBBHDHDHDHJ$        ",
"            .*<DHDHDHDHDHDBBBBHDHDHDHDJ$        ",
"            .*<HDHDHHHDHDBBBBHDHHHDHDHJ$        ",
"            .*<DHDHDHDHDHBBBHDHDHDHDHDJ$        ",
"           ...*<HHHHDHHHDBBBDHHHDHHHDJ$         ",
"           ...*<HDHDHDHDHDHDHDHDHDHDHJ$         ",
"           ...*<HHHHHHHHHBBBHHHHHHHHJ$$         ",
"           ....*<DHDHDHDHBBBHDHDHDHDJ$          ",
"           .....*<HHHHHHHBBBHHHHHHHJ$           ",
"          ......*<JDHHHDHHHDHHHDHHJ$$           ",
"          .......*$JJHHHHHHHHHHHJJ$$            ",
"          .........$$JJHHHHHHDJJ$$              ",
"          ..........$$$JJJJJJJ$$$               ",
"          .............$$$$$$$$                 ",
"     .   ....................                   ",
"     .   ..................                     ",
"     ..  ...............                        ",
"     ... ..........                             ",
"     .........                                  ",
"     .....                                      ",
"     ......                                     ",
"     .......                                    ",
"     .........                                  ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                "
};
