/* XPM */
/* $XConsortium: IcMxbdy.l.pm /main/3 1995/07/18 17:13:40 drk $ */
static char * IcMxbdy_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 10 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray1     m white c #dededededede",
"X    s iconGray3     m white c #adadadadadad",
"o    s iconGray7     m black c #424242424242",
"O	s iconColor2	m white	c white",
"+    s iconGray5     m black c #737373737373",
"@	s iconColor5	m black	c blue",
"#    s iconGray2     m white c #bdbdbdbdbdbd",
"$    s iconGray4     m white c #949494949494",
"%    s iconGray6     m black c #636363636363",
/* pixels */
"   ..........................................   ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.  ",
" .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX. ",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXXo",
".XXO........................................oXXo",
".XXO.+++.++......................+++.+..@@@.oXXo",
".XXO......#######...................+.+.X@@.oXXo",
".XXO.++.++.$$$$$$$$$++###........+++.+..@@X.oXXo",
".XXO........$%+%+%+%%+%+ooooX...........@@@.oXXo",
".XXO.........%%%%%%%%%%%$$$ooo##............oXXo",
".XXO..........$+$+$+$+%%+$++ooo##...........oXXo",
".XXO...........$$$$$$$+%%$$++ooo##..........oXXo",
".XXO...........OO$%$%$%+%%$$++ooo#..........oXXo",
".XXO...........OOOOX%%++%%%$++ooo##.........oXXo",
".XXO..........OOOO#XX+++%%%$$++ooo##........oXXo",
".XXO..........OOO##XXXX%%%X$$++oooo##.......oXXo",
".XXO.........OOO###XXXXXXXXX$++oooooX#......oXXo",
".XXO........OOO####Ooooooo$ooooooooooo#.....oXXo",
".XXO.......OOOOOOOO#.ooo++++oooooXXXXXX#....oXXo",
".XXO........######OO.ooo+XX++ooooX##........oXXo",
".XXO.............#OO.+oo+XXX++oooX#.........oXXo",
".XXO.............#OO.X+o$XXXX+ooo+..........oXXo",
".XXO.............#OO..X+XXXXX+oo$$..........oXXo",
".XXOooooooooooooooOO..##XXXXX+oooooooooooooooXXo",
".XXXXXXXXXXXXXXXXXOO.###XXXXX+ooXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXOO..#X#XXXX++ooXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXX#OO.##X%+++++oooXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXX#OO..##XX%%oooooXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXX#.OO.##XX++o+XXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXX%.OO..##XX+o+XXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXOOOOOO.#XXX++o+XXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXX%%%ooo###X++o+XXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXX+++ooo##+o+XXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXX++oo++o+XXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXX+ooXoXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXX+oo+XXXXXXXXXXXXXXXXXXXXo",
" oXXXXXXXXXXXXXXXXXXXXXX+++XXXXXXXXXXXXXXXXXXXo ",
"  oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo  ",
"   oooooooooooooooooooooooooooooooooooooooooo   "};
