/* XPM */
/* $XConsortium: DtMnone.t.pm /main/3 1995/07/18 16:23:01 drk $ */
static char * DtMnone_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 8 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray7     m black c #424242424242",
"o    s iconGray4     m white c #949494949494",
"O    s iconGray1     m white c #dededededede",
"+    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray3     m white c #adadadadadad",
"#    s iconGray6     m black c #636363636363",
/* pixels */
"                ",
"                ",
"                ",
"                ",
"                ",
"  ...........X  ",
"  .oOOOOOOOOOX  ",
" .ooOOOOOOOOO+X ",
" .oooOOOOOOOO+X ",
".ooooOOOOOOOO++X",
".....@@@@@@@OOOO",
".O+@#@@@@@@Ooo#X",
".O+@oOOOOOOooo#X",
".O+@oooooooooo#X",
".O+@oooooooooo#X",
"###############X"};
